@@ -23,6 +23,9 @@
 # win32/buildkid3.bat, so that these tools can be found, then start
 # buildkid3.bat from a Windows command prompt.
 #
+# You can also build a Windows version from Linux using the MinGW cross
+# compiler. Set compiler="cross-mingw" below.
+#
 # For Mac: XCode, Qt, html\docbook.xsl. XCode and Qt should be installed at
 # the default location, docbook.xsl in
 # $HOME/docbook-xsl-1.72.0/html/docbook.xsl.
@@ -46,6 +49,11 @@ test ${kernel:0:5} = "MINGW" && kernel="MINGW"
 
 compiler="gcc"
 
+qt_version=4.8.5
+zlib_version=1.2.8
+libogg_version=1.3.1
+libav_version=0.8.7
+
 # Uncomment for debug build
 #ENABLE_DEBUG=--enable-debug
 #CMAKE_BUILD_TYPE_DEBUG="-DCMAKE_BUILD_TYPE=Debug"
@@ -62,6 +70,28 @@ elif test $kernel = "Darwin"; then
 CMAKE_OPTIONS="-G \"Unix Makefiles\""
 fi
 
+if test "$compiler" = "cross-mingw"; then
+CMAKE_OPTIONS="$CMAKE_OPTIONS -DCMAKE_TOOLCHAIN_FILE=$thisdir/source/mingw.cmake"
+CONFIGURE_OPTIONS="--host=i586-mingw32msvc"
+fi
+
+if test $kernel = "Darwin" && test $(uname -m) = "x86_64"; then
+#ARCH=i386
+if test "$ARCH" = "i386"; then
+  # To build a 32-bit Mac OS X version of Kid3 use:
+  # cmake -G "Unix Makefiles" -DCMAKE_CXX_FLAGS="-arch i386" -DCMAKE_C_FLAGS="-arch i386" -DCMAKE_EXE_LINKER_FLAGS="-arch i386" -DQT_QMAKE_EXECUTABLE=/usr/local/Trolltech/Qt-4.8.5-i386/bin/qmake -DCMAKE_BUILD_TYPE=Release -DWITH_FFMPEG=ON -DCMAKE_INSTALL_PREFIX= ../kid3
+  # Building multiple architectures needs ARCH_FLAG="-arch i386 -arch x86_64",
+  # CONFIGURE_OPTIONS="--disable-dependency-tracking", but it fails with libav.
+  ARCH_FLAG="-arch i386"
+else
+  ARCH_FLAG="-Xarch_x86_64"
+fi
+CMAKE_OPTIONS="$CMAKE_OPTIONS -DCMAKE_C_FLAGS=\"-O2 $ARCH_FLAG -mmacosx-version-min=10.5\" -DCMAKE_CXX_FLAGS=\"-O2 $ARCH_FLAG -mmacosx-version-min=10.5 -fvisibility=hidden -fvisibility-inlines-hidden\""
+export CFLAGS="-O2 $ARCH_FLAG -mmacosx-version-min=10.5"
+export CXXFLAGS="-O2 $ARCH_FLAG -mmacosx-version-min=10.5"
+export LDFLAGS="$ARCH_FLAG -mmacosx-version-min=10.5"
+fi
+
 if which wget >/dev/null; then
 DOWNLOAD=wget
 else
@@ -92,55 +122,52 @@ fixcmakeinst() {
 test -d source || mkdir source
 cd source
 
-test -f flac_1.2.1-6.diff.gz ||
-$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/f/flac/flac_1.2.1-6.diff.gz
-test -f flac_1.2.1.orig.tar.gz ||
-$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/f/flac/flac_1.2.1.orig.tar.gz
+test -f flac_1.3.0-2.debian.tar.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/f/flac/flac_1.3.0-2.debian.tar.gz
+test -f flac_1.3.0.orig.tar.xz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/f/flac/flac_1.3.0.orig.tar.xz
 
 test -f id3lib3.8.3_3.8.3-15.debian.tar.gz ||
 $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/i/id3lib3.8.3/id3lib3.8.3_3.8.3-15.debian.tar.gz
 test -f id3lib3.8.3_3.8.3.orig.tar.gz ||
 $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/i/id3lib3.8.3/id3lib3.8.3_3.8.3.orig.tar.gz
 
-test -f libogg_1.3.0-4.diff.gz ||
-$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/libo/libogg/libogg_1.3.0-4.diff.gz
-test -f libogg_1.3.0.orig.tar.gz ||
-$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/libo/libogg/libogg_1.3.0.orig.tar.gz
+test -f libogg_1.3.1-1.diff.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/libo/libogg/libogg_1.3.1-1.diff.gz
+test -f libogg_1.3.1.orig.tar.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/libo/libogg/libogg_1.3.1.orig.tar.gz
 
 test -f libvorbis_1.3.2-1.3.diff.gz ||
 $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/libv/libvorbis/libvorbis_1.3.2-1.3.diff.gz
 test -f libvorbis_1.3.2.orig.tar.gz ||
 $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/libv/libvorbis/libvorbis_1.3.2.orig.tar.gz
 
-test -f taglib_1.8-1.debian.tar.gz ||
-$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/t/taglib/taglib_1.8-1.debian.tar.gz
-test -f taglib_1.8.orig.tar.gz ||
-$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/t/taglib/taglib_1.8.orig.tar.gz
+test -f taglib-1.9.tar.gz ||
+$DOWNLOAD http://taglib.github.io/releases/taglib-1.9.tar.gz
 
-test -f zlib_1.2.7.dfsg-13.debian.tar.gz ||
-$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/z/zlib/zlib_1.2.7.dfsg-13.debian.tar.gz
-test -f zlib_1.2.7.dfsg.orig.tar.gz ||
-$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/z/zlib/zlib_1.2.7.dfsg.orig.tar.gz
+test -f zlib_1.2.8.dfsg-1.debian.tar.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/z/zlib/zlib_1.2.8.dfsg-1.debian.tar.gz
+test -f zlib_1.2.8.dfsg.orig.tar.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/z/zlib/zlib_1.2.8.dfsg.orig.tar.gz
 
-# With the new libav 9.1, some M4A fingerprints are not recognized,
+# With the new libav 9.5, some M4A fingerprints are not recognized,
 # so we'll stick with the old.
-libav_version=0.8.5
-if test "$libav_version" = "0.8.5"; then
-test -f libav_0.8.5.orig.tar.gz ||
-$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/liba/libav/libav_0.8.5.orig.tar.gz
-test -f libav_0.8.5-1.debian.tar.gz ||
-$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/liba/libav/libav_0.8.5-1.debian.tar.gz
+if test "$libav_version" = "0.8.7"; then
+test -f libav_0.8.7.orig.tar.xz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/liba/libav/libav_0.8.7.orig.tar.xz
+test -f libav_0.8.7-1.debian.tar.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/liba/libav/libav_0.8.7-1.debian.tar.gz
 else
-test -f libav_9.1.orig.tar.xz ||
-$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/liba/libav/libav_9.1.orig.tar.xz
-test -f libav_9.1-3.debian.tar.gz ||
-$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/liba/libav/libav_9.1-3.debian.tar.gz
+test -f libav_9.9.orig.tar.xz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/liba/libav/libav_9.9.orig.tar.xz
+test -f libav_9.9-1.debian.tar.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/liba/libav/libav_9.9-1.debian.tar.gz
 fi
 
 test -f chromaprint_0.7.orig.tar.gz ||
 $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/c/chromaprint/chromaprint_0.7.orig.tar.gz
-test -f chromaprint_0.7-1.debian.tar.gz ||
-$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/c/chromaprint/chromaprint_0.7-1.debian.tar.gz
+test -f chromaprint_0.7-2.debian.tar.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/c/chromaprint/chromaprint_0.7-2.debian.tar.gz
 
 #test -f mp4v2_1.9.1+svn479~dfsg0.orig.tar.bz2 ||
 #$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/m/mp4v2/mp4v2_1.9.1+svn479~dfsg0.orig.tar.bz2
@@ -149,6 +176,31 @@ $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/c/chromaprint/chromaprint_0.
 
 # Create patch files
 
+if test "$compiler" = "cross-mingw"; then
+test -f mingw.cmake ||
+cat >mingw.cmake <<EOF
+set(QT_PREFIX /windows/Qt/$qt_version)
+
+set(CMAKE_SYSTEM_NAME Windows)
+set(CMAKE_C_COMPILER i586-mingw32msvc-gcc)
+set(CMAKE_CXX_COMPILER i586-mingw32msvc-g++)
+set(CMAKE_RC_COMPILER i586-mingw32msvc-windres)
+set(CMAKE_FIND_ROOT_PATH /usr/i586-mingw32msvc \${QT_PREFIX} $thisdir/buildroot/usr/local $thisdir/zlib-$zlib_version/inst/usr/local $thisdir/libav-$libav_version/inst/usr/local)
+set(CMAKE_FIND_ROOT_PATH_MODE_PROGRAM NEVER)
+set(CMAKE_FIND_ROOT_PATH_MODE_LIBRARY ONLY)
+set(CMAKE_FIND_ROOT_PATH_MODE_INCLUDE ONLY)
+
+set(QT_BINARY_DIR /usr/lib/i386-linux-gnu/qt4/bin)
+set(QT_LIBRARY_DIR  \${QT_PREFIX}/lib)
+set(QT_QTCORE_LIBRARY   \${QT_PREFIX}/lib/libQtCore4.a)
+set(QT_QTCORE_INCLUDE_DIR \${QT_PREFIX}/include/QtCore)
+set(QT_MKSPECS_DIR  \${QT_PREFIX}/mkspecs)
+set(QT_MOC_EXECUTABLE  \${QT_BINARY_DIR}/moc)
+set(QT_QMAKE_EXECUTABLE  \${QT_BINARY_DIR}/qmake)
+set(QT_UIC_EXECUTABLE  \${QT_BINARY_DIR}/uic)
+EOF
+fi
+
 test -f fink_flac.patch ||
 cat >fink_flac.patch <<"EOF"
 diff -ruN flac-1.2.1/patches/fixrpath.sh flac-1.2.1.new/patches/fixrpath.sh
@@ -216,15 +268,14 @@ diff -ruN flac-1.2.1/patches/nasm.h.patch flac-1.2.1.new/patches/nasm.h.patch
 + %else
 + 	%error unsupported object format!
 + %endif
-diff -ruN flac-1.2.1/src/plugin_xmms/Makefile.in flac-1.2.1.new/src/plugin_xmms/Makefile.in
---- flac-1.2.1/src/plugin_xmms/Makefile.in	2007-09-16 16:05:18.000000000 -0400
-+++ flac-1.2.1.new/src/plugin_xmms/Makefile.in	2008-02-18 19:48:45.000000000 -0500
-@@ -265,7 +265,6 @@
+diff -ru flac-1.3.0/src/plugin_xmms/Makefile.in flac-1.3.0.new/src/plugin_xmms/Makefile.in
+--- flac-1.3.0/src/plugin_xmms/Makefile.in	2013-05-27 10:11:57.000000000 +0200
++++ flac-1.3.0.new/src/plugin_xmms/Makefile.in	2013-10-16 13:30:02.000000000 +0200
+@@ -361,7 +361,6 @@
  	$(top_builddir)/src/share/replaygain_synthesis/libreplaygain_synthesis.la \
  	$(top_builddir)/src/share/utf8/libutf8.la \
  	$(top_builddir)/src/libFLAC/libFLAC.la \
 -	-L$(top_builddir)/src/libFLAC/.libs \
- 	@OGG_LIBS@ \
  	@XMMS_LIBS@ \
  	@LIBICONV@
 EOF
@@ -316,22 +367,6 @@ diff -ru id3lib-3.8.3.orig/src/io_helpers.cpp id3lib-3.8.3/src/io_helpers.cpp
 
 EOF
 
-test -f taglib-xm-file-save.patch ||
-cat >taglib-xm-file-save.patch <<"EOF"
-diff -ru taglib-1.8.orig/taglib/xm/xmfile.cpp taglib-1.8/taglib/xm/xmfile.cpp
---- taglib-1.8.orig/taglib/xm/xmfile.cpp	2012-09-06 20:03:15.000000000 +0200
-+++ taglib-1.8/taglib/xm/xmfile.cpp	2012-09-22 08:55:07.052052207 +0200
-@@ -443,7 +443,7 @@
-       return false;
- 
-     uint len = std::min(22UL, instrumentHeaderSize - 4U);
--    if(i > lines.size())
-+    if(i >= lines.size())
-       writeString(String::null, len);
-     else
-       writeString(lines[i], len);
-EOF
-
 test -f taglib-msvc.patch ||
 cat >taglib-msvc.patch <<"EOF"
 diff -ru taglib-1.8.orig/CMakeLists.txt taglib-1.8/CMakeLists.txt
@@ -350,31 +385,7 @@ diff -ru taglib-1.8.orig/CMakeLists.txt taglib-1.8/CMakeLists.txt
  	set(FRAMEWORK_INSTALL_DIR "/Library/Frameworks" CACHE STRING "Directory to install frameworks to.")
 EOF
 
-test -f taglib-no-id3-duplication.patch ||
-cat >taglib-no-id3-duplication.patch <<"EOF"
-diff --git a/taglib/mpeg/mpegfile.cpp b/taglib/mpeg/mpegfile.cpp
-index c73da41..af53ac1 100644
---- a/taglib/mpeg/mpegfile.cpp
-+++ b/taglib/mpeg/mpegfile.cpp
-@@ -203,15 +203,6 @@ bool MPEG::File::save(int tags, bool stripOthers, int id3v2Version)
-     return false;
-   }
- 
--  // Create the tags if we've been asked to.  Copy the values from the tag that
--  // does exist into the new tag, except if the existing tag is to be stripped.
--
--  if((tags & ID3v2) && ID3v1Tag() && !(stripOthers && !(tags & ID3v1)))
--    Tag::duplicate(ID3v1Tag(), ID3v2Tag(true), false);
--
--  if((tags & ID3v1) && d->tag[ID3v2Index] && !(stripOthers && !(tags & ID3v2)))
--    Tag::duplicate(ID3v2Tag(), ID3v1Tag(true), false);
--
-   bool success = true;
- 
-   if(ID3v2 & tags) {
-EOF
-
-if test "$libav_version" = "0.8.5"; then
+if test "$libav_version" = "0.8.7"; then
 test -f libav_sws.patch ||
 cat >libav_sws.patch <<"EOF"
 --- cmdutils.c.org      2011-09-17 13:36:43.000000000 -0700
@@ -399,54 +410,56 @@ cd ..
 
 # Extract and patch sources
 
-# zlib
+echo "### Extracting zlib"
 
-if ! test -d zlib-1.2.7; then
-tar xzf source/zlib_1.2.7.dfsg.orig.tar.gz
-cd zlib-1.2.7/
-tar xzf ../source/zlib_1.2.7.dfsg-13.debian.tar.gz || true
+if ! test -d zlib-1.2.8; then
+tar xzf source/zlib_1.2.8.dfsg.orig.tar.gz
+cd zlib-1.2.8/
+tar xzf ../source/zlib_1.2.8.dfsg-1.debian.tar.gz || true
 echo Can be ignored: Cannot create symlink to debian.series
 for f in $(cat debian/patches/debian.series); do patch -p1 <debian/patches/$f; done
 cd ..
 fi
 
-# libogg
+echo "### Extracting libogg"
 
-if ! test -d libogg-1.3.0; then
-tar xzf source/libogg_1.3.0.orig.tar.gz
-cd libogg-1.3.0/
-gunzip -c ../source/libogg_1.3.0-4.diff.gz | patch -p1
+if ! test -d libogg-1.3.1; then
+tar xzf source/libogg_1.3.1.orig.tar.gz
+cd libogg-1.3.1/
+gunzip -c ../source/libogg_1.3.1-1.diff.gz | patch -p1
 cd ..
 fi
 
-# libvorbis
+echo "### Extracting libvorbis"
 
 if ! test -d libvorbis-1.3.2; then
 tar xzf source/libvorbis_1.3.2.orig.tar.gz
 cd libvorbis-1.3.2/
 gunzip -c ../source/libvorbis_1.3.2-1.3.diff.gz | patch -p1
 test -f win32/VS2008/libogg.vsprops.orig || mv win32/VS2008/libogg.vsprops win32/VS2008/libogg.vsprops.orig
-sed 's/Value="1.1.4"/Value="1.3.0"/' win32/VS2008/libogg.vsprops.orig >win32/VS2008/libogg.vsprops
+sed "s/Value=\"1.1.4\"/Value=\"$libogg_version\"/" win32/VS2008/libogg.vsprops.orig >win32/VS2008/libogg.vsprops
 cd ..
 fi
 
-# libflac
+echo "### Extracting libflac"
 
-if ! test -d flac-1.2.1; then
-tar xzf source/flac_1.2.1.orig.tar.gz
-cd flac-1.2.1/
-gunzip -c ../source/flac_1.2.1-6.diff.gz | patch -p1
+if ! test -d flac-1.3.0; then
+unxz -c source/flac_1.3.0.orig.tar.xz | tar x
+cd flac-1.3.0/
+tar xzf ../source/flac_1.3.0-2.debian.tar.gz
 for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
 patch -p1 <../source/flac_1.2.1_size_t_max_patch.diff
 if test $kernel = "Darwin"; then
 patch -p1 <../source/fink_flac.patch
+if test "$ARCH" != "i386"; then
 patch -p0 <patches/ltmain.sh.patch
+fi
 patch -p0 <patches/nasm.h.patch
 fi
 cd ..
 fi
 
-# id3lib
+echo "### Extracting id3lib"
 
 if ! test -d id3lib-3.8.3; then
 tar xzf source/id3lib3.8.3_3.8.3.orig.tar.gz
@@ -460,26 +473,22 @@ sed 's/-W3 -WX -GX/-W3 -EHsc/; s/-MD -D "WIN32" -D "_DEBUG"/-MDd -D "WIN32" -D "
 cd ..
 fi
 
-# taglib
+echo "### Extracting taglib"
 
-if ! test -d taglib-1.8; then
-tar xzf source/taglib_1.8.orig.tar.gz
-cd taglib-1.8/
-tar xzf ../source/taglib_1.8-1.debian.tar.gz
-for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
-patch -p1 <../source/taglib-xm-file-save.patch
+if ! test -d taglib-1.9; then
+tar xzf source/taglib-1.9.tar.gz
+cd taglib-1.9/
 patch -p1 <../source/taglib-msvc.patch
-patch -p1 <../source/taglib-no-id3-duplication.patch
 cd ..
 fi
 
-# libav
+echo "### Extracting libav"
 
-if test "$libav_version" = "0.8.5"; then
-if ! test -d libav-0.8.5; then
-tar xzf source/libav_0.8.5.orig.tar.gz
-cd libav-0.8.5/
-tar xzf ../source/libav_0.8.5-1.debian.tar.gz
+if test "$libav_version" = "0.8.7"; then
+if ! test -d libav-0.8.7; then
+unxz -c source/libav_0.8.7.orig.tar.xz | tar x
+cd libav-0.8.7/
+tar xzf ../source/libav_0.8.7-1.debian.tar.gz
 oldifs=$IFS
 IFS='
 '
@@ -493,27 +502,27 @@ patch -p0 <../source/libav_sws.patch
 cd ..
 fi
 else
-if ! test -d libav-9.1; then
-unxz -c source/libav_9.1.orig.tar.xz | tar x
-cd libav-9.1/
-tar xzf ../source/libav_9.1-3.debian.tar.gz
+if ! test -d libav-9.9; then
+unxz -c source/libav_9.9.orig.tar.xz | tar x
+cd libav-9.9/
+tar xzf ../source/libav_9.9-1.debian.tar.gz
 for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
 cd ..
 fi
 fi
 
-# chromaprint
+echo "### Extracting chromaprint"
 
 if ! test -d chromaprint-0.7; then
 tar xzf source/chromaprint_0.7.orig.tar.gz
 cd chromaprint-0.7/
-tar xzf ../source/chromaprint_0.7-1.debian.tar.gz
+tar xzf ../source/chromaprint_0.7-2.debian.tar.gz
 for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
 cd ..
 fi
 
-# mp4v2
-
+#echo "### Extracting mp4v2"
+#
 #if ! test -d mp4v2-1.9.1+svn479~dfsg0; then
 #tar xjf source/mp4v2_1.9.1+svn479~dfsg0.orig.tar.bz2
 #cd mp4v2-1.9.1+svn479~dfsg0/
@@ -528,9 +537,9 @@ test -d bin || mkdir bin
 
 if test "$compiler" = "msvc"; then
 
-# libogg
+echo "### Building libogg"
 
-cd libogg-1.3.0/
+cd libogg-1.3.1/
 $COMSPEC /c "\"\"%VS90COMNTOOLS%vsvars32.bat\"\" && msbuild win32\VS2008\libogg_static.sln /p:Configuration=Debug;Platform=Win32"
 $COMSPEC /c "\"\"%VS90COMNTOOLS%vsvars32.bat\"\" && msbuild win32\VS2008\libogg_static.sln /p:Configuration=Release;Platform=Win32"
 mkdir -p inst/include/ogg inst/lib/Debug inst/lib/Release
@@ -538,10 +547,10 @@ cp win32/VS2008/Win32/Debug/libogg_static.lib inst/lib/Debug/
 cp win32/VS2008/Win32/Release/libogg_static.lib inst/lib/Release/
 cp include/ogg/*.h inst/include/ogg/
 cd inst
-tar czf ../../bin/libogg-1.3.0.tgz include lib
+tar czf ../../bin/libogg-1.3.1.tgz include lib
 cd ../..
 
-# libvorbis
+echo "### Building libvorbis"
 
 cd libvorbis-1.3.2/
 $COMSPEC /c "\"\"%VS90COMNTOOLS%vsvars32.bat\"\" && msbuild win32\VS2008\vorbis_static.sln /p:Configuration=Debug;Platform=Win32"
@@ -554,7 +563,7 @@ cd inst
 tar czf ../../bin/libvorbis-1.3.2.tgz include lib
 cd ../..
 
-# id3lib
+echo "### Building id3lib"
 
 cd id3lib-3.8.3/
 test -f config.h || cp config.h.win32 config.h
@@ -568,9 +577,9 @@ cd inst
 tar czf ../../bin/id3lib-3.8.3.tgz include lib
 cd ../..
 
-# taglib
+echo "### Building taglib"
 
-cd taglib-1.8/
+cd taglib-1.9/
 test -f taglib.sln || cmake -G "Visual Studio 9 2008" -DWITH_ASF=ON -DWITH_MP4=ON -DENABLE_STATIC=ON -DCMAKE_INSTALL_PREFIX=
 mkdir -p instd
 DESTDIR=instd cmake --build . --config Debug --target install
@@ -582,10 +591,10 @@ mkdir -p inst/lib
 mv inst/Debug inst/Release inst/lib/
 rm -rf instd
 cd inst
-tar czf ../../bin/taglib-1.8.tgz include lib
+tar czf ../../bin/taglib-1.9.tgz include lib
 cd ../..
 
-# Install to root directory
+echo "### Installing to root directory"
 
 BUILDROOT=../libs-msvc
 test -d $BUILDROOT || mkdir $BUILDROOT
@@ -595,37 +604,44 @@ done
 
 else
 
-# zlib
+echo "### Building zlib"
 
-cd zlib-1.2.7/
+cd zlib-1.2.8/
 if test $kernel = "MINGW"; then
 make -f win32/Makefile.gcc
 make install -f win32/Makefile.gcc INCLUDE_PATH=`pwd`/inst/usr/local/include LIBRARY_PATH=`pwd`/inst/usr/local/lib BINARY_PATH=`pwd`/inst/usr/local/bin
+elif test "$compiler" = "cross-mingw"; then
+make -f win32/Makefile.gcc PREFIX=i586-mingw32msvc-
+make install -f win32/Makefile.gcc INCLUDE_PATH=`pwd`/inst/usr/local/include LIBRARY_PATH=`pwd`/inst/usr/local/lib BINARY_PATH=`pwd`/inst/usr/local/bin
 else
-CFLAGS="-O3 -Wall -DNO_FSEEKO" ./configure --static
+CFLAGS="$CFLAGS -O3 -Wall -DNO_FSEEKO" ./configure --static
 sed 's/LIBS=$(STATICLIB) $(SHAREDLIB) $(SHAREDLIBV)/LIBS=$(STATICLIB)/' Makefile >Makefile.inst
 mkdir -p inst/usr/local
 make install -f Makefile.inst prefix=`pwd`/inst/usr/local
 fi
 cd inst
-tar czf ../../bin/zlib-1.2.7.tgz usr
+tar czf ../../bin/zlib-1.2.8.tgz usr
 cd ../..
 
-# libogg
+echo "### Building libogg"
 
-cd libogg-1.3.0/
-test -f Makefile || ./configure --enable-shared=no --enable-static=yes $ENABLE_DEBUG
+cd libogg-1.3.1/
+test -f Makefile || ./configure --enable-shared=no --enable-static=yes $ENABLE_DEBUG $CONFIGURE_OPTIONS
 make
 mkdir -p inst
 make install DESTDIR=`pwd`/inst
 cd inst
-tar czf ../../bin/libogg-1.3.0.tgz usr
+tar czf ../../bin/libogg-1.3.1.tgz usr
 cd ../..
 
-# libvorbis
+echo "### Building libvorbis"
 
 cd libvorbis-1.3.2/
-test -f Makefile || ./configure --enable-shared=no --enable-static=yes --with-ogg=$thisdir/libogg-1.3.0/inst/usr/local $ENABLE_DEBUG
+if test "$compiler" = "cross-mingw"; then
+test -f Makefile || PKG_CONFIG= ./configure --enable-shared=no --enable-static=yes --with-ogg=$thisdir/libogg-$libogg_version/inst/usr/local $ENABLE_DEBUG $CONFIGURE_OPTIONS
+else
+test -f Makefile || ./configure --enable-shared=no --enable-static=yes --with-ogg=$thisdir/libogg-$libogg_version/inst/usr/local $ENABLE_DEBUG $CONFIGURE_OPTIONS
+fi
 make
 mkdir -p inst
 make install DESTDIR=`pwd`/inst
@@ -633,10 +649,10 @@ cd inst
 tar czf ../../bin/libvorbis-1.3.2.tgz usr
 cd ../..
 
-# libflac
+echo "### Building libflac"
 
-cd flac-1.2.1/
-configure_args="--enable-shared=no --enable-static=yes --with-ogg=$thisdir/libogg-1.3.0/inst/usr/local $ENABLE_DEBUG"
+cd flac-1.3.0/
+configure_args="--enable-shared=no --enable-static=yes --with-ogg=$thisdir/libogg-$libogg_version/inst/usr/local $ENABLE_DEBUG $CONFIGURE_OPTIONS"
 if test $kernel = "Darwin"; then
   configure_args="$configure_args --disable-asm-optimizations"
 fi
@@ -645,14 +661,14 @@ make
 mkdir -p inst
 make install DESTDIR=`pwd`/inst
 cd inst
-tar czf ../../bin/flac-1.2.1.tgz usr
+tar czf ../../bin/flac-1.3.0.tgz usr
 cd ../..
 
-# id3lib
+echo "### Building id3lib"
 
 cd id3lib-3.8.3/
 autoconf
-test -f Makefile || CPPFLAGS=-I/usr/local/include LDFLAGS=-L/usr/local/lib ./configure --enable-shared=no --enable-static=yes $ENABLE_DEBUG
+test -f Makefile || CPPFLAGS=-I/usr/local/include LDFLAGS=-L/usr/local/lib ./configure --enable-shared=no --enable-static=yes $ENABLE_DEBUG $CONFIGURE_OPTIONS
 SED=sed make
 mkdir -p inst
 make install DESTDIR=`pwd`/inst
@@ -660,22 +676,22 @@ cd inst
 tar czf ../../bin/id3lib-3.8.3.tgz usr
 cd ../..
 
-# taglib
+echo "### Building taglib"
 
-cd taglib-1.8/
-test -f Makefile || eval cmake -DWITH_ASF=ON -DWITH_MP4=ON -DINCLUDE_DIRECTORIES=/usr/local/include -DLINK_DIRECTORIES=/usr/local/lib -DENABLE_STATIC=ON -DCMAKE_VERBOSE_MAKEFILE=ON $CMAKE_BUILD_TYPE_DEBUG $CMAKE_OPTIONS
+cd taglib-1.9/
+test -f Makefile || eval cmake -DWITH_ASF=ON -DWITH_MP4=ON -DINCLUDE_DIRECTORIES=/usr/local/include -DLINK_DIRECTORIES=/usr/local/lib -DENABLE_STATIC=ON -DZLIB_ROOT=../zlib-$zlib_version/inst/usr/local $CMAKE_BUILD_TYPE_DEBUG $CMAKE_OPTIONS
 make
 mkdir -p inst
 make install DESTDIR=`pwd`/inst
 fixcmakeinst
 cd inst
-tar czf ../../bin/taglib-1.8.tgz usr
+tar czf ../../bin/taglib-1.9.tgz usr
 cd ../..
 
-# libav
+echo "### Building libav"
 
-if test "$libav_version" = "0.8.5"; then
-cd libav-0.8.5
+if test "$libav_version" = "0.8.7"; then
+cd libav-0.8.7
 # configure needs yasm and pr
 # On msys, make >= 3.81 is needed.
 # Most options taken from
@@ -684,6 +700,10 @@ cd libav-0.8.5
 # Later versions (tested with libav-HEAD-5d2be71) do not have
 # --enable-ffmpeg and additionally need --disable-mmx --disable-mmxext.
 # The two --disable-hwaccel were added for MinGW-builds GCC 4.7.2.
+if test "$compiler" = "cross-mingw"; then
+sed -i 's/^\(.*-Werror=missing-prototypes\)/#\1/' ./configure
+AV_CONFIGURE_OPTIONS="--cross-prefix=i586-mingw32msvc- --arch=x86 --target-os=mingw32 --sysinclude=/usr/i586-mingw32msvc/include"
+fi
 ./configure \
 	--enable-memalign-hack \
 	--disable-shared \
@@ -761,15 +781,15 @@ cd libav-0.8.5
 	--enable-decoder=pcm_u24le \
 	--enable-decoder=rawvideo \
 	--disable-hwaccel=h264_dxva2 \
-	--disable-hwaccel=mpeg2_dxva2
+	--disable-hwaccel=mpeg2_dxva2 $AV_CONFIGURE_OPTIONS
 make
 mkdir -p inst
 make install DESTDIR=`pwd`/inst
 cd inst
-tar czf ../../bin/libav-0.8.5.tgz usr
+tar czf ../../bin/libav-0.8.7.tgz usr
 cd ../..
 else
-cd libav-9.1
+cd libav-9.9
 # configure needs yasm and pr
 # On msys, make >= 3.81 is needed.
 # Most options taken from
@@ -778,6 +798,10 @@ cd libav-9.1
 # Later versions (tested with libav-HEAD-5d2be71) do not have
 # --enable-ffmpeg and additionally need --disable-mmx --disable-mmxext.
 # The two --disable-hwaccel were added for MinGW-builds GCC 4.7.2.
+if test "$compiler" = "cross-mingw"; then
+sed -i 's/^\(.*-Werror=missing-prototypes\)/#\1/' ./configure
+AV_CONFIGURE_OPTIONS="--cross-prefix=i586-mingw32msvc- --arch=x86 --target-os=mingw32 --sysinclude=/usr/i586-mingw32msvc/include"
+fi
 ./configure \
 	--enable-memalign-hack \
 	--disable-shared \
@@ -854,20 +878,20 @@ cd libav-9.1
 	--enable-decoder=pcm_u24le \
 	--enable-decoder=rawvideo \
 	--disable-hwaccel=h264_dxva2 \
-	--disable-hwaccel=mpeg2_dxva2
+	--disable-hwaccel=mpeg2_dxva2 $AV_CONFIGURE_OPTIONS
 make
 mkdir -p inst
 make install DESTDIR=`pwd`/inst
 cd inst
-tar czf ../../bin/libav-9.1.tgz usr
+tar czf ../../bin/libav-9.9.tgz usr
 cd ../..
 fi
 
-# chromaprint
+echo "### Building chromaprint"
 
 # The zlib library path was added for MinGW-builds GCC 4.7.2.
 cd chromaprint-0.7/
-test -f Makefile || eval cmake -DBUILD_EXAMPLES=ON -DBUILD_SHARED_LIBS=OFF -DEXTRA_LIBS=\"-L$thisdir/zlib-1.2.7/inst/usr/local/lib -lz\" -DFFMPEG_ROOT=$thisdir/libav-$libav_version/inst/usr/local $CMAKE_BUILD_TYPE_DEBUG $CMAKE_OPTIONS
+test -f Makefile || eval cmake -DBUILD_EXAMPLES=ON -DBUILD_SHARED_LIBS=OFF -DEXTRA_LIBS=\"-L$thisdir/zlib-$zlib_version/inst/usr/local/lib -lz\" -DFFMPEG_ROOT=$thisdir/libav-$libav_version/inst/usr/local $CMAKE_BUILD_TYPE_DEBUG $CMAKE_OPTIONS
 mkdir -p inst
 make install DESTDIR=`pwd`/inst
 fixcmakeinst
@@ -875,10 +899,10 @@ cd inst
 tar czf ../../bin/chromaprint-0.7.tgz usr
 cd ../..
 
-# mp4v2
-
+#echo "### Building mp4v2"
+#
 #cd mp4v2-1.9.1+svn479~dfsg0/
-#test -f Makefile || ./configure --enable-shared=no --enable-static=yes --disable-gch
+#test -f Makefile || ./configure --enable-shared=no --enable-static=yes --disable-gch $CONFIGURE_OPTIONS
 #mkdir inst
 #make install DESTDIR=`pwd`/inst
 #cd inst
@@ -886,7 +910,7 @@ cd ../..
 #cd ../..
 
 
-# Install to root directory
+echo "### Installing to root directory"
 
 BUILDROOT=/
 if test $kernel = "Linux"; then
@@ -895,23 +919,61 @@ if test $kernel = "Linux"; then
   # Static build can be tested from Linux in kid3 directory
   if ! test -d kid3; then
     mkdir kid3
-    cat >kid3/build.sh <<"EOF"
+    if test "$compiler" = "cross-mingw"; then
+      cat >kid3/build.sh <<EOF
+cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo -DCMAKE_TOOLCHAIN_FILE=$thisdir/source/mingw.cmake -DCMAKE_INSTALL_PREFIX= -DWITH_FFMPEG=ON -DDOCBOOK_XSL_DIR=/usr/share/xml/docbook/stylesheet/nwalsh ../../kid3
+EOF
+      cat >kid3/make_package.sh <<"EOF"
+#!/bin/sh
+VERSION=$(grep VERSION config.h | cut -d'"' -f2)
+INSTDIR=kid3-$VERSION-win32
+QT_PREFIX=$(sed "s/set(QT_PREFIX \(.*\))/\1/;q" ../source/mingw.cmake)
+QT_BIN_DIR=${QT_PREFIX}bin
+QT_TRANSLATIONS_DIR=${QT_PREFIX}translations
+MINGW_DIR=/windows/msys/1.0/mingw/bin
+
+make install/strip DESTDIR=$(pwd)/$INSTDIR
+echo "### Ignore make error"
+
+cp -f po/*.qm doc/*/kid3*.html $INSTDIR
+
+for f in QtCore4.dll QtNetwork4.dll QtGui4.dll QtXml4.dll phonon4.dll; do
+  cp $QT_BIN_DIR/$f $INSTDIR
+done
+
+for f in libgcc_s_dw2-1.dll; do
+  cp $MINGW_DIR/$f $INSTDIR
+done
+
+for f in po/*.qm; do
+  l=${f#*_};
+  l=${l%.qm};
+  test -f $QT_TRANSLATIONS_DIR/qt_$l.qm && cp $QT_TRANSLATIONS_DIR/qt_$l.qm $INSTDIR
+done
+
+rm -f $INSTDIR.zip
+7z a $INSTDIR.zip $INSTDIR
+EOF
+      chmod +x kid3/make_package.sh
+    else
+      cat >kid3/build.sh <<"EOF"
 BUILDPREFIX=$(cd ..; pwd)/buildroot/usr/local
 export PKG_CONFIG_PATH=$BUILDPREFIX/lib/pkgconfig
-cmake -DWITH_TAGLIB=OFF -DHAVE_TAGLIB=1 -DTAGLIB_LIBRARIES:STRING="-L$BUILDPREFIX/lib -ltag" -DTAGLIB_CFLAGS:STRING="-I$BUILDPREFIX/include/taglib -DTAGLIB_STATIC" -DCMAKE_CXX_FLAGS_DEBUG:STRING="-g -DID3LIB_LINKOPTION=1 -DFLAC__NO_DLL" -DCMAKE_INCLUDE_PATH=$BUILDPREFIX/include -DCMAKE_LIBRARY_PATH=$BUILDPREFIX/lib -DCMAKE_PROGRAM_PATH=$BUILDPREFIX/bin -DFFMPEG_ROOT=$BUILDPREFIX -DCMAKE_BUILD_TYPE=Debug -DWITH_GCC_PCH=OFF -DWITH_KDE=OFF -DCMAKE_INSTALL_PREFIX= -DWITH_BINDIR=. -DWITH_DATAROOTDIR=. -DWITH_DOCDIR=. -DWITH_TRANSLATIONSDIR=. ../../kid3
+cmake -DWITH_TAGLIB=OFF -DHAVE_TAGLIB=1 -DTAGLIB_LIBRARIES:STRING="-L$BUILDPREFIX/lib -ltag" -DTAGLIB_CFLAGS:STRING="-I$BUILDPREFIX/include/taglib -I$BUILDPREFIX/include -DTAGLIB_STATIC" -DCMAKE_CXX_FLAGS_DEBUG:STRING="-g -DID3LIB_LINKOPTION=1 -DFLAC__NO_DLL" -DCMAKE_INCLUDE_PATH=$BUILDPREFIX/include -DCMAKE_LIBRARY_PATH=$BUILDPREFIX/lib -DCMAKE_PROGRAM_PATH=$BUILDPREFIX/bin -DWITH_FFMPEG=ON -DFFMPEG_ROOT=$BUILDPREFIX -DCMAKE_BUILD_TYPE=Debug -DBUILD_SHARED_LIBS=OFF -DWITH_GCC_PCH=OFF -DWITH_APPS="Qt;CLI" -DCMAKE_INSTALL_PREFIX= -DWITH_BINDIR=. -DWITH_DATAROOTDIR=. -DWITH_DOCDIR=. -DWITH_TRANSLATIONSDIR=. ../../kid3
 EOF
+    fi
     chmod +x kid3/build.sh
   fi
 elif test $kernel = "Darwin"; then
   sudo chmod go+w ${BUILDROOT}usr/local
 fi
 
-tar xzf bin/zlib-1.2.7.tgz -C $BUILDROOT
-tar xzf bin/libogg-1.3.0.tgz -C $BUILDROOT
+tar xzf bin/zlib-${zlib_version}.tgz -C $BUILDROOT
+tar xzf bin/libogg-${libogg_version}.tgz -C $BUILDROOT
 tar xzf bin/libvorbis-1.3.2.tgz -C $BUILDROOT
-tar xzf bin/flac-1.2.1.tgz -C $BUILDROOT
+tar xzf bin/flac-1.3.0.tgz -C $BUILDROOT
 tar xzf bin/id3lib-3.8.3.tgz -C $BUILDROOT
-tar xzf bin/taglib-1.8.tgz -C $BUILDROOT
+tar xzf bin/taglib-1.9.tgz -C $BUILDROOT
 tar xzf bin/libav-${libav_version}.tgz -C $BUILDROOT
 tar xzf bin/chromaprint-0.7.tgz -C $BUILDROOT
 #tar xzf bin/mp4v2-1.9.1+svn479.tgz -C $BUILDROOT
@@ -922,4 +984,4 @@ fi
 
 fi
 
-echo "Built successfully."
+echo "### Built successfully"
