@@ -2,8 +2,8 @@
 
 BASEDIR="../src" # root of translatable sources
 PROJECT="kid3" # project name
-PROJECTVERSION="2.2" # project version
-BUGADDR="http://sourceforge.net/tracker/?group_id=70849&atid=529221" # MSGID-Bugs
+PROJECTVERSION="3.0.2" # project version
+BUGADDR="http://sourceforge.net/p/kid3/bugs/" # MSGID-Bugs
 WDIR=`pwd` # working dir
 
 echo "Preparing rc files"
@@ -11,13 +11,6 @@ cd ${BASEDIR}
 # we use simple sorting to make sure the lines do not jump around too much from system to system
 find . -name '*.rc' -o -name '*.ui' -o -name '*.kcfg' | sort > ${WDIR}/rcfiles.list
 xargs --arg-file=${WDIR}/rcfiles.list extractrc > ${WDIR}/rc.cpp
-# additional string for KDE 4 KAboutData
-echo 'i18nc("NAME OF TRANSLATORS","Your names");' >> ${WDIR}/rc.cpp
-echo 'i18nc("EMAIL OF TRANSLATORS","Your emails");' >> ${WDIR}/rc.cpp
-# additional string for KDE 3 KAboutData (using printf because echo with back slashes
-# behaves differently in bash and dash)
-printf 'i18n("_: NAME OF TRANSLATORS\\nYour names");\n' >> ${WDIR}/rc.cpp
-printf 'i18n("_: EMAIL OF TRANSLATORS\\nYour emails");\n' >> ${WDIR}/rc.cpp
 cd ${WDIR}
 echo "Done preparing rc files"
 
@@ -28,8 +21,8 @@ cd ${BASEDIR}
 find . -name '*.cpp' -o -name '*.h' -o -name '*.c' -o -name '*.hpp' | sort > ${WDIR}/infiles.list
 echo "rc.cpp" >> ${WDIR}/infiles.list
 cd ${WDIR}
-xgettext --from-code=UTF-8 -C --kde -ci18n -ki18n:1 -ki18nc:1c,2 -ki18np:1,2 -ki18ncp:1c,2,3 -ktr2i18n:1 \
-  -kI18N_NOOP:1 -kI18N_NOOP2:1c,2 -kaliasLocale -kki18n:1 -kki18nc:1c,2 -kki18np:1,2 -kki18ncp:1c,2,3 \
+xgettext --from-code=UTF-8 -C --qt --no-location -ci18n -ktr:1,1t -ktr:1,2c,2t -ktr:1,1,2c,3t \
+  -kQT_TRANSLATE_NOOP:1,1t -kQT_TRANSLATE_NOOP:2,2t \
   --msgid-bugs-address="${BUGADDR}" \
   --package-name="${PROJECT^}" \
   --package-version="${PROJECTVERSION}" \
