@@ -35,15 +35,12 @@
 /**
  * Filter configuration.
  */
-class KID3_CORE_EXPORT FilterConfig : public GeneralConfig {
+class KID3_CORE_EXPORT FilterConfig : public StoredConfig<FilterConfig> {
 public:
   /**
    * Constructor.
-   * Set default configuration.
-   *
-   * @param grp configuration group
    */
-  FilterConfig(const QString& grp);
+  FilterConfig();
 
   /**
    * Destructor.
@@ -55,14 +52,14 @@ public:
    *
    * @param config KDE configuration
    */
-  virtual void writeToConfig(Kid3Settings* config) const;
+  virtual void writeToConfig(ISettings* config) const;
 
   /**
    * Read persisted configuration.
    *
    * @param config KDE configuration
    */
-  virtual void readFromConfig(Kid3Settings* config);
+  virtual void readFromConfig(ISettings* config);
 
   /**
    * Set the filename format in the "Filename Tag Mismatch" filter.
@@ -79,6 +76,9 @@ public:
   int m_filterIdx;
   /** Window geometry */
   QByteArray m_windowGeometry;
+
+  /** Index in configuration storage */
+  static int s_index;
 };
 
 #endif
