@@ -36,15 +36,12 @@
 /**
  * Import configuration.
  */
-class ImportConfig : public GeneralConfig {
+class KID3_CORE_EXPORT ImportConfig : public StoredConfig<ImportConfig> {
 public:
   /**
    * Constructor.
-   * Set default configuration.
-   *
-   * @param grp configuration group
    */
-  ImportConfig(const QString& grp);
+  ImportConfig();
 
   /**
    * Destructor.
@@ -54,16 +51,30 @@ public:
   /**
    * Persist configuration.
    *
-   * @param config KDE configuration
+   * @param config configuration
    */
-  virtual void writeToConfig(Kid3Settings* config) const;
+  virtual void writeToConfig(ISettings* config) const;
 
   /**
    * Read persisted configuration.
    *
-   * @param config KDE configuration
+   * @param config configuration
    */
-  virtual void readFromConfig(Kid3Settings* config);
+  virtual void readFromConfig(ISettings* config);
+
+  /**
+   * Access to list of available plugins.
+   * @return available plugins.
+   * @remark This information is not stored in the configuration, it is
+   * determined when the plugins are loaded.
+   */
+  QStringList& availablePlugins() { return m_availablePlugins; }
+
+  /**
+   * Get list of available plugins.
+   * @return available plugins.
+   */
+  QStringList getAvailablePlugins() const { return m_availablePlugins; }
 
   /** import server */
   int m_importServer;
@@ -95,21 +106,6 @@ public:
   /** selected import tags format */
   int m_importTagsIdx;
 
-  /** Tag1 to export ID3v1 tags, Tag2 for ID3v2 tags */
-  TrackData::TagVersion m_exportSrcV1;
-  /** Names of export formats */
-  QStringList m_exportFormatNames;
-  /** regexp describing header export format */
-  QStringList m_exportFormatHeaders;
-  /** regexp describing track export format */
-  QStringList m_exportFormatTracks;
-  /** regexp describing trailer export format */
-  QStringList m_exportFormatTrailers;
-  /** selected export format */
-  int m_exportFormatIdx;
-  /** export window geometry */
-  QByteArray m_exportWindowGeometry;
-
   /** names of picture sources */
   QStringList m_pictureSourceNames;
   /** picture source URLs */
@@ -123,6 +119,15 @@ public:
 
   /** Last directory used for import or export. */
   QString m_importDir;
+
+  /** Disabled plugins */
+  QStringList m_disabledPlugins;
+
+  /** Index in configuration storage */
+  static int s_index;
+
+private:
+  QStringList m_availablePlugins;
 };
 
 #endif
