@@ -35,7 +35,7 @@
 /**
  * Playlist configuration.
  */
-class KID3_CORE_EXPORT PlaylistConfig : public GeneralConfig {
+class KID3_CORE_EXPORT PlaylistConfig : public StoredConfig<PlaylistConfig> {
 public:
   /**
    * Playlist format.
@@ -57,11 +57,8 @@ public:
 
   /**
    * Constructor.
-   * Set default configuration.
-   *
-   * @param grp configuration group
    */
-  PlaylistConfig(const QString& grp = QLatin1String("Playlist"));
+  explicit PlaylistConfig();
 
   /**
    * Destructor.
@@ -73,14 +70,14 @@ public:
    *
    * @param config KDE configuration
    */
-  virtual void writeToConfig(Kid3Settings* config) const;
+  virtual void writeToConfig(ISettings* config) const;
 
   /**
    * Read persisted configuration.
    *
    * @param config KDE configuration
    */
-  virtual void readFromConfig(Kid3Settings* config);
+  virtual void readFromConfig(ISettings* config);
 
   /** Use file name format if true, else directory name */
   bool m_useFileNameFormat;
@@ -102,6 +99,9 @@ public:
   QString m_sortTagField;
   /** Format for additional information */
   QString m_infoFormat;
+
+  /** Index in configuration storage */
+  static int s_index;
 };
 
 #endif // PLAYLISTCONFIG_H
