@@ -41,11 +41,8 @@ public:
    * Set default configuration.
    *
    * @param grp         configuration group
-   * @param cgiPathUsed true to use CgiPath configuration
-   * @param additionalTagsUsed true to use AdditionalTags configuration
    */
-  ServerImporterConfig(const QString& grp, bool cgiPathUsed = true,
-                       bool additionalTagsUsed = false);
+  explicit ServerImporterConfig(const QString& grp);
 
   /**
    * Constructor.
@@ -63,14 +60,14 @@ public:
    *
    * @param config KDE configuration
    */
-  virtual void writeToConfig(Kid3Settings* config) const;
+  virtual void writeToConfig(ISettings* config) const;
 
   /**
    * Read persisted configuration.
    *
    * @param config KDE configuration
    */
-  virtual void readFromConfig(Kid3Settings* config);
+  virtual void readFromConfig(ISettings* config);
 
   /** server */
   QString m_server;
