@@ -188,9 +188,7 @@ QString PlaylistCreator::Item::formatString(const QString& format)
 {
   if (!m_trackData) {
     m_taggedFile->readTags(false);
-#if defined HAVE_ID3LIB && defined HAVE_TAGLIB
-    m_taggedFile = FileProxyModel::readWithTagLibIfId3V24(m_taggedFile);
-#endif
+    m_taggedFile = FileProxyModel::readWithId3V24IfId3V24(m_taggedFile);
     m_trackData = new ImportTrackData(*m_taggedFile, ImportTrackData::TagV2V1);
   }
   return m_trackData->formatString(format);
