@@ -29,7 +29,10 @@
 #include <QFileInfo>
 #include <QDir>
 #include <QTextStream>
-#include "configstore.h"
+#include <QApplication>
+#include <QClipboard>
+#include "exportconfig.h"
+#include "importconfig.h"
 
 /**
  * Constructor.
@@ -87,9 +90,9 @@ void TextExporter::updateText(
  */
 void TextExporter::updateTextUsingConfig(int fmtIdx)
 {
-  const QStringList& headerFmts = ConfigStore::s_genCfg.m_exportFormatHeaders;
-  const QStringList& trackFmts = ConfigStore::s_genCfg.m_exportFormatTracks;
-  const QStringList& trailerFmts = ConfigStore::s_genCfg.m_exportFormatTrailers;
+  const QStringList& headerFmts = ExportConfig::instance().m_exportFormatHeaders;
+  const QStringList& trackFmts = ExportConfig::instance().m_exportFormatTracks;
+  const QStringList& trailerFmts = ExportConfig::instance().m_exportFormatTrailers;
   if (fmtIdx < headerFmts.size() && fmtIdx < trackFmts.size() &&
       fmtIdx < trailerFmts.size()) {
     updateText(headerFmts.at(fmtIdx), trackFmts.at(fmtIdx),
@@ -109,7 +112,7 @@ bool TextExporter::exportToFile(const QString& fn)
   if (!fn.isEmpty()) {
     QFile file(fn);
     if (file.open(QIODevice::WriteOnly)) {
-      ConfigStore::s_genCfg.m_importDir = QFileInfo(file).dir().path();
+      ImportConfig::instance().m_importDir = QFileInfo(file).dir().path();
       QTextStream stream(&file);
       stream << m_text;
       file.close();
@@ -118,3 +121,11 @@ bool TextExporter::exportToFile(const QString& fn)
   }
   return false;
 }
+
+/**
+ * Export to clipboard.
+ */
+void TextExporter::exportToClipboard()
+{
+  QApplication::clipboard()->setText(m_text, QClipboard::Clipboard);
+}
