@@ -96,6 +96,11 @@ public:
    */
   bool exportToFile(const QString& fn);
 
+  /**
+   * Export to clipboard.
+   */
+  void exportToClipboard();
+
 private:
   ImportTrackDataVector m_trackDataVector;
   QString m_text;
