@@ -29,8 +29,7 @@
 #include <QNetworkRequest>
 #include <QNetworkProxy>
 #include <QByteArray>
-#include "configstore.h"
-#include "qtcompatmac.h"
+#include "networkconfig.h"
 
 
 /** Time when last request was sent to server */
@@ -91,7 +90,7 @@ HttpClient::~HttpClient()
 }
 
 /** Only defined for generation of translation files */
-#define DATA_RECEIVED_FOR_PO I18N_NOOP("Data received: %1")
+#define DATA_RECEIVED_FOR_PO QT_TRANSLATE_NOOP("@default", "Data received: %1")
 
 /**
  * Called when the request is finished.
@@ -103,9 +102,9 @@ void HttpClient::networkReplyFinished()
     m_rcvBodyType = reply->header(QNetworkRequest::ContentTypeHeader).toString();
     m_rcvBodyLen = reply->header(QNetworkRequest::ContentLengthHeader).toUInt();
     emit bytesReceived(data);
-    QString msg(i18n("Ready."));
+    QString msg(tr("Ready."));
     if (reply->error() != QNetworkReply::NoError) {
-      msg = i18n("Error");
+      msg = tr("Error");
       msg += QLatin1String(": ");
       msg += reply->errorString();
     }
@@ -122,7 +121,7 @@ void HttpClient::networkReplyFinished()
  */
 void HttpClient::networkReplyProgress(qint64 received, qint64 total)
 {
-  emitProgress(i18n("Data received: %1").arg(received), received, total);
+  emitProgress(tr("Data received: %1").arg(received), received, total);
 }
 
 /**
@@ -177,13 +176,13 @@ void HttpClient::sendRequest(const QString& server, const QString& path,
   QString proxy, username, password;
   int proxyPort = 0;
   QNetworkProxy::ProxyType proxyType = QNetworkProxy::NoProxy;
-  if (ConfigStore::s_miscCfg.m_useProxy) {
-    splitNamePort(ConfigStore::s_miscCfg.m_proxy, proxy, proxyPort);
+  if (NetworkConfig::instance().m_useProxy) {
+    splitNamePort(NetworkConfig::instance().m_proxy, proxy, proxyPort);
     proxyType = QNetworkProxy::HttpProxy;
   }
-  if (ConfigStore::s_miscCfg.m_useProxyAuthentication) {
-    username = ConfigStore::s_miscCfg.m_proxyUserName;
-    password = ConfigStore::s_miscCfg.m_proxyPassword;
+  if (NetworkConfig::instance().m_useProxyAuthentication) {
+    username = NetworkConfig::instance().m_proxyUserName;
+    password = NetworkConfig::instance().m_proxyPassword;
   }
   m_netMgr->setProxy(QNetworkProxy(proxyType, proxy, proxyPort,
                                    username, password));
@@ -210,7 +209,7 @@ void HttpClient::sendRequest(const QString& server, const QString& path,
   connect(reply, SIGNAL(error(QNetworkReply::NetworkError)),
           this, SLOT(networkReplyError(QNetworkReply::NetworkError)));
   s_lastRequestTime[host] = now;
-  emitProgress(i18n("Request sent..."), 0, 0);
+  emitProgress(tr("Request sent..."), 0, 0);
 }
 
 /**
