@@ -194,9 +194,14 @@ QList<QHeaderView::ResizeMode>
  */
 void ConfigTableModel::setLabels(const QStringList& labels)
 {
+#if QT_VERSION >= 0x040600
   beginResetModel();
   m_labels = labels;
   endResetModel();
+#else
+  m_labels = labels;
+  reset();
+#endif
 }
 
 /**
@@ -206,7 +211,9 @@ void ConfigTableModel::setLabels(const QStringList& labels)
  */
 void ConfigTableModel::setMap(const QMap<QString, QString>& map)
 {
+#if QT_VERSION >= 0x040600
   beginResetModel();
+#endif
   m_keyValues.clear();
   for (QMap<QString, QString>::const_iterator it = map.constBegin();
       it != map.constEnd();
@@ -216,7 +223,11 @@ void ConfigTableModel::setMap(const QMap<QString, QString>& map)
   // make sure that at least one line is in the table
   if (m_keyValues.isEmpty())
     m_keyValues.append(qMakePair(QString(), QString()));
+#if QT_VERSION >= 0x040600
   endResetModel();
+#else
+  reset();
+#endif
 }
 
 /**
