@@ -30,6 +30,7 @@
 #include <QObject>
 #include <QString>
 #include "trackdata.h"
+#include "iabortable.h"
 #include "kid3api.h"
 
 class TaggedFile;
@@ -37,7 +38,8 @@ class TaggedFile;
 /**
  * Directory renamer.
  */
-class KID3_CORE_EXPORT DirRenamer : public QObject {
+class KID3_CORE_EXPORT DirRenamer : public QObject, public IAbortable {
+  Q_OBJECT
 public:
   /**
    * Constructor.
@@ -50,6 +52,23 @@ public:
    */
   virtual ~DirRenamer();
 
+  /**
+   * Check if operation is aborted.
+   *
+   * @return true if aborted.
+   */
+  virtual bool isAborted() const;
+
+  /**
+   * Clear state which is reported by isAborted().
+   */
+  virtual void clearAborted();
+
+  /**
+   * Abort operation.
+   */
+  virtual void abort();
+
   /**
    * Set version of tags used to get rename information.
    * @param tagVersion tag version
@@ -102,24 +121,6 @@ public:
    */
   void performActions(QString* errorMsg);
 
-  /**
-   * Get description of actions to be performed.
-   * @return list of (action, [src,] dst) lists describing the actions to be
-   * performed.
-   */
-  QList<QStringList> describeActions() const;
-
-  /**
-   * Check if dialog was aborted.
-   * @return true if aborted.
-   */
-  bool getAbortFlag() const { return m_aborted; }
-
-  /**
-   * Set abort flag.
-   */
-  void setAbortFlag() { m_aborted = true; }
-
   /**
    * Set directory name.
    * This should be done before calling performActions(), so that the directory
@@ -141,6 +142,14 @@ public:
    */
   QString getDirName() const { return m_dirName; }
 
+signals:
+  /**
+   * Is emitted after an action has been scheduled.
+   *
+   * @param actionStrs description of action
+   */
+  void actionScheduled(const QStringList& actionStrs);
+
 private:
   /**
    * An action performed while renaming a directory.
@@ -276,6 +285,13 @@ private:
    */
   void replaceIfAlreadyRenamed(QString& src) const;
 
+  /**
+   * Get description of an actions to be performed.
+   * @return (action, [src,] dst) list describing the action to be
+   * performed.
+   */
+  QStringList describeAction(const RenameAction& action) const;
+
   RenameActionList m_actions;
   bool m_aborted;
   TrackData::TagVersion m_tagVersion;
