@@ -25,8 +25,7 @@
  */
 
 #include "downloadclient.h"
-#include "configstore.h"
-#include "qtcompatmac.h"
+#include "importconfig.h"
 
 /**
  * Constructor.
@@ -36,8 +35,8 @@
 DownloadClient::DownloadClient(QNetworkAccessManager* netMgr) :
   HttpClient(netMgr), m_canceled(false)
 {
-  connect(this, SIGNAL(bytesReceived(const QByteArray&)),
-          this, SLOT(requestFinished(const QByteArray&)));
+  connect(this, SIGNAL(bytesReceived(QByteArray)),
+          this, SLOT(requestFinished(QByteArray)));
 }
 
 /**
@@ -60,7 +59,7 @@ void DownloadClient::startDownload(const QString& hostName, const QString& path)
   m_url += hostName;
   m_url += path;
   emit downloadStarted(m_url);
-  emit progress(i18n("Ready."), 0, 0);
+  emit progress(tr("Ready."), 0, 0);
   sendRequest(hostName, path);
 }
 
@@ -124,8 +123,8 @@ QString DownloadClient::getImageUrl(const QString& url)
     }
     else {
       for (QMap<QString, QString>::ConstIterator it =
-             ConfigStore::s_genCfg.m_matchPictureUrlMap.begin();
-           it != ConfigStore::s_genCfg.m_matchPictureUrlMap.end();
+             ImportConfig::instance().m_matchPictureUrlMap.begin();
+           it != ImportConfig::instance().m_matchPictureUrlMap.end();
            ++it) {
         QRegExp re(it.key());
         if (re.exactMatch(url)) {
