@@ -57,6 +57,24 @@ public:
    */
   void startDownload(const QString& hostName, const QString& path);
 
+  /**
+   * Send a download request.
+   *
+   * @param url URL of resource to download
+   */
+  void startDownload(const QString& url);
+
+  /**
+   * Get the URL of an image file.
+   * The input URL is transformed using the match picture URL table to
+   * get the URL of an image file.
+   *
+   * @param url URL from image drag
+   *
+   * @return URL of image file, empty if no image URL found.
+   */
+  static QString getImageUrl(const QString& url);
+
 public slots:
   /**
    * Cancel a download.
