@@ -27,13 +27,10 @@
 #include "fileproxymodel.h"
 #include <QFileSystemModel>
 #include "taggedfileiconprovider.h"
+#include "itaggedfilefactory.h"
 #include "config.h"
-#ifdef HAVE_ID3LIB
-#include "mp3file.h"
-#endif
-#ifdef HAVE_TAGLIB
-#include "taglibfile.h"
-#endif
+
+QList<ITaggedFileFactory*> FileProxyModel::s_taggedFileFactories;
 
 /**
  * Constructor.
@@ -44,7 +41,7 @@ FileProxyModel::FileProxyModel(QObject* parent) : QSortFilterProxyModel(parent),
   m_iconProvider(new TaggedFileIconProvider), m_fsModel(0)
 {
   setObjectName(QLatin1String("FileProxyModel"));
-  connect(this, SIGNAL(rowsInserted(QModelIndex, int, int)),
+  connect(this, SIGNAL(rowsInserted(QModelIndex,int,int)),
           this, SLOT(updateInsertedRows(QModelIndex,int,int)));
 }
 
@@ -113,6 +110,23 @@ bool FileProxyModel::rmdir(const QModelIndex& index) const
   return false;
 }
 
+/**
+ * Get index for given path and column.
+ * @param path path to file or directory
+ * @param column model column
+ * @return model index, invalid if not found.
+ */
+QModelIndex FileProxyModel::index(const QString& path, int column) const
+{
+  if (m_fsModel) {
+    QModelIndex sourceIndex = m_fsModel->index(path, column);
+    if (sourceIndex.isValid()) {
+      return mapFromSource(sourceIndex);
+    }
+  }
+  return QModelIndex();
+}
+
 /**
  * Update the TaggedFile contents for rows inserted into the model.
  * @param parent parent model index
@@ -264,7 +278,7 @@ void FileProxyModel::setNameFilters(const QStringList& filters)
 {
   QRegExp wildcardRe(QLatin1String("\\.\\w+"));
   QSet<QString> exts;
-  foreach (QString filter, filters) {
+  foreach (const QString& filter, filters) {
     int pos = 0;
     while ((pos = wildcardRe.indexIn(filter, pos)) != -1) {
       int len = wildcardRe.matchedLength();
@@ -382,7 +396,7 @@ void FileProxyModel::initTaggedFileData(const QModelIndex& index) {
     return;
 
   QFileInfo info = fileInfo(index);
-  dat.setValue(TaggedFile::createFile(info.path(), info.fileName(), index));
+  dat.setValue(createTaggedFile(info.path(), info.fileName(), index));
   setData(index, dat, TaggedFileRole);
 }
 
@@ -439,80 +453,135 @@ QString FileProxyModel::getPathIfIndexOfDir(const QModelIndex& index) {
   return model->filePath(index);
 }
 
-#if defined HAVE_ID3LIB && defined HAVE_TAGLIB
 /**
- * Read tagged file with TagLib.
+ * Read tagged file with ID3v2.4.0.
  *
  * @param taggedFile tagged file
  *
- * @return tagged file (can be new TagLibFile).
+ * @return tagged file (can be newly created tagged file).
  */
-TaggedFile* FileProxyModel::readWithTagLib(TaggedFile* taggedFile)
+TaggedFile* FileProxyModel::readWithId3V24(TaggedFile* taggedFile)
 {
   const QPersistentModelIndex& index = taggedFile->getIndex();
-  TagLibFile* tagLibFile = new TagLibFile(
-        taggedFile->getDirname(), taggedFile->getFilename(), index);
-  if (index.isValid()) {
-    QVariant data;
-    data.setValue(static_cast<TaggedFile*>(tagLibFile));
-    // setData() will not invalidate the model, so this should be safe.
-    QAbstractItemModel* setDataModel = const_cast<QAbstractItemModel*>(
-        index.model());
-    if (setDataModel) {
-      setDataModel->setData(index, data, FileProxyModel::TaggedFileRole);
+  if (TaggedFile* tagLibFile = createTaggedFile(TaggedFile::TF_ID3v24,
+          taggedFile->getDirname(), taggedFile->getFilename(), index)) {
+    if (index.isValid()) {
+      QVariant data;
+      data.setValue(tagLibFile);
+      // setData() will not invalidate the model, so this should be safe.
+      QAbstractItemModel* setDataModel = const_cast<QAbstractItemModel*>(
+          index.model());
+      if (setDataModel) {
+        setDataModel->setData(index, data, FileProxyModel::TaggedFileRole);
+      }
     }
+    taggedFile = tagLibFile;
+    taggedFile->readTags(false);
   }
-  taggedFile = tagLibFile;
-  taggedFile->readTags(false);
   return taggedFile;
 }
 
 /**
- * Read tagged file with id3lib.
+ * Create a tagged file with a given feature.
+ *
+ * @param feature tagged file feature
+ * @param dirName directory name
+ * @param fileName filename
+ * @param idx model index
+ *
+ * @return tagged file, 0 if feature not found or type not supported.
+ */
+TaggedFile* FileProxyModel::createTaggedFile(
+    TaggedFile::Feature feature,
+    const QString& dirName, const QString& fileName,
+    const QPersistentModelIndex& idx) {
+  TaggedFile* taggedFile = 0;
+  foreach (ITaggedFileFactory* factory, s_taggedFileFactories) {
+    foreach (const QString& key, factory->taggedFileKeys()) {
+      if ((factory->taggedFileFeatures(key) & feature) != 0 &&
+          (taggedFile = factory->createTaggedFile(key, dirName, fileName, idx,
+                                                  feature))
+          != 0) {
+        return taggedFile;
+      }
+    }
+  }
+  return 0;
+}
+
+/**
+ * Create a tagged file.
+ *
+ * @param dirName directory name
+ * @param fileName filename
+ * @param idx model index
+ *
+ * @return tagged file, 0 if not found or type not supported.
+ */
+TaggedFile* FileProxyModel::createTaggedFile(
+    const QString& dirName, const QString& fileName,
+    const QPersistentModelIndex& idx) {
+  TaggedFile* taggedFile = 0;
+  foreach (ITaggedFileFactory* factory, s_taggedFileFactories) {
+    foreach (const QString& key, factory->taggedFileKeys()) {
+      taggedFile = factory->createTaggedFile(key, dirName, fileName, idx);
+      if (taggedFile) {
+        return taggedFile;
+      }
+    }
+  }
+  return 0;
+}
+
+/**
+ * Read tagged file with ID3v2.3.0.
  *
  * @param taggedFile tagged file
  *
- * @return tagged file (can be new Mp3File).
+ * @return tagged file (can be newly created tagged file).
  */
-TaggedFile* FileProxyModel::readWithId3Lib(TaggedFile* taggedFile)
+TaggedFile* FileProxyModel::readWithId3V23(TaggedFile* taggedFile)
 {
   const QPersistentModelIndex& index = taggedFile->getIndex();
-  Mp3File* id3libFile = new Mp3File(
-        taggedFile->getDirname(), taggedFile->getFilename(), index);
-  if (index.isValid()) {
-    QVariant data;
-    data.setValue(static_cast<TaggedFile*>(id3libFile));
-    // setData() will not invalidate the model, so this should be safe.
-    QAbstractItemModel* setDataModel = const_cast<QAbstractItemModel*>(
-        index.model());
-    if (setDataModel) {
-      setDataModel->setData(index, data, FileProxyModel::TaggedFileRole);
+  if (TaggedFile* id3libFile = createTaggedFile(TaggedFile::TF_ID3v23,
+          taggedFile->getDirname(), taggedFile->getFilename(), index)) {
+    if (index.isValid()) {
+      QVariant data;
+      data.setValue(id3libFile);
+      // setData() will not invalidate the model, so this should be safe.
+      QAbstractItemModel* setDataModel = const_cast<QAbstractItemModel*>(
+          index.model());
+      if (setDataModel) {
+        setDataModel->setData(index, data, FileProxyModel::TaggedFileRole);
+      }
     }
+    taggedFile = id3libFile;
+    taggedFile->readTags(false);
   }
-  taggedFile = id3libFile;
-  taggedFile->readTags(false);
   return taggedFile;
 }
 
 /**
- * Read file with TagLib if it has an ID3v2.4 or ID3v2.2 tag.
- * ID3v2.2 files are also read with TagLib because id3lib corrupts
+ * Read file with ID3v2.4 if it has an ID3v2.4 or ID3v2.2 tag.
+ * ID3v2.2 files are also read with ID3v2.4 because id3lib corrupts
  * images in ID3v2.2 tags.
  *
  * @param taggedFile tagged file
  *
  * @return tagged file (can be new TagLibFile).
  */
-TaggedFile* FileProxyModel::readWithTagLibIfId3V24(TaggedFile* taggedFile)
+TaggedFile* FileProxyModel::readWithId3V24IfId3V24(TaggedFile* taggedFile)
 {
-  if (dynamic_cast<Mp3File*>(taggedFile) != 0 &&
+  if (taggedFile &&
+      (taggedFile->taggedFileFeatures() &
+       (TaggedFile::TF_ID3v23 | TaggedFile::TF_ID3v24)) ==
+        TaggedFile::TF_ID3v23 &&
       !taggedFile->isChanged() &&
       taggedFile->isTagInformationRead() && taggedFile->hasTagV2()) {
     QString id3v2Version = taggedFile->getTagFormatV2();
     if (id3v2Version.isNull() || id3v2Version == QLatin1String("ID3v2.2.0")) {
-      taggedFile = readWithTagLib(taggedFile);
+      taggedFile = readWithId3V24(taggedFile);
     }
   }
   return taggedFile;
 }
-#endif
