@@ -37,6 +37,7 @@
 
 class QFileSystemModel;
 class TaggedFileIconProvider;
+class ITaggedFileFactory;
 
 /**
  * Proxy for filesystem model which filters files.
@@ -171,6 +172,52 @@ public:
    */
   bool rmdir(const QModelIndex& index) const;
 
+  /**
+   * Get index for given path and column.
+   * @param path path to file or directory
+   * @param column model column
+   * @return model index, invalid if not found.
+   */
+  QModelIndex index(const QString& path, int column = 0) const;
+
+  using QSortFilterProxyModel::index;
+
+  /**
+   * Access to tagged file factories.
+   * @return reference to tagged file factories.
+   */
+  static QList<ITaggedFileFactory*>& taggedFileFactories() {
+    return s_taggedFileFactories;
+  }
+
+  /**
+   * Create a tagged file with a given feature.
+   *
+   * @param feature tagged file feature
+   * @param dirName directory name
+   * @param fileName filename
+   * @param idx model index
+   *
+   * @return tagged file, 0 if feature not found or type not supported.
+   */
+  static TaggedFile* createTaggedFile(
+      TaggedFile::Feature feature,
+      const QString& dirName, const QString& fileName,
+      const QPersistentModelIndex& idx);
+
+  /**
+   * Create a tagged file.
+   *
+   * @param dirName directory name
+   * @param fileName filename
+   * @param idx model index
+   *
+   * @return tagged file, 0 if not found or type not supported.
+   */
+  static TaggedFile* createTaggedFile(
+      const QString& dirName, const QString& fileName,
+      const QPersistentModelIndex& idx);
+
   /**
    * Get tagged file data of model index.
    *
@@ -202,31 +249,33 @@ public:
   static QString getPathIfIndexOfDir(const QModelIndex& index);
 
   /**
-   * Read tagged file with TagLib.
+   * Read tagged file with ID3v2.4.0.
+   *
+   * @param taggedFile tagged file
+   *
+   * @return tagged file (can be newly created tagged file).
+   */
+  static TaggedFile* readWithId3V24(TaggedFile* taggedFile);
+
+  /**
+   * Read tagged file with ID3v2.3.0.
+   *
+   * @param taggedFile tagged file
+   *
+   * @return tagged file (can be newly created tagged file).
+   */
+  static TaggedFile* readWithId3V23(TaggedFile* taggedFile);
+
+  /**
+   * Read file with ID3v2.4 if it has an ID3v2.4 or ID3v2.2 tag.
+   * ID3v2.2 files are also read with ID3v2.4 because id3lib corrupts
+   * images in ID3v2.2 tags.
    *
    * @param taggedFile tagged file
    *
    * @return tagged file (can be new TagLibFile).
    */
-  static TaggedFile* readWithTagLib(TaggedFile* taggedFile);
-
-  /**
-   * Read tagged file with id3lib.
-   *
-   * @param taggedFile tagged file
-   *
-   * @return tagged file (can be new Mp3File).
-   */
-  static TaggedFile* readWithId3Lib(TaggedFile* taggedFile);
-
-  /**
-   * Read file with TagLib if it has an ID3v2.4 tag.
-   *
-   * @param taggedFile tagged file
-   *
-   * @return tagged file (can be new TagLibFile).
-   */
-  static TaggedFile* readWithTagLibIfId3V24(TaggedFile* taggedFile);
+  static TaggedFile* readWithId3V24IfId3V24(TaggedFile* taggedFile);
 
 signals:
 #if QT_VERSION >= 0x040700
@@ -292,6 +341,8 @@ private:
   TaggedFileIconProvider* m_iconProvider;
   QFileSystemModel* m_fsModel;
   QStringList m_extensions;
+
+  static QList<ITaggedFileFactory*> s_taggedFileFactories;
 };
 
 Q_DECLARE_METATYPE(TaggedFile*)
