@@ -27,9 +27,10 @@
 #include "frametablemodel.h"
 #include <QApplication>
 #include <QComboBox>
-#include "configstore.h"
+#include "fileconfig.h"
+#include "tagconfig.h"
+#include "formatconfig.h"
 #include "genres.h"
-#include "qtcompatmac.h"
 
 /**
  * Constructor.
@@ -85,11 +86,11 @@ QString FrameTableModel::getDisplayName(const QString& str)
       // probably "TXXX - User defined text information\nDescription" or
       // "WXXX - User defined URL link\nDescription"
       return str.mid(nlPos + 1);
-    } else if (str.mid(4, 3) == QLatin1String(" - ")) {
+    } else if (str.midRef(4, 3) == QLatin1String(" - ")) {
       // probably "ID3-ID - Description"
       return str.left(4);
     } else {
-      return QCM_translate(str.toLatin1().data());
+      return QCoreApplication::translate("@default", str.toLatin1().data());
     }
   }
   return str;
@@ -117,7 +118,7 @@ QVariant FrameTableModel::data(const QModelIndex& index, int role) const
     return m_frameSelected.at(index.row()) ? Qt::Checked : Qt::Unchecked;
   } else if (role == Qt::BackgroundColorRole) {
     if (index.column() == CI_Enable) {
-      return ConfigStore::s_miscCfg.m_markChanges &&
+      return FileConfig::instance().m_markChanges &&
         (it->isValueChanged() ||
         (static_cast<unsigned>((*it).getType()) < sizeof(m_changedFrames) * 8 &&
          (m_changedFrames & (1ULL << (*it).getType())) != 0))
@@ -188,7 +189,7 @@ QVariant FrameTableModel::headerData(
   if (role != Qt::DisplayRole)
     return QVariant();
   if (orientation == Qt::Horizontal) {
-    return section == CI_Enable ? i18n("Name") : i18n("Data");
+    return section == CI_Enable ? tr("Name") : tr("Data");
   }
   return section + 1;
 }
@@ -500,6 +501,22 @@ void FrameTableModel::deselectAllFrames()
   setAllCheckStates(false);
 }
 
+/**
+ * Select changed frames in the table.
+ */
+void FrameTableModel::selectChangedFrames()
+{
+  int row;
+  FrameCollection::const_iterator it;
+  for (row = 0, it = m_frames.begin();
+       row < m_frameSelected.size() && it != m_frames.end();
+       ++row, ++it) {
+    if (it->isValueChanged()) {
+      m_frameSelected[row] = true;
+    }
+  }
+}
+
 /**
  * Resize the bit array with the frame selection to match the frames size.
  */
@@ -529,8 +546,8 @@ FrameTableLineEdit::FrameTableLineEdit(QWidget* parent) :
   QLineEdit(parent)
 {
   setObjectName(QLatin1String("FrameTableLineEdit"));
-  connect(this, SIGNAL(textChanged(const QString&)),
-          this, SLOT(formatTextIfEnabled(const QString&)));
+  connect(this, SIGNAL(textChanged(QString)),
+          this, SLOT(formatTextIfEnabled(QString)));
 }
 
 /**
@@ -544,9 +561,9 @@ FrameTableLineEdit::~FrameTableLineEdit() {}
  */
 void FrameTableLineEdit::formatTextIfEnabled(const QString& txt)
 {
-  if (ConfigStore::s_id3FormatCfg.m_formatWhileEditing) {
+  if (TagFormatConfig::instance().m_formatWhileEditing) {
     QString str(txt);
-    ConfigStore::s_id3FormatCfg.formatString(str);
+    TagFormatConfig::instance().formatString(str);
     if (str != txt) {
       int curPos = cursorPosition();
       setText(str);
@@ -587,22 +604,27 @@ QWidget* FrameItemDelegate::createEditor(
       for (const char** sl = Genres::s_strList; *sl != 0; ++sl) {
         strList += QString::fromLatin1(*sl);
       }
-      if (ConfigStore::s_miscCfg.m_onlyCustomGenres) {
+      if (TagConfig::instance().onlyCustomGenres()) {
         cb->addItem(QLatin1String(""));
       } else {
         cb->addItems(strList);
       }
+      QStringList customGenres = TagConfig::instance().customGenres();
       if (id3v1) {
-        for (QStringList::const_iterator it =
-               ConfigStore::s_miscCfg.m_customGenres.begin();
-             it != ConfigStore::s_miscCfg.m_customGenres.end();
+        for (QStringList::const_iterator it = customGenres.begin();
+             it != customGenres.end();
              ++it) {
           if (Genres::getNumber(*it) != 255) {
             cb->addItem(*it);
           }
         }
+        if (cb->count() <= 1) {
+          // No custom genres for ID3v1 => Show standard genres
+          cb->clear();
+          cb->addItems(strList);
+        }
       } else {
-        cb->addItems(ConfigStore::s_miscCfg.m_customGenres);
+        cb->addItems(customGenres);
       }
       return cb;
     } else if (id3v1 &&
@@ -630,7 +652,7 @@ void FrameItemDelegate::setEditorData(
     QString genreStr(index.model()->data(index).toString());
     int genreIndex = genreStr.isNull() ? 0 :
       Genres::getIndex(Genres::getNumber(genreStr));
-    if (ConfigStore::s_miscCfg.m_onlyCustomGenres) {
+    if (TagConfig::instance().onlyCustomGenres()) {
       genreIndex = cb->findText(genreStr);
       if (genreIndex < 0) genreIndex = 0;
     } else if (genreIndex <= 0) {
