@@ -261,6 +261,11 @@ public slots:
    */
   void deselectAllFrames();
 
+  /**
+   * Select changed frames in the table.
+   */
+  void selectChangedFrames();
+
 private:
   /**
    * Get the frame at a specific position in the collection.
@@ -304,7 +309,7 @@ public:
    * Constructor.
    * @param parent parent widget
    */
-  FrameTableLineEdit(QWidget* parent);
+  explicit FrameTableLineEdit(QWidget* parent);
 
   /**
    * Destructor.
@@ -327,7 +332,7 @@ public:
    * Constructor.
    * @param parent parent QTableView
    */
-  FrameItemDelegate(QObject* parent) : QItemDelegate(parent) {
+  explicit FrameItemDelegate(QObject* parent) : QItemDelegate(parent) {
     setObjectName(QLatin1String("FrameItemDelegate"));
   }
 
