@@ -39,6 +39,7 @@ class QFileSystemModel;
 class QItemSelectionModel;
 class QModelIndex;
 class QNetworkAccessManager;
+class QTimer;
 class FileProxyModel;
 class FileProxyModelIterator;
 class DirProxyModel;
@@ -51,12 +52,14 @@ class TaggedFile;
 class FrameList;
 class IFrameEditor;
 class ServerImporter;
-class MusicBrainzClient;
+class ServerTrackImporter;
+class ITaggedFileFactory;
 class TextExporter;
 class DirRenamer;
 class BatchImportProfile;
 class BatchImporter;
 class IAbortable;
+class ICorePlatformTools;
 #if defined HAVE_PHONON || QT_VERSION >= 0x050000
 class AudioPlayer;
 #endif
@@ -76,9 +79,11 @@ public:
 
   /**
    * Constructor.
+   * @param platformTools platform tools
    * @param parent parent object
    */
-  explicit Kid3Application(QObject* parent = 0);
+  explicit Kid3Application(ICorePlatformTools* platformTools,
+                           QObject* parent = 0);
 
   /**
    * Destructor.
@@ -158,13 +163,7 @@ public:
    * Get settings.
    * @return settings.
    */
-  Kid3Settings* getSettings() const;
-
-  /**
-   * Get configuration.
-   * @return configuration.
-   */
-  ConfigStore* getConfigStore() const { return m_configStore; }
+  ISettings* getSettings() const;
 
   /**
    * Get download client.
@@ -185,10 +184,12 @@ public:
   QList<ServerImporter*> getServerImporters() { return m_importers; }
 
   /**
-   * Get MusicBrainz client.
-   * @return MusicBrainz client if supported, else 0
+   * Get available server track importers.
+   * @return list of server track importers.
    */
-  MusicBrainzClient* getMusicBrainzClient() { return m_musicBrainzClient; }
+  QList<ServerTrackImporter*> getServerTrackImporters() {
+    return m_trackImporters;
+  }
 
   /**
    * Get directory renamer.
@@ -229,14 +230,15 @@ public:
 
   /**
    * Open directory.
+   * When finished directoryOpened() is emitted, also if false is returned.
    *
-   * @param dir       directory or file path
-   * @param fileCheck if true and dir in not directory, only open directory
-   *                  if dir is a valid file path
+   * @param paths file or directory paths, if multiple paths are given, the
+   * common directory is opened and the files are selected
+   * @param fileCheck if true, only open directory if paths exist
    *
-   * @return true if ok, directoryOpened() is emitted.
+   * @return true if ok.
    */
-  bool openDirectory(QString dir, bool fileCheck = false);
+  bool openDirectory(const QStringList& paths, bool fileCheck = false);
 
   /**
    * Get root index of opened directory in file proxy model.
@@ -260,11 +262,62 @@ public:
    */
   QStringList saveDirectory();
 
+  /**
+   * Update tags of selected files to contain contents of frame models.
+   *
+   * @param selItems list of selected file indexes
+   */
+  void frameModelsToTags(const QList<QPersistentModelIndex>& selItems);
+
+  /**
+   * Update frame models to contain contents of selected files.
+   * The properties starting with "selection" will be set by this method.
+   *
+   * @param selItems list of selected file indexes
+   */
+  void tagsToFrameModels(const QList<QPersistentModelIndex>& selItems);
+
+  /**
+   * Check if a single file is selected.
+   * @return if a single file is selected, this tagged file, else 0.
+   */
+  const TaggedFile* selectionSingleFile() const {
+    return m_selectionSingleFile;
+  }
+
+  /**
+   * Number of selected files which support tag 1.
+   * @return number of selected files which support tag 1.
+   */
+  int selectionTagV1SupportedCount() const {
+    return m_selectionTagV1SupportedCount;
+  }
+
+  /**
+   * Number of selected files.
+   * @return number of selected files which support tag 2.
+   */
+  int selectionFileCount() const {
+    return m_selectionFileCount;
+  }
+
+  /**
+   * Check if any of the selected files has a tag 1.
+   * @return true if any of the selected files has a tag 1.
+   */
+  bool selectionHasTagV1() const { return m_selectionHasTagV1; }
+
+  /**
+   * Check if any of the selected files has a tag 2.
+   * @return true if any of the selected files has a tag 2.
+   */
+  bool selectionHasTagV2() const { return m_selectionHasTagV2; }
+
   /**
    * Import.
    *
    * @param tagMask tag mask
-   * @param path    path of file
+   * @param path    path of file, "clipboard" for import from clipboard
    * @param fmtIdx  index of format
    *
    * @return true if ok.
@@ -276,7 +329,7 @@ public:
    * Export.
    *
    * @param tagVersion tag version
-   * @param path   path of file
+   * @param path   path of file, "clipboard" for export to clipboard
    * @param fmtIdx index of format
    *
    * @return true if ok.
@@ -311,17 +364,18 @@ public:
   /**
    * Set the directory name from the tags.
    * The directory must not have modified files.
+   * renameActionsScheduled() is emitted when the rename actions have been
+   * scheduled. Then performRenameActions() has to be called to effectively
+   * rename the directory.
    *
    * @param tagMask tag mask
    * @param format  directory name format
    * @param create  true to create, false to rename
-   * @param errStr  if not 0, a string describing the error is returned here
    *
    * @return true if ok.
    */
   bool renameDirectory(TrackData::TagVersion tagMask,
-                       const QString& format,
-                       bool create, QString* errStr);
+                       const QString& format, bool create);
 
   /**
    * Number tracks in selected files of directory.
@@ -363,6 +417,30 @@ public:
    */
   void downloadImage(const QString& url, DownloadImageDestination dest);
 
+  /**
+   * Get value of frame.
+   * To get binary data like a picture, the name of a file to write can be
+   * added after the @a name, e.g. "Picture:/path/to/file".
+   *
+   * @param tagMask tag bit (1 for tag 1, 2 for tag 2)
+   * @param name    name of frame (e.g. "artist")
+   */
+  QString getFrame(TrackData::TagVersion tagMask, const QString& name);
+
+  /**
+   * Set value of frame.
+   * For tag 2 (@a tagMask 2), if no frame with @a name exists, a new frame
+   * is added, if @a value is empty, the frame is deleted.
+   * To add binary data like a picture, a file can be added after the
+   * @a name, e.g. "Picture:/path/to/file".
+   *
+   * @param tagMask tag bit (1 for tag 1, 2 for tag 2)
+   * @param name    name of frame (e.g. "artist")
+   * @param value   value of frame
+   */
+  bool setFrame(TrackData::TagVersion tagMask, const QString& name,
+                const QString& value);
+
   /**
    * Format a filename if format while editing is switched on.
    *
@@ -378,11 +456,11 @@ public:
   void formatFramesIfEnabled(FrameCollection& frames) const;
 
   /**
-   * Open directory on drop.
+   * Open directory or add pictures on drop.
    *
-   * @param txt URL of directory or file in directory
+   * @param paths paths of directories or files in directory
    */
-  void openDrop(QString txt);
+  void openDrop(const QStringList& paths);
 
   /**
    * Add picture on drop.
@@ -442,6 +520,11 @@ public:
    */
   bool isModified() { return m_modified; }
 
+  /**
+   * Update modification state from files.
+   */
+  void updateModified();
+
   /**
    * Set filter state.
    *
@@ -456,6 +539,14 @@ public:
    */
   bool isFiltered() { return m_filtered; }
 
+  /**
+   * Get format used to generate filename from tags.
+   * @return format
+   */
+  QString getFilenameToTagsFormat() const {
+    return m_filenameToTagsFormat;
+  }
+
   /**
    * Get format used to generate tags from filename.
    * @return format
@@ -485,9 +576,15 @@ public:
   static void setDirName(const QString& dirName) { s_dirName = dirName; }
 
   /**
-   * Set the ID3v1 and ID3v2 text encodings from the configuration.
+   * Notify the tagged file factories about the changed configuration.
    */
-  static void setTextEncodings();
+  static void notifyConfigurationChange();
+
+  /**
+   * Load plugins.
+   * @return list of plugin instances.
+   */
+  static QObjectList loadPlugins();
 
 public slots:
   /**
@@ -521,19 +618,15 @@ public slots:
    */
   void applyTextEncoding();
 
-#ifdef HAVE_TAGLIB
   /**
    * Convert ID3v2.3 to ID3v2.4 tags.
    */
   void convertToId3v24();
-#endif
 
-#if defined HAVE_TAGLIB && (defined HAVE_ID3LIB || defined HAVE_TAGLIB_ID3V23_SUPPORT)
   /**
    * Convert ID3v2.4 to ID3v2.3 tags.
    */
   void convertToId3v23();
-#endif
 
   /**
    * Copy tags 1 into copy buffer.
@@ -545,6 +638,13 @@ public slots:
    */
   void copyTagsV2();
 
+  /**
+   * Copy tags into copy buffer.
+   *
+   * @param tagMask tag bit (1 for tag 1, 2 for tag 2)
+   */
+  void copyTags(TrackData::TagVersion tagMask);
+
   /**
    * Paste from copy buffer to ID3v1 tags.
    */
@@ -555,6 +655,13 @@ public slots:
    */
   void pasteTagsV2();
 
+  /**
+   * Paste from copy buffer to tags.
+   *
+   * @param tagMask tag bit (1 for tag 1, 2 for tag 2)
+   */
+  void pasteTags(TrackData::TagVersion tagMask);
+
   /**
    * Copy ID3v1 tags to ID3v2 tags of selected files.
    */
@@ -565,6 +672,13 @@ public slots:
    */
   void copyV2ToV1();
 
+  /**
+   * Set tag from other tag.
+   *
+   * @param tagMask tag bit (1 for tag 1, 2 for tag 2)
+   */
+  void copyToOtherTag(TrackData::TagVersion tagMask);
+
   /**
    * Remove ID3v1 tags in selected files.
    */
@@ -575,6 +689,13 @@ public slots:
    */
   void removeTagsV2();
 
+  /**
+   * Remove tags in selected files.
+   *
+   * @param tagMask tag bit (1 for tag 1, 2 for tag 2)
+   */
+  void removeTags(TrackData::TagVersion tagMask);
+
   /**
    * Set ID3v1 tags according to filename.
    * If a single file is selected the tags in the GUI controls
@@ -589,6 +710,13 @@ public slots:
    */
   void getTagsFromFilenameV2();
 
+  /**
+   * Set tags according to filename.
+   *
+   * @param tagMask tag bit (1 for tag 1, 2 for tag 2)
+   */
+  void getTagsFromFilename(TrackData::TagVersion tagMask);
+
   /**
    * Set format used to generate filename from tags.
    * @param format format
@@ -733,6 +861,7 @@ public slots:
 
   /**
    * Schedule actions to rename a directory.
+   * When finished renameActionsScheduled() is emitted.
    */
   void scheduleRenameActions();
 
@@ -768,17 +897,17 @@ public slots:
 signals:
   /**
    * Emitted when a new directory is opened.
-   * @param directoryIndex root path file system model index
-   * @param fileIndex file path index in the file system model
+   * @param directoryIndex root path file proxy model index
+   * @param fileIndexes file path indexes in the file proxy model
    */
-  void directoryOpened(const QModelIndex& directoryIndex,
-                       const QModelIndex& fileIndex);
+  void directoryOpened(const QPersistentModelIndex& directoryIndex,
+                       const QList<QPersistentModelIndex>& fileIndexes);
 
   /**
    * Emitted when a confirmed opening of a directory or file is requested.
-   * @param dir directory or file path
+   * @param paths directory or file paths
    */
-  void confirmedOpenDirectoryRequested(const QString& dir);
+  void confirmedOpenDirectoryRequested(const QStringList& paths);
 
   /**
    * Emitted when saving files is started.
@@ -847,6 +976,12 @@ signals:
    */
   void aboutToPlayAudio();
 
+  /**
+   * Emitted when all rename actions have been scheduled.
+   * @see scheduleRenameActions()
+   */
+  void renameActionsScheduled();
+
 private slots:
   /**
    * Apply single file to file filter.
@@ -869,11 +1004,27 @@ private slots:
    */
   void scheduleNextRenameAction(const QPersistentModelIndex& index);
 
+  /**
+   * Emit directoryOpened().
+   */
+  void emitDirectoryOpened();
+
+  /**
+   * Called when the gatherer thread has finished to load the directory.
+   */
+  void onDirectoryLoaded();
+
 private:
   /**
-  * Init file types.
-  */
-  void initFileTypes();
+   * Load and initialize plugins depending on configuration.
+   */
+  void initPlugins();
+
+  /**
+   * Check type of a loaded plugin and register it.
+   * @param plugin instance returned by plugin loader
+   */
+  void checkPlugin(QObject* plugin);
 
   /**
    * Let the user select and edit a frame type and then edit the frame.
@@ -885,6 +1036,7 @@ private:
    */
   bool selectAddAndEditFrame(IFrameEditor* frameEditor);
 
+  ICorePlatformTools* m_platformTools;
   /** model of filesystem */
   QFileSystemModel* m_fileSystemModel;
   FileProxyModel* m_fileProxyModel;
@@ -911,10 +1063,13 @@ private:
   DirRenamer* m_dirRenamer;
   /** Batch importer */
   BatchImporter* m_batchImporter;
+  /** Timeout timer for openDirectory() */
+  QTimer* m_openDirectoryTimeoutTimer;
 #if defined HAVE_PHONON || QT_VERSION >= 0x050000
   /** Audio player */
   AudioPlayer* m_player;
 #endif
+  FileFilter* m_expressionFileFilter;
   /** Affected files to add frame when downloading image */
   DownloadImageDestination m_downloadImageDest;
   /** Copy buffer */
@@ -925,6 +1080,8 @@ private:
   bool m_filtered;
   /** Root index in file proxy model */
   QPersistentModelIndex m_fileProxyModelRootIndex;
+  /** Indexes of opened file in file proxy model */
+  QList<QPersistentModelIndex> m_fileProxyModelFileIndexes;
   /** Format to generate tags from filename */
   QString m_filenameToTagsFormat;
   /** Format to generate filename from tags */
@@ -932,7 +1089,19 @@ private:
   /** Importers for different servers */
   QList<ServerImporter*> m_importers;
   /** Importer for MusicBrainz fingerprints */
-  MusicBrainzClient* m_musicBrainzClient;
+  QList<ServerTrackImporter*> m_trackImporters;
+
+  /* Context for updateFrameModels() */
+  /** If a single file is selected, this tagged file, else 0 */
+  TaggedFile* m_selectionSingleFile;
+  /** Number of selected files which support tag 1 */
+  int m_selectionTagV1SupportedCount;
+  /** Number of selected files */
+  int m_selectionFileCount;
+  /** true if any of the selected files has a tag 1 */
+  bool m_selectionHasTagV1;
+  /** true if any of the selected files has a tag 2 */
+  bool m_selectionHasTagV2;
 
   /* Context for filterNextFile() */
   FileFilter* m_fileFilter;
