@@ -38,7 +38,7 @@
 #include "pictureframe.h"
 #include "fileproxymodel.h"
 #include "modeliterator.h"
-#include "configstore.h"
+#include "batchimportconfig.h"
 #include "batchimportprofile.h"
 
 /**
@@ -69,7 +69,7 @@ ScriptInterface::~ScriptInterface()
  */
 bool ScriptInterface::openDirectory(const QString& path)
 {
-  return m_app->openDirectory(path, true);
+  return m_app->openDirectory(QStringList() << path, true);
 }
 
 /**
@@ -112,7 +112,7 @@ void ScriptInterface::revert()
  * Import tags from a file.
  *
  * @param tagMask tag bit (1 for tag 1, 2 for tag 2)
- * @param path    path of file
+ * @param path    path of file, "clipboard" for import from clipboard
  * @param fmtIdx  index of format
  *
  * @return true if ok.
@@ -134,7 +134,7 @@ bool ScriptInterface::importFromFile(int tagMask, const QString& path,
 bool ScriptInterface::batchImport(int tagMask, const QString& profileName)
 {
   BatchImportProfile profile;
-  if (ConfigStore::s_batchImportCfg.getProfileByName(profileName, profile)) {
+  if (BatchImportConfig::instance().getProfileByName(profileName, profile)) {
     m_app->batchImport(profile, TrackData::tagVersionCast(tagMask));
     return true;
   }
@@ -158,7 +158,7 @@ void ScriptInterface::downloadAlbumArt(const QString& url, bool allFilesInDir)
  * Export tags to a file.
  *
  * @param tagMask tag bit (1 for tag 1, 2 for tag 2)
- * @param path    path of file
+ * @param path    path of file, "clipboard" for export to clipboard
  * @param fmtIdx  index of format
  *
  * @return true if ok.
@@ -330,16 +330,28 @@ void ScriptInterface::applyTextEncoding()
 bool ScriptInterface::setDirNameFromTag(int tagMask, const QString& format,
                                         bool create)
 {
+  connect(m_app, SIGNAL(renameActionsScheduled()),
+          this, SLOT(onRenameActionsScheduled()));
   if (m_app->renameDirectory(TrackData::tagVersionCast(tagMask), format,
-                             create, &m_errorMsg)) {
-    m_errorMsg.clear();
+                             create)) {
     return true;
   } else {
-    m_errorMsg = QLatin1String("Error while renaming:\n") + m_errorMsg;
+    disconnect(m_app, SIGNAL(renameActionsScheduled()),
+               this, SLOT(onRenameActionsScheduled()));
     return false;
   }
 }
 
+void ScriptInterface::onRenameActionsScheduled()
+{
+  disconnect(m_app, SIGNAL(renameActionsScheduled()),
+             this, SLOT(onRenameActionsScheduled()));
+  m_errorMsg = m_app->performRenameActions();
+  if (!m_errorMsg.isEmpty()) {
+    m_errorMsg = QLatin1String("Error while renaming:\n") + m_errorMsg;
+  }
+}
+
 /**
  * Set subsequent track numbers in the selected files.
  *
@@ -361,7 +373,6 @@ void ScriptInterface::filter(const QString& expression)
   m_app->applyFilter(expression);
 }
 
-#ifdef HAVE_TAGLIB
 /**
  * Convert ID3v2.3 tags to ID3v2.4.
  */
@@ -369,9 +380,7 @@ void ScriptInterface::convertToId3v24()
 {
   m_app->convertToId3v24();
 }
-#endif
 
-#if defined HAVE_TAGLIB && (defined HAVE_ID3LIB || defined HAVE_TAGLIB_ID3V23_SUPPORT)
 /**
  * Convert ID3v2.4 tags to ID3v2.3.
  */
@@ -379,7 +388,6 @@ void ScriptInterface::convertToId3v23()
 {
   m_app->convertToId3v23();
 }
-#endif
 
 /**
  * Get path of directory.
@@ -444,24 +452,7 @@ void ScriptInterface::setFileNameFromTag(int tagMask)
  */
 QString ScriptInterface::getFrame(int tagMask, const QString& name)
 {
-  QString frameName(name);
-  QString dataFileName;
-  int colonIndex = frameName.indexOf(QLatin1Char(':'));
-  if (colonIndex != -1) {
-    dataFileName = frameName.mid(colonIndex + 1);
-    frameName.truncate(colonIndex);
-  }
-  FrameTableModel* ft = (tagMask & 2) ? m_app->frameModelV2() :
-    m_app->frameModelV1();
-  FrameCollection::const_iterator it = ft->frames().findByName(frameName);
-  if (it != ft->frames().end()) {
-    if (!dataFileName.isEmpty()) {
-      PictureFrame::writeDataToFile(*it, dataFileName);
-    }
-    return it->getValue();
-  } else {
-    return QLatin1String("");
-  }
+  return m_app->getFrame(TrackData::tagVersionCast(tagMask), name);
 }
 
 /**
@@ -478,46 +469,7 @@ QString ScriptInterface::getFrame(int tagMask, const QString& name)
 bool ScriptInterface::setFrame(int tagMask, const QString& name,
                            const QString& value)
 {
-  QString frameName(name);
-  QString dataFileName;
-  int colonIndex = frameName.indexOf(QLatin1Char(':'));
-  if (colonIndex != -1) {
-    dataFileName = frameName.mid(colonIndex + 1);
-    frameName.truncate(colonIndex);
-  }
-  FrameTableModel* ft = (tagMask & 2) ? m_app->frameModelV2() :
-    m_app->frameModelV1();
-  FrameCollection frames(ft->frames());
-  FrameCollection::iterator it = frames.findByName(frameName);
-  if (it != frames.end()) {
-    if (it->getType() == Frame::FT_Picture && !dataFileName.isEmpty() &&
-        (tagMask & 2) != 0) {
-      m_app->deleteFrame(it->getName());
-      PictureFrame frame;
-      PictureFrame::setDescription(frame, value);
-      PictureFrame::setDataFromFile(frame, dataFileName);
-      PictureFrame::setMimeTypeFromFileName(frame, dataFileName);
-      m_app->addFrame(&frame);
-    } else if (value.isEmpty() && (tagMask & 2) != 0) {
-      m_app->deleteFrame(it->getName());
-    } else {
-      Frame& frame = const_cast<Frame&>(*it);
-      frame.setValueIfChanged(value);
-      ft->transferFrames(frames);
-    }
-    return true;
-  } else if (tagMask & 2) {
-    Frame frame(Frame::ExtendedType(frameName), value, -1);
-    if (frame.getType() == Frame::FT_Picture && !dataFileName.isEmpty()) {
-      PictureFrame::setFields(frame);
-      PictureFrame::setDescription(frame, value);
-      PictureFrame::setDataFromFile(frame, dataFileName);
-      PictureFrame::setMimeTypeFromFileName(frame, dataFileName);
-    }
-    m_app->addFrame(&frame);
-    return true;
-  }
-  return false;
+  return m_app->setFrame(TrackData::tagVersionCast(tagMask), name, value);
 }
 
 /**
@@ -599,11 +551,7 @@ QStringList ScriptInterface::getInformation()
  */
 void ScriptInterface::setTagFromFileName(int tagMask)
 {
-  if (tagMask & 1) {
-    m_app->getTagsFromFilenameV1();
-  } else if (tagMask & 2) {
-    m_app->getTagsFromFilenameV2();
-  }
+  m_app->getTagsFromFilename(TrackData::tagVersionCast(tagMask));
 }
 
 /**
@@ -613,11 +561,7 @@ void ScriptInterface::setTagFromFileName(int tagMask)
  */
 void ScriptInterface::setTagFromOtherTag(int tagMask)
 {
-  if (tagMask & 1) {
-    m_app->copyV2ToV1();
-  } else if (tagMask & 2) {
-    m_app->copyV1ToV2();
-  }
+  m_app->copyToOtherTag(TrackData::tagVersionCast(tagMask));
 }
 
 /**
@@ -627,11 +571,7 @@ void ScriptInterface::setTagFromOtherTag(int tagMask)
  */
 void ScriptInterface::copyTag(int tagMask)
 {
-  if (tagMask & 1) {
-    m_app->copyTagsV1();
-  } else if (tagMask & 2) {
-    m_app->copyTagsV2();
-  }
+  m_app->copyTags(TrackData::tagVersionCast(tagMask));
 }
 
 /**
@@ -641,11 +581,7 @@ void ScriptInterface::copyTag(int tagMask)
  */
 void ScriptInterface::pasteTag(int tagMask)
 {
-  if (tagMask & 1) {
-    m_app->pasteTagsV1();
-  } else if (tagMask & 2) {
-    m_app->pasteTagsV2();
-  }
+  m_app->pasteTags(TrackData::tagVersionCast(tagMask));
 }
 
 /**
@@ -655,11 +591,7 @@ void ScriptInterface::pasteTag(int tagMask)
  */
 void ScriptInterface::removeTag(int tagMask)
 {
-  if (tagMask & 1) {
-    m_app->removeTagsV1();
-  } else if (tagMask & 2) {
-    m_app->removeTagsV2();
-  }
+  m_app->removeTags(TrackData::tagVersionCast(tagMask));
 }
 
 /**
@@ -672,7 +604,7 @@ void ScriptInterface::reparseConfiguration()
   m_app->readConfig();
 }
 
-#ifdef HAVE_PHONON
+#if defined HAVE_PHONON || QT_VERSION >= 0x050000
 /**
  * Play selected audio files.
  */
