@@ -174,6 +174,12 @@ public:
    */
   void setTimeDifferenceCheck(bool enable, int maxDiff);
 
+  /**
+   * Calculate accuracy of imported track data.
+   * @return accuracy in percent, -1 if unknown.
+   */
+  int calculateAccuracy() const;
+
   /**
    * Get frame for index.
    * @param index model index
@@ -217,7 +223,7 @@ public:
 
 private:
   ImportTrackDataVector m_trackDataVector;
-  QList<int> m_frameTypes;
+  QList<Frame::ExtendedType> m_frameTypes;
   bool m_diffCheckEnabled;
   int m_maxDiff;
 };
