@@ -361,7 +361,7 @@ public:
   /**
    * Set frame inactive.
    */
-  void setInactive() { m_value = QString::null; }
+  void setInactive() { m_value = QString(); }
 
   /**
    * Check if frame represents different frames in multiple files.
@@ -481,7 +481,7 @@ private:
 };
 
 /** Filter to enable a subset of frame types. */
-class FrameFilter {
+class KID3_CORE_EXPORT FrameFilter {
 public:
   /**
    * Constructor.
@@ -808,6 +808,15 @@ public:
     s_quickAccessFrames = mask;
   }
 
+  /**
+   * Get mask containing the bits of all frame types which shall be used as
+   * quick access frames.
+   * @return mask bit mask with bits for quick access frames set.
+   */
+  static quint64 getQuickAccessFrames() {
+    return s_quickAccessFrames;
+  }
+
 private:
   /**
    * Search for a frame only by name.
