@@ -29,13 +29,11 @@
 #include <QString>
 #include <QRegExp>
 #include <sys/stat.h>
-#include "configstore.h"
+#include "tagconfig.h"
 #include "genres.h"
 #include "modeliterator.h"
 #include "saferename.h"
 
-QList<const TaggedFile::Resolver*> TaggedFile::s_resolvers;
-
 /**
  * Constructor.
  *
@@ -58,6 +56,40 @@ TaggedFile::~TaggedFile()
 {
 }
 
+/**
+ * Get features supported.
+ * @return bit mask with Feature flags set.
+ */
+int TaggedFile::taggedFileFeatures() const
+{
+  return 0;
+}
+
+/**
+ * Get currently active tagged file features.
+ * @return active tagged file features.
+ * @see setActiveTaggedFileFeatures()
+ */
+int TaggedFile::activeTaggedFileFeatures() const
+{
+  return 0;
+}
+
+/**
+ * Activate some features provided by the tagged file.
+ * For example, if the TF_ID3v24 feature is provided, it can be set, so that
+ * writeTags() will write ID3v2.4.0 tags. If the feature is deactivated by
+ * passing 0, tags in the default format will be written again.
+ *
+ * @param features bit mask with some of the Feature flags which are
+ * provided by this file, as returned by taggedFileFeatures(), 0 to disable
+ * special features.
+ */
+void TaggedFile::setActiveTaggedFileFeatures(int features)
+{
+  Q_UNUSED(features)
+}
+
 /**
  * Get ID3v1 title.
  *
@@ -67,7 +99,7 @@ TaggedFile::~TaggedFile()
  */
 QString TaggedFile::getTitleV1()
 {
-  return QString::null;
+  return QString();
 }
 
 /**
@@ -79,7 +111,7 @@ QString TaggedFile::getTitleV1()
  */
 QString TaggedFile::getArtistV1()
 {
-  return QString::null;
+  return QString();
 }
 
 /**
@@ -91,7 +123,7 @@ QString TaggedFile::getArtistV1()
  */
 QString TaggedFile::getAlbumV1()
 {
-  return QString::null;
+  return QString();
 }
 
 /**
@@ -103,7 +135,7 @@ QString TaggedFile::getAlbumV1()
  */
 QString TaggedFile::getCommentV1()
 {
-  return QString::null;
+  return QString();
 }
 
 /**
@@ -139,7 +171,7 @@ int TaggedFile::getTrackNumV1()
  */
 QString TaggedFile::getGenreV1()
 {
-  return QString::null;
+  return QString();
 }
 
 /**
@@ -560,7 +592,7 @@ bool TaggedFile::renameFile(const QString& fnOld, const QString& fnNew) const
  */
 QString TaggedFile::getCommentFieldName() const
 {
-  return ConfigStore::s_miscCfg.m_commentName;
+  return TagConfig::instance().commentName();
 }
 
 /**
@@ -614,7 +646,7 @@ int TaggedFile::getTotalNumberOfTracksInDir() const {
  */
 int TaggedFile::getTotalNumberOfTracksIfEnabled() const
 {
-  return ConfigStore::s_miscCfg.m_enableTotalNumberOfTracks
+  return TagConfig::instance().enableTotalNumberOfTracks()
       ? getTotalNumberOfTracksInDir() : -1;
 }
 
@@ -683,7 +715,7 @@ void TaggedFile::formatTrackNumberIfEnabled(QString& value, bool addTotal) const
  */
 int TaggedFile::getTrackNumberDigits() const
 {
-  int numDigits = ConfigStore::s_miscCfg.m_trackNumberDigits;
+  int numDigits = TagConfig::instance().trackNumberDigits();
   if (numDigits < 1 || numDigits > 5)
     numDigits = 1;
   return numDigits;
@@ -714,7 +746,7 @@ void TaggedFile::deleteFramesV2(const FrameFilter& flt)
  */
 QString TaggedFile::getTagFormatV1() const
 {
-  return QString::null;
+  return QString();
 }
 
 /**
@@ -726,7 +758,7 @@ QString TaggedFile::getTagFormatV1() const
  */
 QString TaggedFile::getTagFormatV2() const
 {
-  return QString::null;
+  return QString();
 }
 
 /**
@@ -748,7 +780,7 @@ QString TaggedFile::checkTruncation(
     return s;
   } else {
     m_truncation &= ~flag;
-    return QString::null;
+    return QString();
   }
 }
 
@@ -1113,74 +1145,55 @@ void TaggedFile::setFramesV2(const FrameCollection& frames, bool onlyChanged)
 
 
 /**
- * Add a file type resolver to the end of a list of resolvers.
- *
- * @param resolver file type resolver to add
+ * Constructor.
  */
-void TaggedFile::addResolver(const Resolver* resolver)
+TaggedFile::DetailInfo::DetailInfo() : valid(false), vbr(false),
+  channelMode(CM_None), channels(0), sampleRate(0), bitrate(0), duration(0)
 {
-  s_resolvers.push_back(resolver);
 }
 
 /**
- * Create a TaggedFile subclass using the first successful resolver.
- * @see addResolver()
- *
- * @param dn directory name
- * @param fn filename
- * @param idx model index
- *
- * @return tagged file, 0 if type not supported.
+ * Destructor.
  */
-TaggedFile* TaggedFile::createFile(const QString& dn, const QString& fn,
-                                   const QPersistentModelIndex& idx)
+TaggedFile::DetailInfo::~DetailInfo()
 {
-  TaggedFile* taggedFile = 0;
-  for (QList<const Resolver*>::const_iterator it = s_resolvers.begin();
-       it != s_resolvers.end();
-       ++it) {
-    taggedFile = (*it)->createFile(dn, fn, idx);
-    if (taggedFile) break;
-  }
-  return taggedFile;
 }
 
 /**
- * Get a list with all extensions (e.g. ".mp3") supported by the resolvers.
- * @see addResolver()
- *
- * @return list of file extensions.
+ * Get string representation of detail information.
+ * @return information summary as string.
  */
-QStringList TaggedFile::getSupportedFileExtensions()
+QString TaggedFile::DetailInfo::toString() const
 {
-  QStringList extensions;
-  for (QList<const Resolver*>::const_iterator it = s_resolvers.begin();
-       it != s_resolvers.end();
-       ++it) {
-    extensions += (*it)->getSupportedFileExtensions();
-  }
-
-  // remove duplicates
-  extensions.sort();
-  QString lastExt(QLatin1String(""));
-  for (QStringList::iterator it = extensions.begin();
-       it != extensions.end();) {
-    if (*it == lastExt) {
-      it = extensions.erase(it);
-    } else {
-      lastExt = *it;
-      ++it;
+  QString str;
+  if (valid) {
+    str = format;
+    str += QLatin1Char(' ');
+    if (bitrate > 0 && bitrate < 999) {
+      if (vbr) str += QLatin1String("VBR ");
+      str += QString::number(bitrate);
+      str += QLatin1String(" kbps ");
+    }
+    if (sampleRate > 0) {
+      str += QString::number(sampleRate);
+      str += QLatin1String(" Hz ");
+    }
+    switch (channelMode) {
+      case TaggedFile::DetailInfo::CM_Stereo:
+        str += QLatin1String("Stereo ");
+        break;
+      case TaggedFile::DetailInfo::CM_JointStereo:
+        str += QLatin1String("Joint Stereo ");
+        break;
+      default:
+        if (channels > 0) {
+          str += QString::number(channels);
+          str += QLatin1String(" Channels ");
+        }
+    }
+    if (duration > 0) {
+      str += TaggedFile::formatTime(duration);
     }
   }
-
-  return extensions;
-}
-
-/**
- * Free static resources.
- */
-void TaggedFile::staticCleanup()
-{
-  qDeleteAll(s_resolvers);
-  s_resolvers.clear();
+  return str;
 }
