@@ -36,48 +36,28 @@
 /** Base class for tagged files. */
 class KID3_CORE_EXPORT TaggedFile {
 public:
-  /** Abstract base class for pluggable file type resolution. */
-  class Resolver {
-  public:
-    /**
-     * Constructor.
-     */
-    Resolver() {}
-
-    /**
-     * Destructor.
-     */
-    virtual ~Resolver() {}
-
-    /**
-     * Create a TaggedFile subclass depending on the file extension.
-     *
-     * @param dn directory name
-     * @param fn filename
-     * @param idx model index
-     *
-     * @return tagged file, 0 if type not supported.
-     */
-    virtual TaggedFile* createFile(const QString& dn, const QString& fn,
-                                   const QPersistentModelIndex& idx) const = 0;
-
-    /**
-     * Get a list with all extensions (e.g. ".mp3") supported by TaggedFile subclass.
-     *
-     * @return list of file extensions.
-     */
-    virtual QStringList getSupportedFileExtensions() const = 0;
+  /**
+   * Special features and formats supported.
+   * Additional information which cannot be deduced from the file format
+   * supported.
+   */
+  enum Feature {
+    TF_ID3v11      = 1 << 0, /**< Supports ID3v1.1 tags */
+    TF_ID3v22      = 1 << 1, /**< Supports ID3v2.2 tags */
+    TF_ID3v23      = 1 << 2, /**< Supports ID3v2.3 tags */
+    TF_ID3v24      = 1 << 3, /**< Supports ID3v2.4 tags */
+    TF_OggPictures = 1 << 4  /**< Supports pictures in Ogg files */
   };
 
-
   /** Information about file. */
-  struct DetailInfo {
+  struct KID3_CORE_EXPORT DetailInfo {
     /** Channel mode. */
     enum ChannelMode { CM_None, CM_Stereo, CM_JointStereo };
 
     /** Constructor. */
-    DetailInfo() : valid(false), vbr(false), channelMode(CM_None), channels(0),
-                   sampleRate(0), bitrate(0), duration(0) {}
+    DetailInfo();
+    /** Destructor. */
+    ~DetailInfo();
 
     bool valid;              /**< true if information valid */
     bool vbr;                /**< true if variable bitrate */
@@ -87,6 +67,12 @@ public:
     unsigned sampleRate;     /**< sample rate in Hz > 0 */
     unsigned bitrate;        /**< 0 < bitrate in kbps < 999 */
     unsigned long duration;  /**< duration in seconds > 0 */
+
+    /**
+     * Get string representation of detail information.
+     * @return information summary as string.
+     */
+    QString toString() const;
   };
 
 
@@ -126,6 +112,37 @@ public:
    */
   QString getDirname() const { return m_dirname; }
 
+  /**
+   * Get key of tagged file format.
+   * @return key.
+   */
+  virtual QString taggedFileKey() const = 0;
+
+  /**
+   * Get features supported.
+   * @return bit mask with Feature flags set.
+   */
+  virtual int taggedFileFeatures() const;
+
+  /**
+   * Get currently active tagged file features.
+   * @return active tagged file features.
+   * @see setActiveTaggedFileFeatures()
+   */
+  virtual int activeTaggedFileFeatures() const;
+
+  /**
+   * Activate some features provided by the tagged file.
+   * For example, if the TF_ID3v24 feature is provided, it can be set, so that
+   * writeTags() will write ID3v2.4.0 tags. If the feature is deactivated by
+   * passing 0, tags in the default format will be written again.
+   *
+   * @param features bit mask with some of the Feature flags which are
+   * provided by this file, as returned by taggedFileFeatures(), 0 to disable
+   * special features.
+   */
+  virtual void setActiveTaggedFileFeatures(int features);
+
   /**
    * Read tags from file.
    *
@@ -691,34 +708,6 @@ public:
    */
   static QString formatTime(unsigned seconds);
 
-  /**
-   * Add a file type resolver to the end of a list of resolvers.
-   *
-   * @param resolver file type resolver to add
-   */
-  static void addResolver(const Resolver* resolver);
-
-  /**
-   * Create a TaggedFile subclass using the first successful resolver.
-   * @see addResolver()
-   *
-   * @param dn directory name
-   * @param fn filename
-   * @param idx model index
-   *
-   * @return tagged file, 0 if type not supported.
-   */
-  static TaggedFile* createFile(const QString& dn, const QString& fn,
-                                const QPersistentModelIndex& idx);
-
-  /**
-   * Get a list with all extensions (e.g. ".mp3") supported by the resolvers.
-   * @see addResolver()
-   *
-   * @return list of file extensions.
-   */
-  static QStringList getSupportedFileExtensions();
-
   /**
    * Free static resources.
    */
@@ -853,8 +842,6 @@ private:
   quint64 m_changedFramesV2;
   /** Truncation flags. */
   quint64 m_truncation;
-
-  static QList<const Resolver*> s_resolvers;
 };
 
 #endif // TAGGEDFILE_H
