@@ -28,6 +28,8 @@
 #define TRACKDATA_H
 
 #include <QVector>
+#include <QString>
+#include <QSet>
 #include "frame.h"
 #include "taggedfile.h"
 #include "kid3api.h"
@@ -231,6 +233,24 @@ public:
    */
   void setEnabled(bool enabled) { m_enabled = enabled; }
 
+  /**
+   * Get the difference between the imported duration and the track's duration.
+   * @return absolute value of time difference in seconds, -1 if not available.
+   */
+  int getTimeDifference() const;
+
+  /**
+   * Get words of file name.
+   * @return lower case words found in file name.
+   */
+  QSet<QString> getFilenameWords() const;
+
+  /**
+   * Get words of title.
+   * @return lower case words found in title.
+   */
+  QSet<QString> getTitleWords() const;
+
 private:
   int m_importDuration;
   bool m_enabled;
@@ -284,6 +304,13 @@ public:
    */
   void readTags(ImportTrackData::TagVersion tagVersion);
 
+#ifndef QT_NO_DEBUG
+  /**
+   * Dump contents of tracks to debug console.
+   */
+  void dump() const;
+#endif
+
 private:
   /**
    * Get frame from first track.
