@@ -28,32 +28,17 @@
 #define QTCOMPATMAC_H
 
 #include <QtGlobal>
-#include <QObject>
-#include "config.h"
-
-#ifdef CONFIG_USE_KDE
-#include <klocale.h>
-
-#define QCM_translate(s) i18n(s)
-
-#else
-#include <QCoreApplication>
-
-#define i18n(s) tr(s)
-#define I18N_NOOP(s) QT_TRANSLATE_NOOP("@default", s)
-
-#define QCM_translate(s) QCoreApplication::translate("@default", s)
 
 #if QT_VERSION >= 0x040600
 
+/** Get icon from theme. */
 #define QCM_QIcon_fromTheme(n) QIcon::fromTheme(QLatin1String(n), QIcon(QLatin1String(":/images/" n ".png")))
 
 #else
 
+/** Get icon from theme. */
 #define QCM_QIcon_fromTheme(n) QIcon(QLatin1String(":/images/" n ".png"))
 
 #endif
 
-#endif
-
 #endif // QTCOMPATMAC_H
