@@ -34,20 +34,16 @@
 #include <QSpinBox>
 #include <QApplication>
 #include <QFile>
+#include <QDir>
 #include <QBuffer>
 #include <QVBoxLayout>
 #include <QMimeData>
 #include "kid3application.h"
 #include "imageviewer.h"
 #include "taggedfile.h"
-#include "qtcompatmac.h"
 #include "config.h"
-#include "configstore.h"
-#ifdef CONFIG_USE_KDE
-#include <kfiledialog.h>
-#else
-#include <QFileDialog>
-#endif
+#include "fileconfig.h"
+#include "iplatformtools.h"
 
 /** QTextEdit with label above */
 class LabeledTextEdit : public QWidget {
@@ -272,7 +268,7 @@ LabeledComboBox::LabeledComboBox(QWidget* parent,
   layout->setContentsMargins(0, 0, 0, 0);
   QStringList strList;
   while (*strlst) {
-    strList += QCM_translate(*strlst++);
+    strList += QCoreApplication::translate("@default", *strlst++);
   }
   m_combo->addItems(strList);
   layout->addWidget(m_label);
@@ -473,13 +469,15 @@ class BinFieldControl : public Mp3FieldControl {
 public:
   /**
    * Constructor.
+   * @param platformTools platform tools
    * @param field      field to edit
    * @param frame      frame with fields to edit
    * @param taggedFile file
    */
-  BinFieldControl(Frame::Field& field,
+  BinFieldControl(IPlatformTools* platformTools, Frame::Field& field,
                   const Frame& frame, const TaggedFile* taggedFile) :
-    Mp3FieldControl(field), m_bos(0), m_frame(frame), m_taggedFile(taggedFile) {}
+    Mp3FieldControl(field), m_platformTools(platformTools), m_bos(0),
+    m_frame(frame), m_taggedFile(taggedFile) {}
 
   /**
    * Destructor.
@@ -501,6 +499,8 @@ public:
   virtual QWidget* createWidget(QWidget* parent);
 
 protected:
+  /** Platform dependent tools */
+  IPlatformTools* m_platformTools;
   /** Import, Export, View buttons */
   BinaryOpenSave* m_bos;
   /** frame with fields to edit */
@@ -513,20 +513,23 @@ protected:
 /**
  * Constructor.
  *
+ * @param platformTools platform tools
  * @param parent parent widget
  * @param field  field containing binary data
  */
-BinaryOpenSave::BinaryOpenSave(QWidget* parent, const Frame::Field& field) :
-  QWidget(parent), m_byteArray(field.m_value.toByteArray()),
+BinaryOpenSave::BinaryOpenSave(IPlatformTools* platformTools,
+                               QWidget* parent, const Frame::Field& field) :
+  QWidget(parent),
+  m_platformTools(platformTools), m_byteArray(field.m_value.toByteArray()),
   m_isChanged(false)
 {
   setObjectName(QLatin1String("BinaryOpenSave"));
   QHBoxLayout* layout = new QHBoxLayout(this);
   m_label = new QLabel(this);
-  m_clipButton = new QPushButton(i18n("From Clip&board"), this);
-  QPushButton* openButton = new QPushButton(i18n("&Import"), this);
-  QPushButton* saveButton = new QPushButton(i18n("&Export"), this);
-  QPushButton* viewButton = new QPushButton(i18n("&View"), this);
+  m_clipButton = new QPushButton(tr("From Clip&board"), this);
+  QPushButton* openButton = new QPushButton(tr("&Import"), this);
+  QPushButton* saveButton = new QPushButton(tr("&Export"), this);
+  QPushButton* viewButton = new QPushButton(tr("&View"), this);
   layout->setContentsMargins(0, 0, 0, 0);
   layout->addWidget(m_label);
   layout->addWidget(m_clipButton);
@@ -577,17 +580,9 @@ void BinaryOpenSave::clipData()
  */
 void BinaryOpenSave::loadData()
 {
-#ifdef CONFIG_USE_KDE
-  QString loadfilename = KFileDialog::getOpenFileName(
-    m_defaultDir.isEmpty() ? Kid3Application::getDirName() : m_defaultDir,
-    m_filter, this);
-#else
-  QString loadfilename = QFileDialog::getOpenFileName(
-    this, QString(),
-    m_defaultDir.isEmpty() ? Kid3Application::getDirName() : m_defaultDir,
-    m_filter, 0, ConfigStore::s_miscCfg.m_dontUseNativeDialogs
-    ? QFileDialog::DontUseNativeDialog : QFileDialog::Options(0));
-#endif
+  QString loadfilename = m_platformTools->getOpenFileName(this, QString(),
+        m_defaultDir.isEmpty() ? Kid3Application::getDirName() : m_defaultDir,
+        m_filter, 0);
   if (!loadfilename.isEmpty()) {
     QFile file(loadfilename);
     if (file.open(QIODevice::ReadOnly)) {
@@ -616,13 +611,8 @@ void BinaryOpenSave::saveData()
     }
     dir += m_defaultFile;
   }
-#ifdef CONFIG_USE_KDE
-  QString fn = KFileDialog::getSaveFileName(dir, m_filter, this);
-#else
-  QString fn = QFileDialog::getSaveFileName(this, QString(), dir,
-    m_filter, 0, ConfigStore::s_miscCfg.m_dontUseNativeDialogs
-    ? QFileDialog::DontUseNativeDialog : QFileDialog::Options(0));
-#endif
+  QString fn = m_platformTools->getSaveFileName(
+        this, QString(), dir, m_filter, 0);
   if (!fn.isEmpty()) {
     QFile file(fn);
     if (file.open(QIODevice::WriteOnly)) {
@@ -655,35 +645,35 @@ const char* Mp3FieldControl::getFieldIDString(Frame::Field::Id id) const
 {
   static const char* const idStr[] = {
     "Unknown",
-    I18N_NOOP("Text Encoding"),
-    I18N_NOOP("Text"),
-    I18N_NOOP("URL"),
-    I18N_NOOP("Data"),
-    I18N_NOOP("Description"),
-    I18N_NOOP("Owner"),
-    I18N_NOOP("Email"),
-    I18N_NOOP("Rating"),
-    I18N_NOOP("Filename"),
-    I18N_NOOP("Language"),
-    I18N_NOOP("Picture Type"),
-    I18N_NOOP("Image format"),
-    I18N_NOOP("Mimetype"),
-    I18N_NOOP("Counter"),
-    I18N_NOOP("Identifier"),
-    I18N_NOOP("Volume Adjustment"),
-    I18N_NOOP("Number of Bits"),
-    I18N_NOOP("Volume Change Right"),
-    I18N_NOOP("Volume Change Left"),
-    I18N_NOOP("Peak Volume Right"),
-    I18N_NOOP("Peak Volume Left"),
-    I18N_NOOP("Timestamp Format"),
-    I18N_NOOP("Content Type"),
+    QT_TRANSLATE_NOOP("@default", "Text Encoding"),
+    QT_TRANSLATE_NOOP("@default", "Text"),
+    QT_TRANSLATE_NOOP("@default", "URL"),
+    QT_TRANSLATE_NOOP("@default", "Data"),
+    QT_TRANSLATE_NOOP("@default", "Description"),
+    QT_TRANSLATE_NOOP("@default", "Owner"),
+    QT_TRANSLATE_NOOP("@default", "Email"),
+    QT_TRANSLATE_NOOP("@default", "Rating"),
+    QT_TRANSLATE_NOOP("@default", "Filename"),
+    QT_TRANSLATE_NOOP("@default", "Language"),
+    QT_TRANSLATE_NOOP("@default", "Picture Type"),
+    QT_TRANSLATE_NOOP("@default", "Image format"),
+    QT_TRANSLATE_NOOP("@default", "Mimetype"),
+    QT_TRANSLATE_NOOP("@default", "Counter"),
+    QT_TRANSLATE_NOOP("@default", "Identifier"),
+    QT_TRANSLATE_NOOP("@default", "Volume Adjustment"),
+    QT_TRANSLATE_NOOP("@default", "Number of Bits"),
+    QT_TRANSLATE_NOOP("@default", "Volume Change Right"),
+    QT_TRANSLATE_NOOP("@default", "Volume Change Left"),
+    QT_TRANSLATE_NOOP("@default", "Peak Volume Right"),
+    QT_TRANSLATE_NOOP("@default", "Peak Volume Left"),
+    QT_TRANSLATE_NOOP("@default", "Timestamp Format"),
+    QT_TRANSLATE_NOOP("@default", "Content Type"),
 
-    I18N_NOOP("Price"),
-    I18N_NOOP("Date"),
-    I18N_NOOP("Seller")
+    QT_TRANSLATE_NOOP("@default", "Price"),
+    QT_TRANSLATE_NOOP("@default", "Date"),
+    QT_TRANSLATE_NOOP("@default", "Seller")
   };
-  class not_used { int array_size_check[
+  struct not_used { int array_size_check[
       sizeof(idStr) / sizeof(idStr[0]) == Frame::Field::ID_Seller + 1
       ? 1 : -1 ]; };
   return idStr[id <= Frame::Field::ID_Seller ? id : 0];
@@ -709,7 +699,8 @@ QWidget* TextFieldControl::createWidget(QWidget* parent)
   if (m_edit == NULL)
     return NULL;
 
-  m_edit->setLabel(QCM_translate(getFieldIDString(static_cast<Frame::Field::Id>(m_field.m_id))));
+  m_edit->setLabel(QCoreApplication::translate("@default",
+      getFieldIDString(static_cast<Frame::Field::Id>(m_field.m_id))));
   m_edit->setText(m_field.m_value.toString());
   m_edit->setFocus();
   return m_edit;
@@ -732,7 +723,8 @@ void LineFieldControl::updateTag()
 QWidget* LineFieldControl::createWidget(QWidget* parent)
 {
   m_edit = new LabeledLineEdit(parent);
-  m_edit->setLabel(QCM_translate(getFieldIDString(static_cast<Frame::Field::Id>(m_field.m_id))));
+  m_edit->setLabel(QCoreApplication::translate("@default",
+      getFieldIDString(static_cast<Frame::Field::Id>(m_field.m_id))));
   m_edit->setText(m_field.m_value.toString());
   return m_edit;
 }
@@ -754,7 +746,8 @@ void IntFieldControl::updateTag()
 QWidget* IntFieldControl::createWidget(QWidget* parent)
 {
   m_numInp = new LabeledSpinBox(parent);
-  m_numInp->setLabel(QCM_translate(getFieldIDString(static_cast<Frame::Field::Id>(m_field.m_id))));
+  m_numInp->setLabel(QCoreApplication::translate("@default",
+      getFieldIDString(static_cast<Frame::Field::Id>(m_field.m_id))));
   m_numInp->setValue(m_field.m_value.toInt());
   return m_numInp;
 }
@@ -776,7 +769,8 @@ void IntComboBoxControl::updateTag()
 QWidget* IntComboBoxControl::createWidget(QWidget* parent)
 {
   m_ptInp = new LabeledComboBox(parent, m_strLst);
-  m_ptInp->setLabel(QCM_translate(getFieldIDString(static_cast<Frame::Field::Id>(m_field.m_id))));
+  m_ptInp->setLabel(QCoreApplication::translate("@default",
+      getFieldIDString(static_cast<Frame::Field::Id>(m_field.m_id))));
   m_ptInp->setCurrentItem(m_field.m_value.toInt());
   return m_ptInp;
 }
@@ -799,21 +793,22 @@ void BinFieldControl::updateTag()
  */
 QWidget* BinFieldControl::createWidget(QWidget* parent)
 {
-  m_bos = new BinaryOpenSave(parent, m_field);
-  m_bos->setLabel(QCM_translate(getFieldIDString(static_cast<Frame::Field::Id>(m_field.m_id))));
+  m_bos = new BinaryOpenSave(m_platformTools, parent, m_field);
+  m_bos->setLabel(QCoreApplication::translate("@default",
+      getFieldIDString(static_cast<Frame::Field::Id>(m_field.m_id))));
   if (m_taggedFile) {
     m_bos->setDefaultDir(m_taggedFile->getDirname());
   }
   if (m_frame.getType() == Frame::FT_Picture) {
-    m_bos->setDefaultFile(ConfigStore::s_miscCfg.m_defaultCoverFileName);
-    m_bos->setFilter(
-#ifdef CONFIG_USE_KDE
-          QLatin1String("*.jpg *.jpeg *.png|") +
-          i18n("Images (*.jpg *.jpeg *.png)") + QLatin1String("\n*|") + i18n("All Files (*)")
-#else
-          i18n("Images (*.jpg *.jpeg *.png)") + QLatin1String(";;") + i18n("All Files (*)")
-#endif
-          );
+    m_bos->setDefaultFile(FileConfig::instance().m_defaultCoverFileName);
+    m_bos->setFilter(m_platformTools->fileDialogNameFilter(
+               QList<QPair<QString, QString> >()
+               << qMakePair(QCoreApplication::translate("@default",
+                                QT_TRANSLATE_NOOP("@default", "Images")),
+                            QString(QLatin1String("*.jpg *.jpeg *.png")))
+               << qMakePair(QCoreApplication::translate("@default",
+                                QT_TRANSLATE_NOOP("@default", "All Files")),
+                            QString(QLatin1Char('*')))));
   }
   return m_bos;
 }
@@ -837,15 +832,18 @@ const Frame::FieldList& EditFrameFieldsDialog::getUpdatedFieldList()
 /**
  * Constructor.
  *
+ * @param platformTools platform tools
  * @param parent     parent widget
  * @param caption    caption
  * @param frame      frame with fields to edit
  * @param taggedFile file
  */
 EditFrameFieldsDialog::EditFrameFieldsDialog(
+  IPlatformTools* platformTools,
   QWidget* parent, const QString& caption,
   const Frame& frame, const TaggedFile* taggedFile) :
-  QDialog(parent), m_fields(frame.getFieldList())
+  QDialog(parent),
+  m_platformTools(platformTools), m_fields(frame.getFieldList())
 {
   setObjectName(QLatin1String("EditFrameFieldsDialog"));
   setModal(true);
@@ -863,10 +861,10 @@ EditFrameFieldsDialog::EditFrameFieldsDialog(
       case QVariant::UInt:
         if (fld.m_id == Frame::Field::ID_TextEnc) {
           static const char* strlst[] = {
-            I18N_NOOP("ISO-8859-1"),
-            I18N_NOOP("UTF16"),
-            I18N_NOOP("UTF16BE"),
-            I18N_NOOP("UTF8"),
+            QT_TRANSLATE_NOOP("@default", "ISO-8859-1"),
+            QT_TRANSLATE_NOOP("@default", "UTF16"),
+            QT_TRANSLATE_NOOP("@default", "UTF16BE"),
+            QT_TRANSLATE_NOOP("@default", "UTF8"),
             NULL
           };
           IntComboBoxControl* cbox = new IntComboBoxControl(fld, strlst);
@@ -874,27 +872,27 @@ EditFrameFieldsDialog::EditFrameFieldsDialog(
         }
         else if (fld.m_id == Frame::Field::ID_PictureType) {
           static const char* strlst[] = {
-            I18N_NOOP("Other"),
-            I18N_NOOP("32x32 pixels PNG file icon"),
-            I18N_NOOP("Other file icon"),
-            I18N_NOOP("Cover (front)"),
-            I18N_NOOP("Cover (back)"),
-            I18N_NOOP("Leaflet page"),
-            I18N_NOOP("Media"),
-            I18N_NOOP("Lead artist/lead performer/soloist"),
-            I18N_NOOP("Artist/performer"),
-            I18N_NOOP("Conductor"),
-            I18N_NOOP("Band/Orchestra"),
-            I18N_NOOP("Composer"),
-            I18N_NOOP("Lyricist/text writer"),
-            I18N_NOOP("Recording Location"),
-            I18N_NOOP("During recording"),
-            I18N_NOOP("During performance"),
-            I18N_NOOP("Movie/video screen capture"),
-            I18N_NOOP("A bright coloured fish"),
-            I18N_NOOP("Illustration"),
-            I18N_NOOP("Band/artist logotype"),
-            I18N_NOOP("Publisher/Studio logotype"),
+            QT_TRANSLATE_NOOP("@default", "Other"),
+            QT_TRANSLATE_NOOP("@default", "32x32 pixels PNG file icon"),
+            QT_TRANSLATE_NOOP("@default", "Other file icon"),
+            QT_TRANSLATE_NOOP("@default", "Cover (front)"),
+            QT_TRANSLATE_NOOP("@default", "Cover (back)"),
+            QT_TRANSLATE_NOOP("@default", "Leaflet page"),
+            QT_TRANSLATE_NOOP("@default", "Media"),
+            QT_TRANSLATE_NOOP("@default", "Lead artist/lead performer/soloist"),
+            QT_TRANSLATE_NOOP("@default", "Artist/performer"),
+            QT_TRANSLATE_NOOP("@default", "Conductor"),
+            QT_TRANSLATE_NOOP("@default", "Band/Orchestra"),
+            QT_TRANSLATE_NOOP("@default", "Composer"),
+            QT_TRANSLATE_NOOP("@default", "Lyricist/text writer"),
+            QT_TRANSLATE_NOOP("@default", "Recording Location"),
+            QT_TRANSLATE_NOOP("@default", "During recording"),
+            QT_TRANSLATE_NOOP("@default", "During performance"),
+            QT_TRANSLATE_NOOP("@default", "Movie/video screen capture"),
+            QT_TRANSLATE_NOOP("@default", "A bright coloured fish"),
+            QT_TRANSLATE_NOOP("@default", "Illustration"),
+            QT_TRANSLATE_NOOP("@default", "Band/artist logotype"),
+            QT_TRANSLATE_NOOP("@default", "Publisher/Studio logotype"),
             NULL
           };
           IntComboBoxControl* cbox = new IntComboBoxControl(fld, strlst);
@@ -902,9 +900,9 @@ EditFrameFieldsDialog::EditFrameFieldsDialog(
         }
         else if (fld.m_id == Frame::Field::ID_TimestampFormat) {
           static const char* strlst[] = {
-            I18N_NOOP("Other"),
-            I18N_NOOP("MPEG frames as unit"),
-            I18N_NOOP("Milliseconds as unit"),
+            QT_TRANSLATE_NOOP("@default", "Other"),
+            QT_TRANSLATE_NOOP("@default", "MPEG frames as unit"),
+            QT_TRANSLATE_NOOP("@default", "Milliseconds as unit"),
             NULL
           };
           IntComboBoxControl* cbox = new IntComboBoxControl(fld, strlst);
@@ -912,13 +910,13 @@ EditFrameFieldsDialog::EditFrameFieldsDialog(
         }
         else if (fld.m_id == Frame::Field::ID_ContentType) {
           static const char* strlst[] = {
-            I18N_NOOP("Other"),
-            I18N_NOOP("Lyrics"),
-            I18N_NOOP("Text transcription"),
-            I18N_NOOP("Movement/part name"),
-            I18N_NOOP("Events"),
-            I18N_NOOP("Chord"),
-            I18N_NOOP("Trivia/pop up"),
+            QT_TRANSLATE_NOOP("@default", "Other"),
+            QT_TRANSLATE_NOOP("@default", "Lyrics"),
+            QT_TRANSLATE_NOOP("@default", "Text transcription"),
+            QT_TRANSLATE_NOOP("@default", "Movement/part name"),
+            QT_TRANSLATE_NOOP("@default", "Events"),
+            QT_TRANSLATE_NOOP("@default", "Chord"),
+            QT_TRANSLATE_NOOP("@default", "Trivia/pop up"),
             NULL
           };
           IntComboBoxControl* cbox = new IntComboBoxControl(fld, strlst);
@@ -944,7 +942,8 @@ EditFrameFieldsDialog::EditFrameFieldsDialog(
 
       case QVariant::ByteArray:
       {
-        BinFieldControl* binctl = new BinFieldControl(fld, frame, taggedFile);
+        BinFieldControl* binctl = new BinFieldControl(
+              m_platformTools, fld, frame, taggedFile);
         m_fieldcontrols.append(binctl);
         break;
       }
@@ -962,8 +961,8 @@ EditFrameFieldsDialog::EditFrameFieldsDialog(
   QHBoxLayout* hlayout = new QHBoxLayout;
   QSpacerItem* hspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
              QSizePolicy::Minimum);
-  QPushButton* okButton = new QPushButton(i18n("&OK"), this);
-  QPushButton* cancelButton = new QPushButton(i18n("&Cancel"), this);
+  QPushButton* okButton = new QPushButton(tr("&OK"), this);
+  QPushButton* cancelButton = new QPushButton(tr("&Cancel"), this);
   hlayout->addItem(hspacer);
   hlayout->addWidget(okButton);
   hlayout->addWidget(cancelButton);
