@@ -25,13 +25,6 @@
  */
 
 #include "exportdialog.h"
-#include "config.h"
-#ifdef CONFIG_USE_KDE
-#include <kfiledialog.h>
-#else
-#include <QFileDialog>
-#endif
-
 #include <QLayout>
 #include <QPushButton>
 #include <QLabel>
@@ -42,34 +35,35 @@
 #include <QTableView>
 #include <QComboBox>
 #include <QDir>
-#include <QApplication>
-#include <QClipboard>
 #include <QUrl>
 #include <QMessageBox>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
 #include "taggedfile.h"
 #include "genres.h"
-#include "configstore.h"
+#include "exportconfig.h"
+#include "importconfig.h"
 #include "contexthelp.h"
 #include "textexporter.h"
 #include "texttablemodel.h"
 #include "formatlistedit.h"
-#include "qtcompatmac.h"
+#include "iplatformtools.h"
 
 /**
  * Constructor.
  *
+ * @param platformTools platform tools
  * @param parent       parent widget
  * @param textExporter text exporter to use
  */
-ExportDialog::ExportDialog(QWidget* parent, TextExporter* textExporter) :
-  QDialog(parent),
+ExportDialog::ExportDialog(IPlatformTools* platformTools,
+                           QWidget* parent, TextExporter* textExporter) :
+  QDialog(parent), m_platformTools(platformTools),
   m_textExporter(textExporter), m_textTableModel(new TextTableModel(this))
 {
   setObjectName(QLatin1String("ExportDialog"));
   setModal(true);
-  setWindowTitle(i18n("Export"));
+  setWindowTitle(tr("Export"));
   setSizeGripEnabled(true);
 
   QVBoxLayout* vlayout = new QVBoxLayout(this);
@@ -84,10 +78,10 @@ ExportDialog::ExportDialog(QWidget* parent, TextExporter* textExporter) :
 
   QString formatToolTip = ImportTrackData::getFormatToolTip();
   m_formatListEdit = new FormatListEdit(
-        QStringList() << i18n("Format:")
-                      << i18n("Header:")
-                      << i18n("Tracks:")
-                      << i18n("Footer:"),
+        QStringList() << tr("Format:")
+                      << tr("Header:")
+                      << tr("Tracks:")
+                      << tr("Footer:"),
         QStringList() << QString()
                       << formatToolTip
                       << formatToolTip
@@ -98,12 +92,12 @@ ExportDialog::ExportDialog(QWidget* parent, TextExporter* textExporter) :
   vlayout->addWidget(m_formatListEdit);
 
   QHBoxLayout* butlayout = new QHBoxLayout;
-  m_fileButton = new QPushButton(i18n("To F&ile"), this);
+  m_fileButton = new QPushButton(tr("To F&ile"), this);
   m_fileButton->setAutoDefault(false);
   butlayout->addWidget(m_fileButton);
   connect(m_fileButton, SIGNAL(clicked()), this, SLOT(slotToFile()));
 
-  m_clipButton = new QPushButton(i18n("To Clip&board"), this);
+  m_clipButton = new QPushButton(tr("To Clip&board"), this);
   m_clipButton->setAutoDefault(false);
   butlayout->addWidget(m_clipButton);
   connect(m_clipButton, SIGNAL(clicked()), this, SLOT(slotToClipboard()));
@@ -112,12 +106,12 @@ ExportDialog::ExportDialog(QWidget* parent, TextExporter* textExporter) :
                                            QSizePolicy::Minimum);
   butlayout->addItem(butspacer);
 
-  QLabel* srcLabel = new QLabel(i18n("&Source:"), this);
+  QLabel* srcLabel = new QLabel(tr("&Source:"), this);
   butlayout->addWidget(srcLabel);
   m_srcComboBox = new QComboBox(this);
   m_srcComboBox->setEditable(false);
-  m_srcComboBox->addItem(i18n("Tag 1"), TrackData::TagV1);
-  m_srcComboBox->addItem(i18n("Tag 2"), TrackData::TagV2);
+  m_srcComboBox->addItem(tr("Tag 1"), TrackData::TagV1);
+  m_srcComboBox->addItem(tr("Tag 2"), TrackData::TagV2);
   srcLabel->setBuddy(m_srcComboBox);
   butlayout->addWidget(m_srcComboBox);
   connect(m_srcComboBox, SIGNAL(activated(int)),
@@ -126,12 +120,12 @@ ExportDialog::ExportDialog(QWidget* parent, TextExporter* textExporter) :
   vlayout->addLayout(butlayout);
 
   QHBoxLayout* hlayout = new QHBoxLayout;
-  QPushButton* helpButton = new QPushButton(i18n("&Help"), this);
+  QPushButton* helpButton = new QPushButton(tr("&Help"), this);
   helpButton->setAutoDefault(false);
   hlayout->addWidget(helpButton);
   connect(helpButton, SIGNAL(clicked()), this, SLOT(showHelp()));
 
-  QPushButton* saveButton = new QPushButton(i18n("&Save Settings"), this);
+  QPushButton* saveButton = new QPushButton(tr("&Save Settings"), this);
   saveButton->setAutoDefault(false);
   hlayout->addWidget(saveButton);
   connect(saveButton, SIGNAL(clicked()), this, SLOT(saveConfig()));
@@ -140,7 +134,7 @@ ExportDialog::ExportDialog(QWidget* parent, TextExporter* textExporter) :
                                          QSizePolicy::Minimum);
   hlayout->addItem(hspacer);
 
-  QPushButton* closeButton = new QPushButton(i18n("&Close"), this);
+  QPushButton* closeButton = new QPushButton(tr("&Close"), this);
   closeButton->setAutoDefault(false);
   hlayout->addWidget(closeButton);
   connect(closeButton, SIGNAL(clicked()), this, SLOT(accept()));
@@ -160,21 +154,13 @@ ExportDialog::~ExportDialog()
  */
 void ExportDialog::slotToFile()
 {
-  QString fileName =
-#ifdef CONFIG_USE_KDE
-    KFileDialog::getSaveFileName(ConfigStore::s_genCfg.m_importDir,
-                                 QString::null, this);
-#else
-    QFileDialog::getSaveFileName(this, QString(),
-     ConfigStore::s_genCfg.m_importDir, QString(), 0,
-     ConfigStore::s_miscCfg.m_dontUseNativeDialogs
-     ? QFileDialog::DontUseNativeDialog : QFileDialog::Options(0));
-#endif
+  QString fileName = m_platformTools->getSaveFileName(this, QString(),
+      ImportConfig::instance().m_importDir, QString(), 0);
   if (!fileName.isEmpty()) {
     if (!m_textExporter->exportToFile(fileName)) {
       QMessageBox::warning(
-        0, i18n("File Error"),
-        i18n("Error while writing file:\n") + fileName,
+        0, tr("File Error"),
+        tr("Error while writing file:\n") + fileName,
         QMessageBox::Ok, Qt::NoButton);
     }
   }
@@ -185,8 +171,7 @@ void ExportDialog::slotToFile()
  */
 void ExportDialog::slotToClipboard()
 {
-  QApplication::clipboard()->setText(
-    m_textExporter->getText(), QClipboard::Clipboard);
+  m_textExporter->exportToClipboard();
 }
 
 /**
@@ -216,11 +201,11 @@ void ExportDialog::showPreview()
 void ExportDialog::setFormatFromConfig()
 {
   m_formatListEdit->setFormats(
-        QList<QStringList>() << ConfigStore::s_genCfg.m_exportFormatNames
-                             << ConfigStore::s_genCfg.m_exportFormatHeaders
-                             << ConfigStore::s_genCfg.m_exportFormatTracks
-                             << ConfigStore::s_genCfg.m_exportFormatTrailers,
-        ConfigStore::s_genCfg.m_exportFormatIdx);
+        QList<QStringList>() << ExportConfig::instance().m_exportFormatNames
+                             << ExportConfig::instance().m_exportFormatHeaders
+                             << ExportConfig::instance().m_exportFormatTracks
+                             << ExportConfig::instance().m_exportFormatTrailers,
+        ExportConfig::instance().m_exportFormatIdx);
 }
 
 /**
@@ -229,12 +214,12 @@ void ExportDialog::setFormatFromConfig()
 void ExportDialog::readConfig()
 {
   m_srcComboBox->setCurrentIndex(
-      m_srcComboBox->findData(ConfigStore::s_genCfg.m_exportSrcV1));
+      m_srcComboBox->findData(ExportConfig::instance().m_exportSrcV1));
 
   setFormatFromConfig();
 
-  if (!ConfigStore::s_genCfg.m_exportWindowGeometry.isEmpty()) {
-    restoreGeometry(ConfigStore::s_genCfg.m_exportWindowGeometry);
+  if (!ExportConfig::instance().m_exportWindowGeometry.isEmpty()) {
+    restoreGeometry(ExportConfig::instance().m_exportWindowGeometry);
   }
 }
 
@@ -243,15 +228,15 @@ void ExportDialog::readConfig()
  */
 void ExportDialog::saveConfig()
 {
-  ConfigStore::s_genCfg.m_exportSrcV1 = TrackData::tagVersionCast(
+  ExportConfig::instance().m_exportSrcV1 = TrackData::tagVersionCast(
     m_srcComboBox->itemData(m_srcComboBox->currentIndex()).toInt());
   QList<QStringList> formats = m_formatListEdit->getFormats(
-        &ConfigStore::s_genCfg.m_exportFormatIdx);
-  ConfigStore::s_genCfg.m_exportFormatNames = formats.at(0);
-  ConfigStore::s_genCfg.m_exportFormatHeaders = formats.at(1);
-  ConfigStore::s_genCfg.m_exportFormatTracks = formats.at(2);
-  ConfigStore::s_genCfg.m_exportFormatTrailers = formats.at(3);
-  ConfigStore::s_genCfg.m_exportWindowGeometry = saveGeometry();
+        &ExportConfig::instance().m_exportFormatIdx);
+  ExportConfig::instance().m_exportFormatNames = formats.at(0);
+  ExportConfig::instance().m_exportFormatHeaders = formats.at(1);
+  ExportConfig::instance().m_exportFormatTracks = formats.at(2);
+  ExportConfig::instance().m_exportFormatTrailers = formats.at(3);
+  ExportConfig::instance().m_exportWindowGeometry = saveGeometry();
 
   setFormatFromConfig();
 }
