@@ -32,10 +32,9 @@
 #include <QString>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
-#include "configstore.h"
+#include "filterconfig.h"
 #include "contexthelp.h"
 #include "formatlistedit.h"
-#include "qtcompatmac.h"
 
 /**
  * Constructor.
@@ -46,7 +45,7 @@ FilterDialog::FilterDialog(QWidget* parent) : QDialog(parent),
   m_isAbortButton(false)
 {
   setObjectName(QLatin1String("FilterDialog"));
-  setWindowTitle(i18n("Filter"));
+  setWindowTitle(tr("Filter"));
   setSizeGripEnabled(true);
 
   QVBoxLayout* vlayout = new QVBoxLayout(this);
@@ -57,20 +56,20 @@ FilterDialog::FilterDialog(QWidget* parent) : QDialog(parent),
   vlayout->addWidget(m_edit);
 
   m_formatListEdit = new FormatListEdit(
-        QStringList() << i18n("&Filter:")
-                      << i18n("&Expression:"),
+        QStringList() << tr("&Filter:")
+                      << tr("&Expression:"),
         QStringList() << QString()
                       << FileFilter::getFormatToolTip(),
         this);
   vlayout->addWidget(m_formatListEdit);
 
   QHBoxLayout* hlayout = new QHBoxLayout;
-  QPushButton* helpButton = new QPushButton(i18n("&Help"), this);
+  QPushButton* helpButton = new QPushButton(tr("&Help"), this);
   helpButton->setAutoDefault(false);
   hlayout->addWidget(helpButton);
   connect(helpButton, SIGNAL(clicked()), this, SLOT(showHelp()));
 
-  QPushButton* saveButton = new QPushButton(i18n("&Save Settings"), this);
+  QPushButton* saveButton = new QPushButton(tr("&Save Settings"), this);
   saveButton->setAutoDefault(false);
   hlayout->addWidget(saveButton);
   connect(saveButton, SIGNAL(clicked()), this, SLOT(saveConfig()));
@@ -81,7 +80,7 @@ FilterDialog::FilterDialog(QWidget* parent) : QDialog(parent),
 
   m_applyButton = new QPushButton(this);
   setAbortButton(false);
-  QPushButton* closeButton = new QPushButton(i18n("&Close"), this);
+  QPushButton* closeButton = new QPushButton(tr("&Close"), this);
   m_applyButton->setAutoDefault(false);
   closeButton->setAutoDefault(false);
   hlayout->addWidget(m_applyButton);
@@ -120,9 +119,9 @@ void FilterDialog::applyOrAbortFilter()
 void FilterDialog::setFiltersFromConfig()
 {
   m_formatListEdit->setFormats(
-        QList<QStringList>() << ConfigStore::s_filterCfg.m_filterNames
-                             << ConfigStore::s_filterCfg.m_filterExpressions,
-        ConfigStore::s_filterCfg.m_filterIdx);
+        QList<QStringList>() << FilterConfig::instance().m_filterNames
+                             << FilterConfig::instance().m_filterExpressions,
+        FilterConfig::instance().m_filterIdx);
 }
 
 /**
@@ -136,8 +135,8 @@ void FilterDialog::readConfig()
 
   setFiltersFromConfig();
 
-  if (!ConfigStore::s_filterCfg.m_windowGeometry.isEmpty()) {
-    restoreGeometry(ConfigStore::s_filterCfg.m_windowGeometry);
+  if (!FilterConfig::instance().m_windowGeometry.isEmpty()) {
+    restoreGeometry(FilterConfig::instance().m_windowGeometry);
   }
 }
 
@@ -147,10 +146,10 @@ void FilterDialog::readConfig()
 void FilterDialog::saveConfig()
 {
   QList<QStringList> formats = m_formatListEdit->getFormats(
-        &ConfigStore::s_filterCfg.m_filterIdx);
-  ConfigStore::s_filterCfg.m_filterNames = formats.at(0);
-  ConfigStore::s_filterCfg.m_filterExpressions = formats.at(1);
-  ConfigStore::s_filterCfg.m_windowGeometry = saveGeometry();
+        &FilterConfig::instance().m_filterIdx);
+  FilterConfig::instance().m_filterNames = formats.at(0);
+  FilterConfig::instance().m_filterExpressions = formats.at(1);
+  FilterConfig::instance().m_windowGeometry = saveGeometry();
 
   setFiltersFromConfig();
 }
@@ -170,7 +169,7 @@ void FilterDialog::showFilterEvent(FileFilter::FilterEventType type,
                                    const QString& fileName) {
   switch (type) {
   case FileFilter::Started:
-    m_edit->append(i18n("Started"));
+    m_edit->append(tr("Started"));
     setAbortButton(true);
     break;
   case FileFilter::Directory:
@@ -186,11 +185,11 @@ void FilterDialog::showFilterEvent(FileFilter::FilterEventType type,
     m_edit->append(QLatin1String("-\t") + fileName);
     break;
   case FileFilter::Finished:
-    m_edit->append(i18n("Finished"));
+    m_edit->append(tr("Finished"));
     setAbortButton(false);
     break;
   case FileFilter::Aborted:
-    m_edit->append(i18n("Aborted"));
+    m_edit->append(tr("Aborted"));
     setAbortButton(false);
     break;
   }
@@ -203,5 +202,5 @@ void FilterDialog::showFilterEvent(FileFilter::FilterEventType type,
 void FilterDialog::setAbortButton(bool enableAbort)
 {
   m_isAbortButton = enableAbort;
-  m_applyButton->setText(m_isAbortButton ? i18n("A&bort") : i18n("&Apply"));
+  m_applyButton->setText(m_isAbortButton ? tr("A&bort") : tr("&Apply"));
 }
