@@ -25,10 +25,6 @@
  */
 
 #include "importdialog.h"
-#include "config.h"
-#ifdef CONFIG_USE_KDE
-#include <kicon.h>
-#endif
 #include <QLayout>
 #include <QPushButton>
 #include <QToolButton>
@@ -49,12 +45,15 @@
 #include <QGroupBox>
 #include <QDir>
 #include <QMenu>
+#include <QCoreApplication>
+#include "config.h"
 #include "genres.h"
 #include "serverimporter.h"
+#include "servertrackimporter.h"
 #include "serverimportdialog.h"
+#include "servertrackimportdialog.h"
 #include "textimportdialog.h"
 #include "tagimportdialog.h"
-#include "configstore.h"
 #include "contexthelp.h"
 #include "taggedfile.h"
 #include "trackdata.h"
@@ -62,11 +61,7 @@
 #include "frametablemodel.h"
 #include "trackdatamatcher.h"
 #include "qtcompatmac.h"
-#include "config.h"
-#ifdef HAVE_CHROMAPRINT
-#include "musicbrainzdialog.h"
-#include "musicbrainzconfig.h"
-#endif
+#include "iplatformtools.h"
 
 namespace {
 
@@ -85,33 +80,33 @@ QList<int> checkableFrameTypes() {
 /**
  * Constructor.
  *
+ * @param platformTools platform tools
  * @param parent        parent widget
  * @param caption       dialog title
  * @param trackDataModel track data to be filled with imported values,
  *                      is passed with durations of files set
  * @param importers     server importers
- * @param mbClient      MusicBrainz client if supported, else 0
+ * @param trackImporters server track importers
  */
-ImportDialog::ImportDialog(QWidget* parent, QString& caption,
+ImportDialog::ImportDialog(IPlatformTools* platformTools,
+                           QWidget* parent, QString& caption,
                            TrackDataModel* trackDataModel,
                            const QList<ServerImporter*>& importers,
-                           MusicBrainzClient* mbClient) :
-  QDialog(parent),
+                           const QList<ServerTrackImporter*>& trackImporters) :
+  QDialog(parent), m_platformTools(platformTools),
   m_autoStartSubDialog(-1), m_columnVisibility(0ULL),
   m_trackDataModel(trackDataModel), m_importers(importers),
-  m_musicBrainzClient(mbClient)
+  m_trackImporters(trackImporters)
 {
   setObjectName(QLatin1String("ImportDialog"));
-  setModal(true);
+  setModal(false);
   setWindowTitle(caption);
   setSizeGripEnabled(true);
 
   m_serverImportDialog = 0;
   m_textImportDialog = 0;
   m_tagImportDialog = 0;
-#ifdef HAVE_CHROMAPRINT
-  m_musicBrainzDialog = 0;
-#endif
+  m_serverTrackImportDialog = 0;
 
   QVBoxLayout* vlayout = new QVBoxLayout(this);
 
@@ -130,21 +125,21 @@ ImportDialog::ImportDialog(QWidget* parent, QString& caption,
 #endif
   m_trackDataTable->horizontalHeader()->setContextMenuPolicy(
         Qt::CustomContextMenu);
-  connect(m_trackDataTable->verticalHeader(), SIGNAL(sectionMoved(int, int, int)),
-          this, SLOT(moveTableRow(int, int, int)));
+  connect(m_trackDataTable->verticalHeader(), SIGNAL(sectionMoved(int,int,int)),
+          this, SLOT(moveTableRow(int,int,int)));
   connect(m_trackDataTable->horizontalHeader(),
           SIGNAL(customContextMenuRequested(QPoint)),
       this, SLOT(showTableHeaderContextMenu(QPoint)));
   vlayout->addWidget(m_trackDataTable);
 
   QHBoxLayout* accuracyLayout = new QHBoxLayout;
-  QLabel* accuracyLabel = new QLabel(i18n("Accuracy:"));
+  QLabel* accuracyLabel = new QLabel(tr("Accuracy:"));
   accuracyLayout->addWidget(accuracyLabel);
   m_accuracyPercentLabel = new QLabel(QLatin1String("-"));
   m_accuracyPercentLabel->setMinimumWidth(
         m_accuracyPercentLabel->fontMetrics().width(QLatin1String("100%")));
   accuracyLayout->addWidget(m_accuracyPercentLabel);
-  QLabel* coverArtLabel = new QLabel(i18n("Cover Art:"));
+  QLabel* coverArtLabel = new QLabel(tr("Cover Art:"));
   accuracyLayout->addWidget(coverArtLabel);
   m_coverArtUrlLabel = new QLabel(QLatin1String(" -"));
   accuracyLayout->addWidget(m_coverArtUrlLabel);
@@ -152,46 +147,45 @@ ImportDialog::ImportDialog(QWidget* parent, QString& caption,
   vlayout->addLayout(accuracyLayout);
 
   QHBoxLayout* butlayout = new QHBoxLayout;
-  QPushButton* fileButton = new QPushButton(i18n("From F&ile/Clipboard..."));
+  QPushButton* fileButton = new QPushButton(tr("From F&ile/Clipboard..."));
   fileButton->setAutoDefault(false);
   butlayout->addWidget(fileButton);
-  QPushButton* tagsButton = new QPushButton(i18n("From T&ags..."));
+  QPushButton* tagsButton = new QPushButton(tr("From T&ags..."));
   tagsButton->setAutoDefault(false);
   butlayout->addWidget(tagsButton);
-  QPushButton* serverButton = new QPushButton(i18n("&From Server:"));
+  QPushButton* serverButton = new QPushButton(tr("&From Server:"));
   serverButton->setAutoDefault(false);
   butlayout->addWidget(serverButton);
   m_serverComboBox = new QComboBox;
   m_serverComboBox->setEditable(false);
   foreach (const ServerImporter* si, m_importers) {
-    m_serverComboBox->addItem(QCM_translate(si->name()));
+    m_serverComboBox->addItem(QCoreApplication::translate("@default", si->name()));
+  }
+  foreach (const ServerTrackImporter* si, m_trackImporters) {
+    m_serverComboBox->addItem(QCoreApplication::translate("@default", si->name()));
   }
-#ifdef HAVE_CHROMAPRINT
-  m_serverComboBox->addItem(i18n("MusicBrainz Fingerprint"));
-#endif
   butlayout->addWidget(m_serverComboBox);
+  if (m_serverComboBox->count() == 0) {
+    serverButton->hide();
+    m_serverComboBox->hide();
+  }
   QSpacerItem* butspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
                                          QSizePolicy::Minimum);
   butlayout->addItem(butspacer);
   QLabel* destLabel = new QLabel;
-  destLabel->setText(i18n("D&estination:"));
+  destLabel->setText(tr("D&estination:"));
   butlayout->addWidget(destLabel);
   m_destComboBox = new QComboBox;
   m_destComboBox->setEditable(false);
-  m_destComboBox->addItem(i18n("Tag 1"), TrackData::TagV1);
-  m_destComboBox->addItem(i18n("Tag 2"), TrackData::TagV2);
-  m_destComboBox->addItem(i18n("Tag 1 and Tag 2"), TrackData::TagV2V1);
+  m_destComboBox->addItem(tr("Tag 1"), TrackData::TagV1);
+  m_destComboBox->addItem(tr("Tag 2"), TrackData::TagV2);
+  m_destComboBox->addItem(tr("Tag 1 and Tag 2"), TrackData::TagV2V1);
   destLabel->setBuddy(m_destComboBox);
   butlayout->addWidget(m_destComboBox);
   QToolButton* revertButton = new QToolButton;
   revertButton->setIcon(
-#ifdef CONFIG_USE_KDE
-        KIcon(QLatin1String("document-revert"))
-#else
-        QCM_QIcon_fromTheme("document-revert")
-#endif
-        );
-  revertButton->setToolTip(i18n("Revert"));
+        m_platformTools->iconFromTheme(QLatin1String("document-revert")));
+  revertButton->setToolTip(tr("Revert"));
   connect(revertButton, SIGNAL(clicked()),
           this, SLOT(changeTagDestination()));
   butlayout->addWidget(revertButton);
@@ -199,7 +193,7 @@ ImportDialog::ImportDialog(QWidget* parent, QString& caption,
 
   QHBoxLayout* matchLayout = new QHBoxLayout;
   m_mismatchCheckBox = new QCheckBox(
-    i18n("Check maximum allowable time &difference (sec):"));
+    tr("Check maximum allowable time &difference (sec):"));
   matchLayout->addWidget(m_mismatchCheckBox);
   m_maxDiffSpinBox = new QSpinBox;
   m_maxDiffSpinBox->setMaximum(9999);
@@ -207,15 +201,15 @@ ImportDialog::ImportDialog(QWidget* parent, QString& caption,
   QSpacerItem* matchSpacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
                                              QSizePolicy::Minimum);
   matchLayout->addItem(matchSpacer);
-  QLabel* matchLabel = new QLabel(i18n("Match with:"));
+  QLabel* matchLabel = new QLabel(tr("Match with:"));
   matchLayout->addWidget(matchLabel);
-  QPushButton* lengthButton = new QPushButton(i18n("&Length"));
+  QPushButton* lengthButton = new QPushButton(tr("&Length"));
   lengthButton->setAutoDefault(false);
   matchLayout->addWidget(lengthButton);
-  QPushButton* trackButton = new QPushButton(i18n("T&rack"));
+  QPushButton* trackButton = new QPushButton(tr("T&rack"));
   trackButton->setAutoDefault(false);
   matchLayout->addWidget(trackButton);
-  QPushButton* titleButton = new QPushButton(i18n("&Title"));
+  QPushButton* titleButton = new QPushButton(tr("&Title"));
   titleButton->setAutoDefault(false);
   matchLayout->addWidget(titleButton);
   vlayout->addLayout(matchLayout);
@@ -234,13 +228,13 @@ ImportDialog::ImportDialog(QWidget* parent, QString& caption,
   QHBoxLayout* hlayout = new QHBoxLayout;
   QSpacerItem* hspacer = new QSpacerItem(16, 0, QSizePolicy::Expanding,
                                          QSizePolicy::Minimum);
-  QPushButton* helpButton = new QPushButton(i18n("&Help"), this);
+  QPushButton* helpButton = new QPushButton(tr("&Help"), this);
   helpButton->setAutoDefault(false);
-  QPushButton* saveButton = new QPushButton(i18n("&Save Settings"), this);
+  QPushButton* saveButton = new QPushButton(tr("&Save Settings"), this);
   saveButton->setAutoDefault(false);
-  QPushButton* okButton = new QPushButton(i18n("&OK"), this);
+  QPushButton* okButton = new QPushButton(tr("&OK"), this);
   okButton->setAutoDefault(false);
-  QPushButton* cancelButton = new QPushButton(i18n("&Cancel"), this);
+  QPushButton* cancelButton = new QPushButton(tr("&Cancel"), this);
   cancelButton->setAutoDefault(false);
   hlayout->addWidget(helpButton);
   hlayout->addWidget(saveButton);
@@ -262,9 +256,7 @@ ImportDialog::~ImportDialog()
   delete m_textImportDialog;
   delete m_tagImportDialog;
   delete m_serverImportDialog;
-#ifdef HAVE_CHROMAPRINT
-  delete m_musicBrainzDialog;
-#endif
+  delete m_serverTrackImportDialog;
 }
 
 /**
@@ -282,7 +274,8 @@ void ImportDialog::fromServer()
 void ImportDialog::fromText()
 {
   if (!m_textImportDialog) {
-    m_textImportDialog = new TextImportDialog(this, m_trackDataModel);
+    m_textImportDialog = new TextImportDialog(
+          m_platformTools, this, m_trackDataModel);
     connect(m_textImportDialog, SIGNAL(trackDataUpdated()),
             this, SLOT(showPreview()));
   }
@@ -315,11 +308,9 @@ void ImportDialog::displayServerImportDialog(int importerIdx)
   if (importerIdx >= 0) {
     if (importerIdx < m_importers.size()) {
       displayServerImportDialog(m_importers.at(importerIdx));
-    } else {
-      // special case for MusicBrainz Fingerprint
-#ifdef HAVE_CHROMAPRINT
-      fromMusicBrainz();
-#endif
+    } else if (importerIdx - m_importers.size() < m_trackImporters.size()) {
+      displayServerTrackImportDialog(
+            m_trackImporters.at(importerIdx - m_importers.size()));
     }
   }
 }
@@ -335,6 +326,8 @@ void ImportDialog::displayServerImportDialog(ServerImporter* source)
     m_serverImportDialog = new ServerImportDialog(this);
     connect(m_serverImportDialog, SIGNAL(trackDataUpdated()),
             this, SLOT(showPreview()));
+    connect(m_serverImportDialog, SIGNAL(accepted()),
+            this, SLOT(onServerImportDialogClosed()));
   }
   m_serverImportDialog->setImportSource(source);
   m_serverImportDialog->setArtistAlbum(
@@ -343,6 +336,23 @@ void ImportDialog::displayServerImportDialog(ServerImporter* source)
   m_serverImportDialog->show();
 }
 
+/**
+ * Import from track server and preview in table.
+ *
+ * @param source import source
+ */
+void ImportDialog::displayServerTrackImportDialog(ServerTrackImporter* source)
+{
+  if (!m_serverTrackImportDialog) {
+    m_serverTrackImportDialog = new ServerTrackImportDialog(this, m_trackDataModel);
+    connect(m_serverTrackImportDialog, SIGNAL(trackDataUpdated()),
+            this, SLOT(showPreview()));
+  }
+  m_serverTrackImportDialog->setImportSource(source);
+  m_serverTrackImportDialog->initTable();
+  m_serverTrackImportDialog->exec();
+}
+
 /**
  * Hide subdialogs.
  */
@@ -356,47 +366,23 @@ void ImportDialog::hideSubdialogs()
     m_tagImportDialog->hide();
 }
 
-#ifdef HAVE_CHROMAPRINT
 /**
- * Import from MusicBrainz and preview in table.
- */
-void ImportDialog::fromMusicBrainz()
-{
-  if (!m_musicBrainzDialog) {
-    m_musicBrainzDialog = new MusicBrainzDialog(this, m_trackDataModel,
-                                                m_musicBrainzClient);
-    connect(m_musicBrainzDialog, SIGNAL(trackDataUpdated()),
-            this, SLOT(showPreview()));
-  }
-  m_musicBrainzDialog->initTable();
-  (void)m_musicBrainzDialog->exec();
-}
-#endif
-
-/**
- * Shows the dialog as a modal dialog.
- */
-int ImportDialog::exec()
-{
-  if (m_autoStartSubDialog >= 0) {
-    show();
-    displayServerImportDialog(m_autoStartSubDialog);
-  }
-  return QDialog::exec();
-}
-
-/**
- * Set dialog to be started automatically.
+ * Shows the dialog as a modeless dialog.
  *
- * @param importerIndex index of importer to use
+ * @param importerIndex index of importer to use, -1 for none
  */
-void ImportDialog::setAutoStartSubDialog(int importerIndex)
+void ImportDialog::showWithSubDialog(int importerIndex)
 {
   m_autoStartSubDialog = importerIndex;
 
   if (importerIndex >= 0 && importerIndex < m_serverComboBox->count()) {
     m_serverComboBox->setCurrentIndex(importerIndex);
   }
+
+  show();
+  if (m_autoStartSubDialog >= 0) {
+    displayServerImportDialog(m_autoStartSubDialog);
+  }
 }
 
 /**
@@ -404,8 +390,8 @@ void ImportDialog::setAutoStartSubDialog(int importerIndex)
  */
 void ImportDialog::clear()
 {
-  m_serverComboBox->setCurrentIndex(ConfigStore::s_genCfg.m_importServer);
-  TrackData::TagVersion importDest = ConfigStore::s_genCfg.m_importDest;
+  m_serverComboBox->setCurrentIndex(ImportConfig::instance().m_importServer);
+  TrackData::TagVersion importDest = ImportConfig::instance().m_importDest;
   int index = m_destComboBox->findData(importDest);
   m_destComboBox->setCurrentIndex(index);
   if (importDest == TrackData::TagV1 &&
@@ -415,9 +401,9 @@ void ImportDialog::clear()
     changeTagDestination();
   }
 
-  m_mismatchCheckBox->setChecked(ConfigStore::s_genCfg.m_enableTimeDifferenceCheck);
-  m_maxDiffSpinBox->setValue(ConfigStore::s_genCfg.m_maxTimeDifference);
-  m_columnVisibility = ConfigStore::s_genCfg.m_importVisibleColumns;
+  m_mismatchCheckBox->setChecked(ImportConfig::instance().m_enableTimeDifferenceCheck);
+  m_maxDiffSpinBox->setValue(ImportConfig::instance().m_maxTimeDifference);
+  m_columnVisibility = ImportConfig::instance().m_importVisibleColumns;
 
   foreach (int frameType, checkableFrameTypes()) {
     if (frameType < 64) {
@@ -429,8 +415,8 @@ void ImportDialog::clear()
     }
   }
 
-  if (!ConfigStore::s_genCfg.m_importWindowGeometry.isEmpty()) {
-    restoreGeometry(ConfigStore::s_genCfg.m_importWindowGeometry);
+  if (!ImportConfig::instance().m_importWindowGeometry.isEmpty()) {
+    restoreGeometry(ImportConfig::instance().m_importWindowGeometry);
   }
 
   showPreview();
@@ -457,6 +443,19 @@ void ImportDialog::showPreview()
   m_coverArtUrlLabel->setText(coverArtUrl.isEmpty() ? QLatin1String("-") : coverArtUrl);
 }
 
+/**
+ * Called when server import dialog is closed.
+ */
+void ImportDialog::onServerImportDialogClosed()
+{
+  // This is used to prevent that the import dialog is brought behind the
+  // main window when the server import dialog is closed, which happened
+  // with Qt 5 on Mac OS X.
+  show();
+  raise();
+  activateWindow();
+}
+
 /**
  * Get import destination.
  *
@@ -481,15 +480,15 @@ void ImportDialog::showHelp()
  */
 void ImportDialog::saveConfig()
 {
-  ConfigStore::s_genCfg.m_importDest = TrackData::tagVersionCast(
+  ImportConfig::instance().m_importDest = TrackData::tagVersionCast(
     m_destComboBox->itemData(m_destComboBox->currentIndex()).toInt());
 
-  ConfigStore::s_genCfg.m_importServer = m_serverComboBox->currentIndex();
-  getTimeDifferenceCheck(ConfigStore::s_genCfg.m_enableTimeDifferenceCheck,
-                         ConfigStore::s_genCfg.m_maxTimeDifference);
-  ConfigStore::s_genCfg.m_importVisibleColumns = m_columnVisibility;
+  ImportConfig::instance().m_importServer = m_serverComboBox->currentIndex();
+  getTimeDifferenceCheck(ImportConfig::instance().m_enableTimeDifferenceCheck,
+                         ImportConfig::instance().m_maxTimeDifference);
+  ImportConfig::instance().m_importVisibleColumns = m_columnVisibility;
 
-  ConfigStore::s_genCfg.m_importWindowGeometry = saveGeometry();
+  ImportConfig::instance().m_importWindowGeometry = saveGeometry();
 }
 
 /**
@@ -524,9 +523,9 @@ void ImportDialog::moveTableRow(int, int fromIndex, int toIndex) {
   QHeaderView* vHeader = qobject_cast<QHeaderView*>(sender());
   if (vHeader) {
     // revert movement, but avoid recursion
-    disconnect(vHeader, SIGNAL(sectionMoved(int, int, int)), 0, 0);
+    disconnect(vHeader, SIGNAL(sectionMoved(int,int,int)), 0, 0);
     vHeader->moveSection(toIndex, fromIndex);
-    connect(vHeader, SIGNAL(sectionMoved(int, int, int)), this, SLOT(moveTableRow(int, int, int)));
+    connect(vHeader, SIGNAL(sectionMoved(int,int,int)), this, SLOT(moveTableRow(int,int,int)));
   }
   ImportTrackDataVector trackDataVector(m_trackDataModel->getTrackData());
   int numTracks = static_cast<int>(trackDataVector.size());
