@@ -40,11 +40,9 @@
 #include "taggedfile.h"
 #include "frame.h"
 #include "trackdata.h"
-#include "configstore.h"
 #include "contexthelp.h"
-#include "miscconfig.h"
+#include "rendirconfig.h"
 #include "dirrenamer.h"
-#include "qtcompatmac.h"
 
 /**
  * Constructor.
@@ -57,23 +55,23 @@ RenDirDialog::RenDirDialog(QWidget* parent, DirRenamer* dirRenamer) :
 {
   setObjectName(QLatin1String("RenDirDialog"));
   setModal(true);
-  setWindowTitle(i18n("Rename Directory"));
+  setWindowTitle(tr("Rename Directory"));
   setSizeGripEnabled(true);
 
   QWizardPage* mainPage = new QWizardPage;
 
   QVBoxLayout* mainLayout = new QVBoxLayout(mainPage);
   setupMainPage(mainPage, mainLayout);
-  mainPage->setTitle(i18n("Format"));
+  mainPage->setTitle(tr("Format"));
   addPage(mainPage);
 
   QWizardPage* previewPage = new QWizardPage;
   setupPreviewPage(previewPage);
-  previewPage->setTitle(i18n("Preview"));
+  previewPage->setTitle(tr("Preview"));
   addPage(previewPage);
 
   setOptions(HaveHelpButton | HaveCustomButton1);
-  setButtonText(CustomButton1, i18n("&Save Settings"));
+  setButtonText(CustomButton1, tr("&Save Settings"));
   connect(this, SIGNAL(helpRequested()), this, SLOT(showHelp()));
   connect(this, SIGNAL(customButtonClicked(int)), this, SLOT(saveConfig()));
   connect(this, SIGNAL(currentIdChanged(int)), this, SLOT(pageChanged()));
@@ -100,43 +98,43 @@ void RenDirDialog::setupMainPage(QWidget* page, QVBoxLayout* vlayout)
   QHBoxLayout* actionLayout = new QHBoxLayout;
   m_actionComboBox = new QComboBox(page);
   m_tagversionComboBox = new QComboBox(page);
-  m_actionComboBox->insertItem(ActionRename, i18n("Rename Directory"));
-  m_actionComboBox->insertItem(ActionCreate, i18n("Create Directory"));
+  m_actionComboBox->insertItem(ActionRename, tr("Rename Directory"));
+  m_actionComboBox->insertItem(ActionCreate, tr("Create Directory"));
   actionLayout->addWidget(m_actionComboBox);
   connect(m_actionComboBox, SIGNAL(activated(int)), this, SLOT(slotUpdateNewDirname()));
-  m_tagversionComboBox->addItem(i18n("From Tag 2 and Tag 1"), TrackData::TagV2V1);
-  m_tagversionComboBox->addItem(i18n("From Tag 1"), TrackData::TagV1);
-  m_tagversionComboBox->addItem(i18n("From Tag 2"), TrackData::TagV2);
+  m_tagversionComboBox->addItem(tr("From Tag 2 and Tag 1"), TrackData::TagV2V1);
+  m_tagversionComboBox->addItem(tr("From Tag 1"), TrackData::TagV1);
+  m_tagversionComboBox->addItem(tr("From Tag 2"), TrackData::TagV2);
   actionLayout->addWidget(m_tagversionComboBox);
   connect(m_tagversionComboBox, SIGNAL(activated(int)), this, SLOT(slotUpdateNewDirname()));
   vlayout->addLayout(actionLayout);
 
   QHBoxLayout* formatLayout = new QHBoxLayout;
-  QLabel* formatLabel = new QLabel(i18n("&Format:"), page);
+  QLabel* formatLabel = new QLabel(tr("&Format:"), page);
   m_formatComboBox = new QComboBox(page);
   QStringList strList;
-  for (const char** sl = MiscConfig::s_defaultDirFmtList; *sl != 0; ++sl) {
+  for (const char** sl = RenDirConfig::s_defaultDirFmtList; *sl != 0; ++sl) {
     strList += QString::fromLatin1(*sl);
   }
   m_formatComboBox->addItems(strList);
   m_formatComboBox->setEditable(true);
-  m_formatComboBox->setItemText(ConfigStore::s_miscCfg.m_dirFormatItem,
-                                ConfigStore::s_miscCfg.m_dirFormatText);
-  m_formatComboBox->setCurrentIndex(ConfigStore::s_miscCfg.m_dirFormatItem);
+  m_formatComboBox->setItemText(RenDirConfig::instance().m_dirFormatItem,
+                                RenDirConfig::instance().m_dirFormatText);
+  m_formatComboBox->setCurrentIndex(RenDirConfig::instance().m_dirFormatItem);
   m_tagversionComboBox->setCurrentIndex(
-        m_tagversionComboBox->findData(ConfigStore::s_miscCfg.m_renDirSrc));
+        m_tagversionComboBox->findData(RenDirConfig::instance().m_renDirSrc));
   formatLabel->setBuddy(m_formatComboBox);
   formatLayout->addWidget(formatLabel);
   formatLayout->addWidget(m_formatComboBox);
   connect(m_formatComboBox, SIGNAL(activated(int)), this, SLOT(slotUpdateNewDirname()));
-  connect(m_formatComboBox, SIGNAL(editTextChanged(const QString&)), this, SLOT(slotUpdateNewDirname()));
+  connect(m_formatComboBox, SIGNAL(editTextChanged(QString)), this, SLOT(slotUpdateNewDirname()));
   vlayout->addLayout(formatLayout);
 
   QGridLayout* fromToLayout = new QGridLayout;
   vlayout->addLayout(fromToLayout);
-  QLabel* fromLabel = new QLabel(i18n("From:"), page);
+  QLabel* fromLabel = new QLabel(tr("From:"), page);
   m_currentDirLabel = new QLabel(page);
-  QLabel* toLabel = new QLabel(i18n("To:"), page);
+  QLabel* toLabel = new QLabel(tr("To:"), page);
   m_newDirLabel = new QLabel(page);
   fromToLayout->addWidget(fromLabel, 0, 0);
   fromToLayout->addWidget(m_currentDirLabel, 0, 1);
@@ -224,9 +222,9 @@ void RenDirDialog::slotUpdateNewDirname()
  */
 void RenDirDialog::saveConfig()
 {
-  ConfigStore::s_miscCfg.m_dirFormatItem = m_formatComboBox->currentIndex();
-  ConfigStore::s_miscCfg.m_dirFormatText = m_formatComboBox->currentText();
-  ConfigStore::s_miscCfg.m_renDirSrc = TrackData::tagVersionCast(
+  RenDirConfig::instance().m_dirFormatItem = m_formatComboBox->currentIndex();
+  RenDirConfig::instance().m_dirFormatText = m_formatComboBox->currentText();
+  RenDirConfig::instance().m_renDirSrc = TrackData::tagVersionCast(
     m_tagversionComboBox->itemData(m_tagversionComboBox->currentIndex()).toInt());
 }
 
