@@ -30,10 +30,9 @@
 #include "textimporter.h"
 #include "importparser.h"
 #include "trackdatamodel.h"
-#include "configstore.h"
+#include "importconfig.h"
 #include "contexthelp.h"
 #include "formatlistedit.h"
-#include "qtcompatmac.h"
 
 /**
  * Constructor.
@@ -46,15 +45,15 @@ TagImportDialog::TagImportDialog(QWidget* parent,
   QDialog(parent), m_trackDataModel(trackDataModel)
 {
   setObjectName(QLatin1String("TagImportDialog"));
-  setWindowTitle(i18n("Import from Tags"));
+  setWindowTitle(tr("Import from Tags"));
   setSizeGripEnabled(true);
 
   QVBoxLayout* vboxLayout = new QVBoxLayout(this);
 
   m_formatListEdit = new FormatListEdit(
-        QStringList() << i18n("Format:")
-                      << i18n("Source:")
-                      << i18n("Extraction:"),
+        QStringList() << tr("Format:")
+                      << tr("Source:")
+                      << tr("Extraction:"),
         QStringList() << QString()
                       << TrackDataFormatReplacer::getToolTip()
                       << ImportParser::getFormatToolTip(),
@@ -62,20 +61,20 @@ TagImportDialog::TagImportDialog(QWidget* parent,
   vboxLayout->addWidget(m_formatListEdit);
 
   QHBoxLayout* buttonLayout = new QHBoxLayout;
-  QPushButton* helpButton = new QPushButton(i18n("&Help"), this);
+  QPushButton* helpButton = new QPushButton(tr("&Help"), this);
   helpButton->setAutoDefault(false);
   buttonLayout->addWidget(helpButton);
   connect(helpButton, SIGNAL(clicked()), this, SLOT(showHelp()));
-  QPushButton* saveButton = new QPushButton(i18n("&Save Settings"), this);
+  QPushButton* saveButton = new QPushButton(tr("&Save Settings"), this);
   saveButton->setAutoDefault(false);
   buttonLayout->addWidget(saveButton);
   connect(saveButton, SIGNAL(clicked()), this, SLOT(saveConfig()));
   buttonLayout->addStretch();
-  QPushButton* applyButton = new QPushButton(i18n("&Apply"), this);
+  QPushButton* applyButton = new QPushButton(tr("&Apply"), this);
   applyButton->setAutoDefault(false);
   buttonLayout->addWidget(applyButton);
   connect(applyButton, SIGNAL(clicked()), this, SLOT(apply()));
-  QPushButton* closeButton = new QPushButton(i18n("&Close"), this);
+  QPushButton* closeButton = new QPushButton(tr("&Close"), this);
   closeButton->setAutoDefault(false);
   buttonLayout->addWidget(closeButton);
   connect(closeButton, SIGNAL(clicked()), this, SLOT(accept()));
@@ -116,10 +115,10 @@ void TagImportDialog::apply()
 void TagImportDialog::setFormatFromConfig()
 {
   m_formatListEdit->setFormats(
-        QList<QStringList>() << ConfigStore::s_genCfg.m_importTagsNames
-                             << ConfigStore::s_genCfg.m_importTagsSources
-                             << ConfigStore::s_genCfg.m_importTagsExtractions,
-        ConfigStore::s_genCfg.m_importTagsIdx);
+        QList<QStringList>() << ImportConfig::instance().m_importTagsNames
+                             << ImportConfig::instance().m_importTagsSources
+                             << ImportConfig::instance().m_importTagsExtractions,
+        ImportConfig::instance().m_importTagsIdx);
 }
 
 /**
@@ -128,10 +127,10 @@ void TagImportDialog::setFormatFromConfig()
 void TagImportDialog::saveConfig()
 {
   QList<QStringList> formats = m_formatListEdit->getFormats(
-        &ConfigStore::s_genCfg.m_importTagsIdx);
-  ConfigStore::s_genCfg.m_importTagsNames = formats.at(0);
-  ConfigStore::s_genCfg.m_importTagsSources = formats.at(1);
-  ConfigStore::s_genCfg.m_importTagsExtractions = formats.at(2);
+        &ImportConfig::instance().m_importTagsIdx);
+  ImportConfig::instance().m_importTagsNames = formats.at(0);
+  ImportConfig::instance().m_importTagsSources = formats.at(1);
+  ImportConfig::instance().m_importTagsExtractions = formats.at(2);
 
   setFormatFromConfig();
 }
