@@ -34,26 +34,26 @@
 #include "fileproxymodel.h"
 #include "modeliterator.h"
 #include "taggedfile.h"
-#include "kid3mainwindow.h"
-#include "configstore.h"
+#include "basemainwindow.h"
+#include "useractionsconfig.h"
+#include "guiconfig.h"
 #include "externalprocess.h"
 #include "commandformatreplacer.h"
-#include "qtcompatmac.h"
 
 /**
  * Constructor.
  * @param parent parent widget
  * @param mainWin main window
  */
-FileList::FileList(QWidget* parent, Kid3MainWindow* mainWin) :
+FileList::FileList(QWidget* parent, BaseMainWindowImpl* mainWin) :
   QTreeView(parent), m_process(0), m_mainWin(mainWin)
 {
   setObjectName(QLatin1String("FileList"));
   setSelectionMode(ExtendedSelection);
   setSortingEnabled(false);
   setContextMenuPolicy(Qt::CustomContextMenu);
-  connect(this, SIGNAL(customContextMenuRequested(const QPoint&)),
-      this, SLOT(customContextMenu(const QPoint&)));
+  connect(this, SIGNAL(customContextMenuRequested(QPoint)),
+      this, SLOT(customContextMenu(QPoint)));
 #if defined HAVE_PHONON || QT_VERSION >= 0x050000
   connect(this, SIGNAL(doubleClicked(QModelIndex)),
           this, SLOT(playIfTaggedFile(QModelIndex)));
@@ -82,28 +82,30 @@ QSize FileList::sizeHint() const
 /**
  * Fill the filelist with the files found in a directory.
  *
- * @param dirIndex index of directory in filesystem model
- * @param fileIndex index of file to select in filesystem model (optional,
- * else invalid)
+ * @param dirIndex index of directory in file proxy model
+ * @param fileIndexes indexes of files to select in file proxy model
+ * (optional, else empty)
  *
  * @return false if name is not directory path, else true.
  */
-bool FileList::readDir(const QModelIndex& dirIndex,
-                        const QModelIndex& fileIndex) {
-  QAbstractProxyModel* proxyModel = qobject_cast<QAbstractProxyModel*>(model());
-  QModelIndex rootIndex = proxyModel ? proxyModel->mapFromSource(dirIndex) : dirIndex;
-  if (rootIndex.isValid()) {
-    setRootIndex(rootIndex);
-    if (fileIndex.isValid()) {
-      QModelIndex index = proxyModel ? proxyModel->mapFromSource(fileIndex) : fileIndex;
-      if (index.isValid()) {
-        setCurrentIndex(index);
+bool FileList::readDir(const QPersistentModelIndex& dirIndex,
+                       const QList<QPersistentModelIndex>& fileIndexes) {
+  if (dirIndex.isValid()) {
+    setRootIndex(dirIndex);
+    if (QItemSelectionModel* selModel = selectionModel()) {
+      selModel->clearSelection();
+      if (!fileIndexes.isEmpty()) {
+        foreach (const QPersistentModelIndex& fileIndex, fileIndexes) {
+          selModel->select(fileIndex, QItemSelectionModel::Select);
+          scrollTo(fileIndex);
+        }
+        selModel->setCurrentIndex(fileIndexes.first(),
+                                  QItemSelectionModel::NoUpdate);
+      } else {
+        setCurrentIndex(dirIndex);
+        // Make sure that this invisible root index item is not selected
+        selModel->clearSelection();
       }
-    } else {
-      setCurrentIndex(rootIndex);
-      // Make sure that this invisible root index item is not selected
-      if (selectionModel())
-        selectionModel()->clearSelection();
     }
     return true;
   }
@@ -118,7 +120,7 @@ void FileList::updateCurrentSelection()
   if (!selectionModel())
     return;
   m_currentSelection.clear();
-  foreach (QModelIndex index, selectionModel()->selectedIndexes()) {
+  foreach (const QModelIndex& index, selectionModel()->selectedIndexes()) {
     m_currentSelection.append(QPersistentModelIndex(index));
   }
 }
@@ -133,17 +135,17 @@ void FileList::contextMenu(const QModelIndex& index, const QPoint& pos)
 {
   if (index.isValid()) {
     QMenu menu(this);
-    menu.addAction(i18n("&Expand all"), m_mainWin, SLOT(expandFileList()));
-    menu.addAction(i18n("&Collapse all"), this, SLOT(collapseAll()));
-    menu.addAction(i18n("&Rename"), m_mainWin, SLOT(renameFile()));
-    menu.addAction(i18n("&Move to Trash"), m_mainWin, SLOT(deleteFile()));
+    menu.addAction(tr("&Expand all"), m_mainWin, SLOT(expandFileList()));
+    menu.addAction(tr("&Collapse all"), this, SLOT(collapseAll()));
+    menu.addAction(tr("&Rename"), m_mainWin, SLOT(renameFile()));
+    menu.addAction(tr("&Move to Trash"), m_mainWin, SLOT(deleteFile()));
 #if defined HAVE_PHONON || QT_VERSION >= 0x050000
-    menu.addAction(i18n("&Play"), m_mainWin, SLOT(slotPlayAudio()));
+    menu.addAction(tr("&Play"), m_mainWin, SLOT(slotPlayAudio()));
 #endif
     int id = 0;
-    for (QList<MiscConfig::MenuCommand>::const_iterator
-           it = ConfigStore::s_miscCfg.m_contextMenuCommands.begin();
-         it != ConfigStore::s_miscCfg.m_contextMenuCommands.end();
+    for (QList<UserActionsConfig::MenuCommand>::const_iterator
+           it = UserActionsConfig::instance().m_contextMenuCommands.begin();
+         it != UserActionsConfig::instance().m_contextMenuCommands.end();
          ++it) {
       QString name((*it).getName());
       if (!name.isEmpty()) {
@@ -184,7 +186,7 @@ QStringList FileList::formatStringList(const QStringList& format)
   TaggedFile* firstSelectedFile = 0;
   QModelIndexList selItems(selectionModel()
        ? selectionModel()->selectedIndexes() : QModelIndexList());
-  foreach (QModelIndex index, selItems) {
+  foreach (const QModelIndex& index, selItems) {
     if (TaggedFile* taggedFile = FileProxyModel::getTaggedFileOfIndex(index)) {
       if (!firstSelectedFile) {
         firstSelectedFile = taggedFile;
@@ -249,16 +251,15 @@ QStringList FileList::formatStringList(const QStringList& format)
  */
 void FileList::executeContextCommand(int id)
 {
-  if (id < static_cast<int>(ConfigStore::s_miscCfg.m_contextMenuCommands.size())) {
+  if (id < static_cast<int>(UserActionsConfig::instance().m_contextMenuCommands.size())) {
     QStringList args;
-    const MiscConfig::MenuCommand& menuCmd = ConfigStore::s_miscCfg.m_contextMenuCommands[id];
+    const UserActionsConfig::MenuCommand& menuCmd = UserActionsConfig::instance().m_contextMenuCommands[id];
     QString cmd = menuCmd.getCommand();
 
     int len = cmd.length();
-    int begin;
     int end = 0;
     while (end < len) {
-      begin = end;
+      int begin = end;
       while (begin < len && cmd[begin] == QLatin1Char(' ')) ++begin;
       if (begin >= len) break;
       if (cmd[begin] == QLatin1Char('"')) {
@@ -305,9 +306,9 @@ void FileList::executeAction(QAction* action)
   if (action) {
     QString name = action->text().remove(QLatin1Char('&'));
     int id = 0;
-    for (QList<MiscConfig::MenuCommand>::const_iterator
-           it = ConfigStore::s_miscCfg.m_contextMenuCommands.begin();
-         it != ConfigStore::s_miscCfg.m_contextMenuCommands.end();
+    for (QList<UserActionsConfig::MenuCommand>::const_iterator
+           it = UserActionsConfig::instance().m_contextMenuCommands.begin();
+         it != UserActionsConfig::instance().m_contextMenuCommands.end();
          ++it) {
       if (name == (*it).getName()) {
         executeContextCommand(id);
@@ -336,7 +337,7 @@ void FileList::customContextMenu(const QPoint& pos)
  */
 void FileList::playIfTaggedFile(const QModelIndex& index)
 {
-  if (ConfigStore::s_miscCfg.m_playOnDoubleClick &&
+  if (GuiConfig::instance().m_playOnDoubleClick &&
       FileProxyModel::getTaggedFileOfIndex(index)) {
     m_mainWin->slotPlayAudio();
   }
