@@ -31,7 +31,7 @@
 #include <QList>
 #include "config.h"
 
-class Kid3MainWindow;
+class BaseMainWindowImpl;
 class ExternalProcess;
 
 /**
@@ -46,7 +46,7 @@ public:
    * @param parent parent widget
    * @param mainWin main window
    */
-  FileList(QWidget* parent, Kid3MainWindow* mainWin);
+  FileList(QWidget* parent, BaseMainWindowImpl* mainWin);
 
   /**
    * Destructor.
@@ -62,14 +62,15 @@ public:
   /**
    * Fill the filelist with the files found in a directory.
    *
-   * @param dirIndex index of directory in filesystem model
-   * @param fileIndex index of file to select in filesystem model (optional,
-   * else invalid)
+   * @param dirIndex index of directory in file proxy model
+   * @param fileIndexes indexes of files to select in file proxy model
+   * (optional, else empty)
    *
    * @return false if name is not directory path, else true.
    */
-  bool readDir(const QModelIndex& dirIndex,
-               const QModelIndex& fileIndex=QModelIndex());
+  bool readDir(const QPersistentModelIndex& dirIndex,
+               const QList<QPersistentModelIndex>& fileIndexes =
+                 QList<QPersistentModelIndex>());
 
   /**
    * Get the stored current selection.
@@ -165,7 +166,7 @@ private:
   /** Process for context menu commands */
   ExternalProcess* m_process;
   QList<QPersistentModelIndex> m_currentSelection;
-  Kid3MainWindow* m_mainWin;
+  BaseMainWindowImpl* m_mainWin;
 };
 
 #endif // FILELIST_H
