@@ -50,22 +50,16 @@
 #include "frametablemodel.h"
 #include "trackdata.h"
 #include "genres.h"
-#include "kid3mainwindow.h"
+#include "basemainwindow.h"
 #include "filelist.h"
 #include "dirlist.h"
 #include "picturelabel.h"
-#include "configstore.h"
-#include "miscconfig.h"
+#include "fileconfig.h"
+#include "guiconfig.h"
 #include "formatconfig.h"
 #include "dirproxymodel.h"
 #include "fileproxymodel.h"
 #include "kid3application.h"
-#include "qtcompatmac.h"
-
-#ifndef CONFIG_USE_KDE
-#include <QAction>
-#include "shortcutsmodel.h"
-#endif
 
 /** Collapse pixmap, will be allocated in constructor */
 QPixmap* Kid3Form::s_collapsePixmap = 0;
@@ -118,7 +112,7 @@ public:
 
 protected:
   /**
-   * Event filter function, calls Kid3MainWindow::editOrAddPicture().
+   * Event filter function, calls Kid3Application::editOrAddPicture().
    *
    * @param obj watched object
    * @param event event for object
@@ -133,7 +127,7 @@ private:
 };
 
 /**
- * Event filter function, calls Kid3MainWindow::editOrAddPicture() on double click.
+ * Event filter function, calls Kid3Application::editOrAddPicture() on double click.
  *
  * @param obj watched object
  * @param event event for object
@@ -158,8 +152,9 @@ bool PictureDblClickHandler::eventFilter(QObject* obj, QEvent* event)
  * @param app application
  * @param parent parent widget
  */
-Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
- : QSplitter(parent), m_app(app)
+Kid3Form::Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
+                   QWidget* parent)
+  : QSplitter(parent), m_app(app), m_mainWin(mainWin)
 {
   setObjectName(QLatin1String("Kid3Form"));
 
@@ -171,17 +166,19 @@ Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
   }
 
   setAcceptDrops(true);
-  setWindowTitle(i18n("Kid3"));
+  setWindowTitle(tr("Kid3"));
 
   m_vSplitter = new QSplitter(Qt::Vertical, this);
-  m_fileListBox = new FileList(m_vSplitter, mainWin());
+  m_fileListBox = new FileList(m_vSplitter, m_mainWin);
   m_fileListBox->setModel(m_app->getFileProxyModel());
   m_fileListBox->setSelectionModel(m_app->getFileSelectionModel());
   m_dirListBox = new DirList(m_vSplitter);
   m_dirListBox->setModel(m_app->getDirProxyModel());
 
-  connect(m_app, SIGNAL(directoryOpened(QModelIndex,QModelIndex)),
-          this, SLOT(setDirectoryIndex(QModelIndex,QModelIndex)));
+  connect(m_app,
+   SIGNAL(directoryOpened(QPersistentModelIndex,QList<QPersistentModelIndex>)),
+   this,
+   SLOT(setDirectoryIndex(QPersistentModelIndex,QList<QPersistentModelIndex>)));
 
   m_rightHalfVBox = new QWidget;
   QScrollArea* scrollView = new QScrollArea(this);
@@ -196,7 +193,7 @@ Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
 #ifdef Q_OS_MAC
   m_fileButton->setStyleSheet(QLatin1String("border: 0;"));
 #endif
-  m_fileLabel = new QLabel(i18n("F&ile"), m_rightHalfVBox);
+  m_fileLabel = new QLabel(tr("F&ile"), m_rightHalfVBox);
   QHBoxLayout* fileButtonLayout = new QHBoxLayout;
   fileButtonLayout->addWidget(m_fileButton);
   fileButtonLayout->addWidget(m_fileLabel);
@@ -207,14 +204,14 @@ Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
   rightHalfLayout->addWidget(m_fileWidget);
   QGridLayout* fileLayout = new QGridLayout(m_fileWidget);
 
-  m_nameLabel = new QLabel(i18n("Name:"), m_fileWidget);
+  m_nameLabel = new QLabel(tr("Name:"), m_fileWidget);
   fileLayout->addWidget(m_nameLabel, 0, 0);
 
   m_nameLineEdit = new QLineEdit(m_fileWidget);
   fileLayout->addWidget(m_nameLineEdit, 0, 1, 1, 4);
   m_fileLabel->setBuddy(m_nameLineEdit);
 
-  QLabel* formatLabel = new QLabel(i18n("Format:") + QChar(0x2191),
+  QLabel* formatLabel = new QLabel(tr("Format:") + QChar(0x2191),
                                    m_fileWidget);
   fileLayout->addWidget(formatLabel, 1, 0);
 
@@ -229,16 +226,16 @@ Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
           m_formatComboBox, SLOT(setEditText(QString)));
   fileLayout->addWidget(m_formatComboBox, 1, 1);
 
-  QLabel* fromTagLabel = new QLabel(i18n("From:"), m_fileWidget);
+  QLabel* fromTagLabel = new QLabel(tr("From:"), m_fileWidget);
   fileLayout->addWidget(fromTagLabel, 1, 2);
-  m_fnV1Button = new QPushButton(i18n("Tag 1"), m_fileWidget);
-  m_fnV1Button->setToolTip(i18n("Filename from Tag 1"));
+  m_fnV1Button = new QPushButton(tr("Tag 1"), m_fileWidget);
+  m_fnV1Button->setToolTip(tr("Filename from Tag 1"));
   fileLayout->addWidget(m_fnV1Button, 1, 3);
-  QPushButton* fnV2Button = new QPushButton(i18n("Tag 2"), m_fileWidget);
-  fnV2Button->setToolTip(i18n("Filename from Tag 2"));
+  QPushButton* fnV2Button = new QPushButton(tr("Tag 2"), m_fileWidget);
+  fnV2Button->setToolTip(tr("Filename from Tag 2"));
   fileLayout->addWidget(fnV2Button, 1, 4);
 
-  QLabel* formatFromFilenameLabel = new QLabel(i18n("Format:") + QChar(0x2193),
+  QLabel* formatFromFilenameLabel = new QLabel(tr("Format:") + QChar(0x2193),
                                                m_fileWidget);
   fileLayout->addWidget(formatFromFilenameLabel, 2, 0);
 
@@ -253,15 +250,15 @@ Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
           m_formatFromFilenameComboBox, SLOT(setEditText(QString)));
   fileLayout->addWidget(m_formatFromFilenameComboBox, 2, 1);
 
-  QLabel* toTagLabel = new QLabel(i18n("To:"), m_fileWidget);
+  QLabel* toTagLabel = new QLabel(tr("To:"), m_fileWidget);
   fileLayout->addWidget(toTagLabel, 2, 2);
   m_toTagV1Button =
-    new QPushButton(i18n("Tag 1"), m_fileWidget);
-  m_toTagV1Button->setToolTip(i18n("Tag 1 from Filename"));
+    new QPushButton(tr("Tag 1"), m_fileWidget);
+  m_toTagV1Button->setToolTip(tr("Tag 1 from Filename"));
   fileLayout->addWidget(m_toTagV1Button, 2, 3);
   QPushButton* toTagV2Button =
-    new QPushButton(i18n("Tag 2"), m_fileWidget);
-  toTagV2Button->setToolTip(i18n("Tag 2 from Filename"));
+    new QPushButton(tr("Tag 2"), m_fileWidget);
+  toTagV2Button->setToolTip(tr("Tag 2 from Filename"));
   fileLayout->addWidget(toTagV2Button, 2, 4);
 
   m_tag1Button = new QToolButton(m_rightHalfVBox);
@@ -270,7 +267,7 @@ Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
 #ifdef Q_OS_MAC
   m_tag1Button->setStyleSheet(QLatin1String("border: 0;"));
 #endif
-  m_tag1Label = new QLabel(i18n("Tag &1"), m_rightHalfVBox);
+  m_tag1Label = new QLabel(tr("Tag &1"), m_rightHalfVBox);
   QHBoxLayout* tag1ButtonLayout = new QHBoxLayout;
   tag1ButtonLayout->addWidget(m_tag1Button);
   tag1ButtonLayout->addWidget(m_tag1Label);
@@ -290,18 +287,18 @@ Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
   idV1HBoxLayout->addLayout(buttonsV1VBoxLayout);
 
   QPushButton* id3V1PushButton =
-    new QPushButton(i18n("From Tag 2"), m_tag1Widget);
+    new QPushButton(tr("From Tag 2"), m_tag1Widget);
   buttonsV1VBoxLayout->addWidget(id3V1PushButton);
 
-  QPushButton* copyV1PushButton = new QPushButton(i18n("Copy"), m_tag1Widget);
+  QPushButton* copyV1PushButton = new QPushButton(tr("Copy"), m_tag1Widget);
   buttonsV1VBoxLayout->addWidget(copyV1PushButton);
 
   QPushButton* pasteV1PushButton =
-    new QPushButton(i18n("Paste"), m_tag1Widget);
+    new QPushButton(tr("Paste"), m_tag1Widget);
   buttonsV1VBoxLayout->addWidget(pasteV1PushButton);
 
   QPushButton* removeV1PushButton =
-    new QPushButton(i18n("Remove"), m_tag1Widget);
+    new QPushButton(tr("Remove"), m_tag1Widget);
   buttonsV1VBoxLayout->addWidget(removeV1PushButton);
 
   buttonsV1VBoxLayout->addItem(
@@ -313,7 +310,7 @@ Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
 #ifdef Q_OS_MAC
   m_tag2Button->setStyleSheet(QLatin1String("border: 0;"));
 #endif
-  m_tag2Label = new QLabel(i18n("Tag &2"), m_rightHalfVBox);
+  m_tag2Label = new QLabel(tr("Tag &2"), m_rightHalfVBox);
   QHBoxLayout* tag2ButtonLayout = new QHBoxLayout;
   tag2ButtonLayout->addWidget(m_tag2Button);
   tag2ButtonLayout->addWidget(m_tag2Label);
@@ -331,19 +328,19 @@ Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
   QVBoxLayout* buttonsV2VBoxLayout = new QVBoxLayout;
   idV2HBoxLayout->addLayout(buttonsV2VBoxLayout);
 
-  m_id3V2PushButton = new QPushButton(i18n("From Tag 1"), m_tag2Widget);
+  m_id3V2PushButton = new QPushButton(tr("From Tag 1"), m_tag2Widget);
   buttonsV2VBoxLayout->addWidget(m_id3V2PushButton);
 
   QPushButton* copyV2PushButton =
-    new QPushButton(i18n("Copy"), m_tag2Widget);
+    new QPushButton(tr("Copy"), m_tag2Widget);
   buttonsV2VBoxLayout->addWidget(copyV2PushButton);
 
   QPushButton* pasteV2PushButton =
-    new QPushButton(i18n("Paste"), m_tag2Widget);
+    new QPushButton(tr("Paste"), m_tag2Widget);
   buttonsV2VBoxLayout->addWidget(pasteV2PushButton);
 
   QPushButton* removeV2PushButton =
-    new QPushButton(i18n("Remove"), m_tag2Widget);
+    new QPushButton(tr("Remove"), m_tag2Widget);
   buttonsV2VBoxLayout->addWidget(removeV2PushButton);
 
   QFrame* frameLine = new QFrame;
@@ -352,17 +349,17 @@ Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
   buttonsV2VBoxLayout->addWidget(frameLine);
 
   QPushButton* editFramesPushButton =
-    new QPushButton(i18n("Edit"), m_tag2Widget);
+    new QPushButton(tr("Edit"), m_tag2Widget);
   buttonsV2VBoxLayout->addWidget(editFramesPushButton);
   QPushButton* framesAddPushButton =
-    new QPushButton(i18n("Add"), m_tag2Widget);
+    new QPushButton(tr("Add"), m_tag2Widget);
   buttonsV2VBoxLayout->addWidget(framesAddPushButton);
   QPushButton* deleteFramesPushButton =
-    new QPushButton(i18n("Delete"), m_tag2Widget);
+    new QPushButton(tr("Delete"), m_tag2Widget);
   buttonsV2VBoxLayout->addWidget(deleteFramesPushButton);
 
   m_pictureLabel = new PictureLabel(this);
-  m_pictureLabel->installEventFilter(new PictureDblClickHandler(m_app, mainWin()));
+  m_pictureLabel->installEventFilter(new PictureDblClickHandler(m_app, m_mainWin));
   buttonsV2VBoxLayout->addWidget(m_pictureLabel);
 
   buttonsV2VBoxLayout->addItem(
@@ -389,8 +386,8 @@ Kid3Form::Kid3Form(Kid3Application* app, QWidget* parent)
           m_app, SLOT(getTagsFromFilenameV1()));
   connect(toTagV2Button, SIGNAL(clicked()),
           m_app, SLOT(getTagsFromFilenameV2()));
-  connect(m_nameLineEdit, SIGNAL(textChanged(const QString&)), this,
-      SLOT(nameLineEditChanged(const QString&)));
+  connect(m_nameLineEdit, SIGNAL(textChanged(QString)), this,
+      SLOT(nameLineEditChanged(QString)));
   connect(m_dirListBox, SIGNAL(activated(QModelIndex)), this,
       SLOT(dirSelected(QModelIndex)));
   connect(m_fileButton, SIGNAL(clicked()), this, SLOT(showHideFile()));
@@ -455,11 +452,20 @@ void Kid3Form::dropEvent(QDropEvent* ev)
   QList<QUrl> urls = ev->mimeData()->urls();
   if (urls.isEmpty())
     return;
-  QString text = urls.first().toLocalFile();
-  if (!text.isEmpty()) {
-    m_app->openDrop(text);
+  if (
+#if QT_VERSION >= 0x040800
+    urls.first().isLocalFile()
+#else
+    !urls.first().toLocalFile().isEmpty()
+#endif
+    ) {
+    QStringList localFiles;
+    foreach (const QUrl& url, urls) {
+      localFiles.append(url.toLocalFile());
+    }
+    m_app->openDrop(localFiles);
   } else {
-    text = urls.first().toString();
+    QString text = urls.first().toString();
     if (text.startsWith(QLatin1String("http://"))) {
       m_app->dropUrl(text);
     }
@@ -471,7 +477,7 @@ void Kid3Form::dropEvent(QDropEvent* ev)
  */
 void Kid3Form::editFrame()
 {
-  m_app->editFrame(mainWin());
+  m_app->editFrame(m_mainWin);
 }
 
 /**
@@ -479,7 +485,7 @@ void Kid3Form::editFrame()
  */
 void Kid3Form::addFrame()
 {
-  m_app->addFrame(0, mainWin());
+  m_app->addFrame(0, m_mainWin);
 }
 
 /**
@@ -514,7 +520,7 @@ void Kid3Form::fnFromID3V2()
  */
 void Kid3Form::nameLineEditChanged(const QString& txt)
 {
-  formatLineEdit(m_nameLineEdit, txt, &ConfigStore::s_fnFormatCfg);
+  formatLineEdit(m_nameLineEdit, txt, &FilenameFormatConfig::instance());
 }
 
 /**
@@ -565,8 +571,8 @@ void Kid3Form::dirSelected(const QModelIndex& index)
   if (!dirPath.isEmpty()) {
     m_dirListBox->setEntryToSelect(
         dirPath.endsWith(QLatin1String("..")) ? index.parent() : QModelIndex());
-    mainWin()->updateCurrentSelection();
-    mainWin()->confirmedOpenDirectory(dirPath);
+    m_mainWin->updateCurrentSelection();
+    m_mainWin->confirmedOpenDirectory(QStringList() << dirPath);
   }
 }
 
@@ -590,7 +596,7 @@ void Kid3Form::enableControlsV1(bool enable)
  */
 void Kid3Form::setTagFormatV1(const QString& str)
 {
-  QString txt = i18n("Tag &1");
+  QString txt = tr("Tag &1");
   if (!str.isEmpty()) {
     txt += QLatin1String(": ");
     txt += str;
@@ -605,7 +611,7 @@ void Kid3Form::setTagFormatV1(const QString& str)
  */
 void Kid3Form::setTagFormatV2(const QString& str)
 {
-  QString txt = i18n("Tag &2");
+  QString txt = tr("Tag &2");
   if (!str.isEmpty()) {
     txt += QLatin1String(": ");
     txt += str;
@@ -768,18 +774,18 @@ static QStringList getItemsFromComboBox(const QComboBox* comboBox)
  */
 void Kid3Form::saveConfig()
 {
-  ConfigStore::s_miscCfg.m_splitterSizes = sizes();
-  ConfigStore::s_miscCfg.m_vSplitterSizes = m_vSplitter->sizes();
-  ConfigStore::s_miscCfg.m_formatItem = m_formatComboBox->currentIndex();
-  ConfigStore::s_miscCfg.m_formatText = m_formatComboBox->currentText();
-  ConfigStore::s_miscCfg.m_formatItems = getItemsFromComboBox(m_formatComboBox);
-  ConfigStore::s_miscCfg.m_formatFromFilenameItem = m_formatFromFilenameComboBox->currentIndex();
-  ConfigStore::s_miscCfg.m_formatFromFilenameText = m_formatFromFilenameComboBox->currentText();
-  ConfigStore::s_miscCfg.m_formatFromFilenameItems = getItemsFromComboBox(m_formatFromFilenameComboBox);
-  if (!ConfigStore::s_miscCfg.m_autoHideTags) {
-    ConfigStore::s_miscCfg.m_hideFile = m_fileWidget->isHidden();
-    ConfigStore::s_miscCfg.m_hideV1 = m_tag1Widget->isHidden();
-    ConfigStore::s_miscCfg.m_hideV2 = m_tag2Widget->isHidden();
+  GuiConfig::instance().m_splitterSizes = sizes();
+  GuiConfig::instance().m_vSplitterSizes = m_vSplitter->sizes();
+  FileConfig::instance().m_formatItem = m_formatComboBox->currentIndex();
+  FileConfig::instance().m_formatText = m_formatComboBox->currentText();
+  FileConfig::instance().m_formatItems = getItemsFromComboBox(m_formatComboBox);
+  FileConfig::instance().m_formatFromFilenameItem = m_formatFromFilenameComboBox->currentIndex();
+  FileConfig::instance().m_formatFromFilenameText = m_formatFromFilenameComboBox->currentText();
+  FileConfig::instance().m_formatFromFilenameItems = getItemsFromComboBox(m_formatFromFilenameComboBox);
+  if (!GuiConfig::instance().m_autoHideTags) {
+    GuiConfig::instance().m_hideFile = m_fileWidget->isHidden();
+    GuiConfig::instance().m_hideV1 = m_tag1Widget->isHidden();
+    GuiConfig::instance().m_hideV2 = m_tag2Widget->isHidden();
   }
 }
 
@@ -788,38 +794,38 @@ void Kid3Form::saveConfig()
  */
 void Kid3Form::readConfig()
 {
-  if (!ConfigStore::s_miscCfg.m_splitterSizes.empty()) {
-    setSizes(ConfigStore::s_miscCfg.m_splitterSizes);
+  if (!GuiConfig::instance().m_splitterSizes.empty()) {
+    setSizes(GuiConfig::instance().m_splitterSizes);
   } else {
     setSizes(QList<int>() << 307 << 601);
   }
-  if (!ConfigStore::s_miscCfg.m_vSplitterSizes.empty()) {
-    m_vSplitter->setSizes(ConfigStore::s_miscCfg.m_vSplitterSizes);
+  if (!GuiConfig::instance().m_vSplitterSizes.empty()) {
+    m_vSplitter->setSizes(GuiConfig::instance().m_vSplitterSizes);
   } else {
     m_vSplitter->setSizes(QList<int>() << 451 << 109);
   }
-  if (!ConfigStore::s_miscCfg.m_formatItems.isEmpty()) {
+  if (!FileConfig::instance().m_formatItems.isEmpty()) {
     m_formatComboBox->clear();
-    m_formatComboBox->addItems(ConfigStore::s_miscCfg.m_formatItems);
+    m_formatComboBox->addItems(FileConfig::instance().m_formatItems);
   }
-  if (!ConfigStore::s_miscCfg.m_formatFromFilenameItems.isEmpty()) {
+  if (!FileConfig::instance().m_formatFromFilenameItems.isEmpty()) {
     m_formatFromFilenameComboBox->clear();
-    m_formatFromFilenameComboBox->addItems(ConfigStore::s_miscCfg.m_formatFromFilenameItems);
+    m_formatFromFilenameComboBox->addItems(FileConfig::instance().m_formatFromFilenameItems);
   }
-  m_formatComboBox->setItemText(ConfigStore::s_miscCfg.m_formatItem,
-                                ConfigStore::s_miscCfg.m_formatText);
-  m_formatComboBox->setCurrentIndex(ConfigStore::s_miscCfg.m_formatItem);
+  m_formatComboBox->setItemText(FileConfig::instance().m_formatItem,
+                                FileConfig::instance().m_formatText);
+  m_formatComboBox->setCurrentIndex(FileConfig::instance().m_formatItem);
   m_formatFromFilenameComboBox->setItemText(
-    ConfigStore::s_miscCfg.m_formatFromFilenameItem,
-    ConfigStore::s_miscCfg.m_formatFromFilenameText);
+    FileConfig::instance().m_formatFromFilenameItem,
+    FileConfig::instance().m_formatFromFilenameText);
   m_formatFromFilenameComboBox->setCurrentIndex(
-    ConfigStore::s_miscCfg.m_formatFromFilenameItem);
-  if (!ConfigStore::s_miscCfg.m_autoHideTags) {
-    hideFile(ConfigStore::s_miscCfg.m_hideFile);
-    hideV1(ConfigStore::s_miscCfg.m_hideV1);
-    hideV2(ConfigStore::s_miscCfg.m_hideV2);
+    FileConfig::instance().m_formatFromFilenameItem);
+  if (!GuiConfig::instance().m_autoHideTags) {
+    hideFile(GuiConfig::instance().m_hideFile);
+    hideV1(GuiConfig::instance().m_hideV1);
+    hideV2(GuiConfig::instance().m_hideV2);
   }
-  hidePicture(ConfigStore::s_miscCfg.m_hidePicture);
+  hidePicture(GuiConfig::instance().m_hidePicture);
 }
 
 /**
@@ -838,40 +844,11 @@ void Kid3Form::setPictureData(const QByteArray* data)
  */
 void Kid3Form::setDetailInfo(const TaggedFile::DetailInfo& info)
 {
-  QString str;
-  if (info.valid) {
-    str = info.format;
-    str += QLatin1Char(' ');
-    if (info.bitrate > 0 && info.bitrate < 999) {
-      if (info.vbr) str += QLatin1String("VBR ");
-      str += QString::number(info.bitrate);
-      str += QLatin1String(" kbps ");
-    }
-    if (info.sampleRate > 0) {
-      str += QString::number(info.sampleRate);
-      str += QLatin1String(" Hz ");
-    }
-    switch (info.channelMode) {
-      case TaggedFile::DetailInfo::CM_Stereo:
-        str += QLatin1String("Stereo ");
-        break;
-      case TaggedFile::DetailInfo::CM_JointStereo:
-        str += QLatin1String("Joint Stereo ");
-        break;
-      default:
-        if (info.channels > 0) {
-          str += QString::number(info.channels);
-          str += QLatin1String(" Channels ");
-        }
-    }
-    if (info.duration > 0) {
-      str += TaggedFile::formatTime(info.duration);
-    }
-  }
+  QString str = info.toString();
   if (!str.isEmpty()) {
-    str = i18n("F&ile") + QLatin1String(": ") + str;
+    str = tr("F&ile") + QLatin1String(": ") + str;
   } else {
-    str = i18n("F&ile");
+    str = tr("F&ile");
   }
   m_fileLabel->setText(str);
 }
@@ -916,64 +893,68 @@ void Kid3Form::selectAllInDirectory()
   }
 }
 
+/**
+ * Set the next file as the current file.
+ *
+ * @param select true to select the file
+ *
+ * @return true if a next file exists.
+ */
+bool Kid3Form::nextFile(bool select)
+{
+  FrameTable* editingFrameTable = getEditingFrameTable();
+  bool ok = m_app->nextFile(select);
+  if (ok && editingFrameTable) {
+    editingFrameTable->edit(editingFrameTable->currentIndex());
+  }
+  return ok;
+}
+
+/**
+ * Set the previous file as the current file.
+ *
+ * @param select true to select the file
+ *
+ * @return true if a previous file exists.
+ */
+bool Kid3Form::previousFile(bool select)
+{
+  FrameTable* editingFrameTable = getEditingFrameTable();
+  bool ok = m_app->previousFile(select);
+  if (ok && editingFrameTable) {
+    editingFrameTable->edit(editingFrameTable->currentIndex());
+  }
+  return ok;
+}
+
+/**
+ * Get frame table which is currently in editing state.
+ * The returned frame table can be used to restore the editing state after
+ * changing the current file.
+ * @return frame table which is in editing state, 0 if none.
+ */
+FrameTable* Kid3Form::getEditingFrameTable() const
+{
+  if (QWidget* focusWidget = QApplication::focusWidget()) {
+    if (m_framesV1Table->getCurrentEditor() == focusWidget) {
+      return m_framesV1Table;
+    } else if (m_framesV2Table->getCurrentEditor() == focusWidget) {
+      return m_framesV2Table;
+    }
+  }
+  return 0;
+}
+
 /**
  * Set the root index of the directory and file lists.
  *
- * @param directoryIndex root index of directory in file system model
- * @param fileIndex index of file to select
+ * @param directoryIndex root index of directory in file proxy model
+ * @param fileIndexes indexes of files to select in file proxy model
  */
-void Kid3Form::setDirectoryIndex(const QModelIndex& directoryIndex,
-                                 const QModelIndex& fileIndex)
+void Kid3Form::setDirectoryIndex(const QPersistentModelIndex& directoryIndex,
+                                 const QList<QPersistentModelIndex>& fileIndexes)
 {
-  m_fileListBox->readDir(directoryIndex, fileIndex);
-  m_dirListBox->readDir(directoryIndex);
+  m_fileListBox->readDir(directoryIndex, fileIndexes);
+  m_dirListBox->readDir(
+        m_app->getFileProxyModel()->mapToSource(directoryIndex));
 }
-
-#ifndef CONFIG_USE_KDE
-/**
- * Init actions.
- */
-void Kid3Form::initActions()
-{
-  QString ctx(i18n("Filename"));
-  ShortcutsModel* sm = m_app->getConfigStore()->getShortcutsModel();
-  initAction(i18n("From Tag 1"), QLatin1String("filename_from_v1"), this, SLOT(fnFromID3V1()), ctx, sm);
-  initAction(i18n("From Tag 2"), QLatin1String("filename_from_v2"), this, SLOT(fnFromID3V2()), ctx, sm);
-  initAction(i18n("Focus"), QLatin1String("filename_focus"), this, SLOT(setFocusFilename()), ctx, sm);
-  ctx = i18n("Tag 1");
-  initAction(i18n("From Filename"), QLatin1String("v1_from_filename"), m_app, SLOT(getTagsFromFilenameV1()), ctx, sm);
-  initAction(i18n("From Tag 2"), QLatin1String("v1_from_v2"), m_app, SLOT(copyV2ToV1()), ctx, sm);
-  initAction(i18n("Copy"), QLatin1String("v1_copy"), m_app, SLOT(copyTagsV1()), ctx, sm);
-  initAction(i18n("Paste"), QLatin1String("v1_paste"), m_app, SLOT(pasteTagsV1()), ctx, sm);
-  initAction(i18n("Remove"), QLatin1String("v1_remove"), m_app, SLOT(removeTagsV1()), ctx, sm);
-  initAction(i18n("Focus"), QLatin1String("v1_focus"), this, SLOT(setFocusV1()), ctx, sm);
-  ctx = i18n("Tag 2");
-  initAction(i18n("From Filename"), QLatin1String("v2_from_filename"), m_app, SLOT(getTagsFromFilenameV2()), ctx, sm);
-  initAction(i18n("From Tag 1"), QLatin1String("v2_from_v1"), m_app, SLOT(copyV1ToV2()), ctx, sm);
-  initAction(i18n("Copy"), QLatin1String("v2_copy"), m_app, SLOT(copyTagsV2()), ctx, sm);
-  initAction(i18n("Paste"), QLatin1String("v2_paste"), m_app, SLOT(pasteTagsV2()), ctx, sm);
-  initAction(i18n("Remove"), QLatin1String("v2_remove"), m_app, SLOT(removeTagsV2()), ctx, sm);
-  initAction(i18n("Edit"), QLatin1String("frames_edit"), this, SLOT(editFrame()), ctx, sm);
-  initAction(i18n("Add"), QLatin1String("frames_add"), this, SLOT(addFrame()), ctx, sm);
-  initAction(i18n("Delete"), QLatin1String("frames_delete"), this, SLOT(deleteFrame()), ctx, sm);
-  initAction(i18n("Focus"), QLatin1String("v2_focus"), this, SLOT(setFocusV2()), ctx, sm);
-  ctx = i18n("File List");
-  initAction(i18n("Focus"), QLatin1String("filelist_focus"), this, SLOT(setFocusFileList()), ctx, sm);
-  ctx = i18n("Directory List");
-  initAction(i18n("Focus"), QLatin1String("dirlist_focus"), this, SLOT(setFocusDirList()), ctx, sm);
-}
-
-void Kid3Form::initAction(const QString& text, const QString& name,
-                          const QObject* receiver, const char* slot,
-                          const QString& context,
-                          ShortcutsModel* shortcutsModel)
-{
-  QAction* action = new QAction(this);
-  action->setStatusTip(text);
-  action->setText(text);
-  action->setObjectName(name);
-  shortcutsModel->registerAction(action, context);
-  connect(action, SIGNAL(triggered()), receiver, slot);
-  addAction(action);
-}
-#endif // CONFIG_USE_KDE
