@@ -48,8 +48,7 @@ class Kid3Application;
 class FileList;
 class DirList;
 class PictureLabel;
-class Kid3MainWindow;
-class ShortcutsModel;
+class BaseMainWindowImpl;
 
 /**
  * Main widget.
@@ -63,9 +62,11 @@ public:
    * Constructs an Id3Form as a child of 'parent', with the
    * name 'name' and widget flags set to 'f'.
    * @param app application
+   * @param mainWin main window
    * @param parent parent widget
    */
-  explicit Kid3Form(Kid3Application* app, QWidget* parent = 0);
+  Kid3Form(Kid3Application* app, BaseMainWindowImpl* mainWin,
+           QWidget* parent = 0);
 
   /**
    * Destructor.
@@ -196,13 +197,6 @@ public:
    */
   FrameTable* frameTableV2() { return m_framesV2Table; }
 
-#ifndef CONFIG_USE_KDE
-  /**
-   * Init actions.
-   */
-  void initActions();
-#endif
-
 public slots:
   /**
    * Frame list button Edit.
@@ -282,14 +276,32 @@ public slots:
    */
   void selectAllInDirectory();
 
+  /**
+   * Set the next file as the current file.
+   *
+   * @param select true to select the file
+   *
+   * @return true if a next file exists.
+   */
+  bool nextFile(bool select = true);
+
+  /**
+   * Set the previous file as the current file.
+   *
+   * @param select true to select the file
+   *
+   * @return true if a previous file exists.
+   */
+  bool previousFile(bool select = true);
+
   /**
    * Set the root index of the directory and file lists.
    *
    * @param directoryIndex root index of directory in file system model
-   * @param fileIndex index of file to select
+   * @param fileIndexes indexes of files to select
    */
-  void setDirectoryIndex(const QModelIndex& directoryIndex,
-                         const QModelIndex& fileIndex);
+  void setDirectoryIndex(const QPersistentModelIndex& directoryIndex,
+                         const QList<QPersistentModelIndex>& fileIndexes);
 
 private:
   /**
@@ -303,16 +315,12 @@ private:
             const FormatConfig* fcfg);
 
   /**
-   * Shortcut for pointer to parent main window.
-   * @return main window.
+   * Get frame table which is currently in editing state.
+   * The returned frame table can be used to restore the editing state after
+   * changing the current file.
+   * @return frame table which is in editing state, 0 if none.
    */
-  Kid3MainWindow* mainWin() const { return (Kid3MainWindow*)parentWidget(); }
-
-#ifndef CONFIG_USE_KDE
-  void initAction(const QString& text, const QString& name,
-                  const QObject* receiver, const char* slot,
-                  const QString& context, ShortcutsModel* shortcutsModel);
-#endif
+  FrameTable* getEditingFrameTable() const;
 
   FileList* m_fileListBox;
   QComboBox* m_formatComboBox;
@@ -338,6 +346,7 @@ private:
   QWidget* m_rightHalfVBox;
   PictureLabel* m_pictureLabel;
   Kid3Application* m_app;
+  BaseMainWindowImpl* m_mainWin;
 
   /** Collapse pixmap, will be allocated in constructor */
   static QPixmap* s_collapsePixmap;
