@@ -49,7 +49,7 @@ public:
    * @param title  title
    * @param parent parent widget
    */
-  FormatBox(const QString& title, QWidget* parent = 0);
+  explicit FormatBox(const QString& title, QWidget* parent = 0);
 
   /**
    * Destructor.
@@ -61,14 +61,14 @@ public:
    *
    * @param cfg format configuration
    */
-  void fromFormatConfig(const FormatConfig* cfg);
+  void fromFormatConfig(const FormatConfig& cfg);
 
   /**
    * Store the values in a format configuration.
    *
    * @param cfg format configuration
    */
-  void toFormatConfig(FormatConfig* cfg) const;
+  void toFormatConfig(FormatConfig& cfg) const;
 
 private:
   QComboBox* m_caseConvComboBox;
